### This is the analysis script for the study "Nouns slow down speech across structurally       ###
### and culturally diverse languages" by Frank Seifart, Jan Strunk, Swintha Danielsen, Iren     ### 
### Hartmann, Brigitte Pakendorf, Søren Wichmann, Alena Witzlack-Makarevich, Nivja H. de Jong,  ###
### and Balthasar Bickel, Proceedings of the National Academy of Sciences 115(22). 5720–5725,   ###
### 2018. doi: 10.1073/pnas.1800708115.                                                         ###

### Written by Jan Strunk                                                                       ###

### For replication purposes, we include the results from our own run as comments.

### Set options ###

options(scipen=999)
options(digits=7)

### Load libraries ###

library(lme4)
library(ggplot2)
library(dplyr)
library(effects)
library(proportion)
library(sjstats)
library(gtools)

# The library lmerTest is loaded and unloaded for certain tasks below.


### Functions ###

## Standardized coefficients
## inspired by http://stats.stackexchange.com/questions/123366/lmer-standardized-regression-coefficients
lm.beta.lmer <- function(mod) {
   b <- fixef(mod)[-1]
   sd.x <- apply(getME(mod,"X")[,-1],2,sd)
   sd.y <- sd(getME(mod,"y"))
   b*sd.x/sd.y
}

# Helper function to calculate confidence intervals per language and per word class
ci_per_language_per_pos = function (data, variable, language, pos) {
	
	result = by(data[,variable],list(data[,language],data[,pos]),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")]*100)
	result = lapply(result,FUN = function (x) {if (is.null(x)) {return(data.frame(LEXx=NA,UEXx=NA))} else {return(x)}})
	result = as.data.frame(matrix(unlist(result),ncol=2,byrow=T))
	prop = as.vector(t(prop.table(table(data[,pos],data[,variable],data[,language]),c(1,3))[,"yes",]*100))
	result = cbind(rep(levels(data[,language]),length(levels(data[,pos]))),rep(levels(data[,pos]), each = length(levels(data[,language]))),prop,result)
	colnames(result) = c("language","pos","percent","lower.ci","upper.ci")
	result$pos = factor(result$pos, levels=c("N","V","AUX"))
	return(result)
}


### ggplot2 parameters ###

pos_color_scale = scale_color_manual(values = c("N" = "#1b9e77", "V" = "#d95f02", "AUX" = "#7570b3"))
pos_fill_scale = scale_fill_manual(values = c("N" = "#1b9e77", "V" = "#d95f02", "AUX" = "#7570b3"))

pos_color_scale2 = scale_color_manual(values = c("nouns" = "#1b9e77", "verbs" = "#d95f02", "auxiliaries" = "#7570b3"))
pos_fill_scale2 = scale_fill_manual(values = c("nouns" = "#1b9e77", "verbs" = "#d95f02", "auxiliaries" = "#7570b3"))

theme_set(theme_bw(base_size = 20) + theme(text = element_text(family = "Helvetica"), plot.background = element_rect(fill = "transparent", colour = NA)))


### Load the data ###

# Complete data set
load("pre_word_windows.data.RData")

# Data set for main study of articulation rate excluding auxiliaries (AUX)
load("pre_word_windows.articulation_rate.no_aux.data.RData")

# Data set for alternative study of articulation rate including auxiliaries (AUX)
load("pre_word_windows.articulation_rate.aux.data.RData")

# Data set for main study of pause probability excluding auxiliaries (AUX)
load("pre_word_windows.pause_probability.no_aux.data.RData")

# Data set for alternative study of pause probability including auxiliaries (AUX)
load("pre_word_windows.pause_probability.aux.data.RData")

ls()

# [1] "combined.wordtimes.prewindows.publish"                         
# [2] "combined.wordtimes.prewindows.publish.articulation_rate.aux"   
# [3] "combined.wordtimes.prewindows.publish.articulation_rate.no_aux"
# [4] "combined.wordtimes.prewindows.publish.pause_probability.aux"   
# [5] "combined.wordtimes.prewindows.publish.pause_probability.no_aux"
# [6] "lm.beta.lmer"                                                  
# [7] "pos_color_scale"                                               
# [8] "pos_color_scale2"                                              
# [9] "pos_fill_scale"                                                
# [10] "pos_fill_scale2"                                               


# ## Alternatively load the data from raw table ##
# 
# combined.wordtimes.prewindows.publish = read.table(file="pre_word_windows.data.tsv",header=T,sep="\t",quote="",dec=".",comment.char="",fileEncoding="UTF-8")
# 
# # Set correct variable classes
# combined.wordtimes.prewindows.publish$whole_word_word_class_all = as.character(combined.wordtimes.prewindows.publish$whole_word_word_class_all)
# combined.wordtimes.prewindows.publish$word_position = as.numeric(combined.wordtimes.prewindows.publish$word_position)
# combined.wordtimes.prewindows.publish$word_frequency = as.numeric(combined.wordtimes.prewindows.publish$word_frequency)
# combined.wordtimes.prewindows.publish$morphemes_in_word = as.numeric(combined.wordtimes.prewindows.publish$morphemes_in_word)
# combined.wordtimes.prewindows.publish$filled_pauses_in_pre_word_window = as.numeric(combined.wordtimes.prewindows.publish$filled_pauses_in_pre_word_window)
# combined.wordtimes.prewindows.publish$false_starts_in_pre_word_window = as.numeric(combined.wordtimes.prewindows.publish$false_starts_in_pre_word_window)
# combined.wordtimes.prewindows.publish$pre_word_window_length_characters = as.numeric(combined.wordtimes.prewindows.publish$pre_word_window_length_characters)
# 
# # Change order of factor levels
# combined.wordtimes.prewindows.publish$excluded_why = factor(combined.wordtimes.prewindows.publish$excluded_why,levels=c("irrelevant word class","ambiguous word class","first word in utterance","target word disfluent","context window of length zero","empty context window","disfluency in context window"))
# combined.wordtimes.prewindows.publish$excluded = factor(combined.wordtimes.prewindows.publish$excluded,levels=c("no","articulation rate","both"))
# combined.wordtimes.prewindows.publish$excluded_aux = factor(combined.wordtimes.prewindows.publish$excluded_aux,levels=c("no","yes"))
# 
# combined.wordtimes.prewindows.publish$word_class_all = factor(combined.wordtimes.prewindows.publish$word_class_all,levels=c("-","-AFFIX","-AFFIX-","-BPN","-BPP","-N","-OTHER","-OTHER-","-PRO","-V","***","=","=AFFIX","=AUX","=BPN","=OTHER","=PRO","AFFIX","AFFIX-","AMBIGUOUS","AUX","BPN","BPN-","BPN=","BPP-","FLDPS","N","N-","OTHER","OTHER-","PRO","PRO-","UNKNOWN","UNKNOWN-","V","V-","V-BPN"))
# combined.wordtimes.prewindows.publish$word_class_relevant = factor(combined.wordtimes.prewindows.publish$word_class_relevant,levels=c("N","V","AUX","PRO","OTHER","FLDPS","BPN","BPP"))
# combined.wordtimes.prewindows.publish$word_class_relevant_aux = factor(combined.wordtimes.prewindows.publish$word_class_relevant_aux,levels=c("N","V","PRO","OTHER","FLDPS","BPN","BPP"))
# combined.wordtimes.prewindows.publish$word_class_relevant_no_aux = factor(combined.wordtimes.prewindows.publish$word_class_relevant_no_aux,levels=c("N","V","PRO","OTHER","FLDPS","BPN","BPP"))
# 
# ## Create minimal data sets for the four different studies: articulation rate (exluding and including auxiliaries) and pause probability
# ## (excluding and including auxiliaries)
# 
# # Omit cases that are excluded in all versions of the study
# combined.wordtimes.prewindows.publish.minimal = droplevels(subset(combined.wordtimes.prewindows.publish,subset=excluded!="both"))
# 
# # Omit words duplicated because of multiple roots
# combined.wordtimes.prewindows.publish.minimal = droplevels(subset(combined.wordtimes.prewindows.publish.minimal,subset=!duplicated(word_id)))
# 
# # Correct words containing both V and AUX roots to make sure their ntvr_ps_root.simplified value is "V" and not "AUX"
# combined.wordtimes.prewindows.publish.minimal$word_class_relevant[grepl("V",combined.wordtimes.prewindows.publish.minimal$whole_word_word_class_all) & grepl("AUX",combined.wordtimes.prewindows.publish.minimal$whole_word_word_class_all) & combined.wordtimes.prewindows.publish.minimal$word_class_relevant=="AUX"] = "V"
# 
# # Create data sets for the four variant studies
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux = droplevels(subset(combined.wordtimes.prewindows.publish.minimal,subset=excluded=="no" & excluded_aux=="no"))
# combined.wordtimes.prewindows.publish.articulation_rate.aux = droplevels(subset(combined.wordtimes.prewindows.publish.minimal,subset=excluded=="no"))
# combined.wordtimes.prewindows.publish.pause_probability.no_aux = droplevels(subset(combined.wordtimes.prewindows.publish.minimal,subset=excluded %in% c("no","articulation rate") & excluded_aux=="no"))
# combined.wordtimes.prewindows.publish.pause_probability.aux = droplevels(subset(combined.wordtimes.prewindows.publish.minimal,subset=excluded %in% c("no","articulation rate")))
# 
# # Delete superfluous columns
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux$excluded <- NULL
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux$excluded_why <- NULL
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux$excluded_aux <- NULL
# 
# combined.wordtimes.prewindows.publish.articulation_rate.aux$excluded <- NULL
# combined.wordtimes.prewindows.publish.articulation_rate.aux$excluded_why <- NULL
# combined.wordtimes.prewindows.publish.articulation_rate.aux$excluded_aux <- NULL
# 
# combined.wordtimes.prewindows.publish.pause_probability.no_aux$excluded <- NULL
# combined.wordtimes.prewindows.publish.pause_probability.no_aux$excluded_why <- NULL
# combined.wordtimes.prewindows.publish.pause_probability.no_aux$excluded_aux <- NULL
# 
# combined.wordtimes.prewindows.publish.pause_probability.aux$excluded <- NULL
# combined.wordtimes.prewindows.publish.pause_probability.aux$excluded_why <- NULL
# combined.wordtimes.prewindows.publish.pause_probability.aux$excluded_aux <- NULL


### Prepare data frame for collecting p values for multiple testing correction ###
### (see section "Adjust p values for multiple testing" below)                 ###

# For the alternative study including auxiliaries, only the languages English, Even, Hoocąk, and Texistepec are included (since the other corpora do not contain any annotated auxiliaries)
p.values = rbind(expand.grid(study=c("articulation rate","pause probability"),auxiliaries=c("excluded"),model=c("cross-linguistic","Baure","Bora","Chintang","Dutch","English","Even","Hoocąk","Nǁng","Texistepec"),variable=c("word class","word length","position","word class:position","word length:position","language","word class:language","speaker","text","word type")),expand.grid(study=c("articulation rate","pause probability"),auxiliaries=c("included"),model=c("cross-linguistic","English","Even","Hoocąk","Texistepec"),variable=c("word class","word length","position","word class:position","word length:position","language","word class:language","speaker","text","word type")))

p.values = arrange(p.values,study,auxiliaries,model,variable)

p.values$p.value = NA

# No interactions in study of pause probability
p.values = subset(p.values,subset=!(study=="pause probability" & variable %in% c("word class:position","word length:position")))

# No language effect in models on individual languages
p.values = subset(p.values,subset=!(model!="cross-linguistic" & variable %in% c("language","word class:language")))

# No random factor speaker for Texistepec Popoluca because there is only one speaker in this subcorpus
p.values = subset(p.values,subset=!(model=="Texistepec" & variable=="speaker"))

p.values$factor = "fixed"

p.values$factor[p.values$variable %in% c("speaker","text","word type")] = "random"

p.values$study = factor(p.values$study)
p.values$auxiliaries = factor(p.values$auxiliaries)
p.values$model = factor(p.values$model)
p.values$variable = factor(p.values$variable)
p.values$factor = factor(p.values$factor)


### Basic corpus statistics ###

# Speakers
by(combined.wordtimes.prewindows.publish$speaker,INDICES=list(combined.wordtimes.prewindows.publish$language),FUN=function(x) length(unique(x)))
# : Baure
# [1] 12
# ------------------------------------------------------------------------------------------------------
# : Bora
# [1] 46
# ------------------------------------------------------------------------------------------------------
# : Chintang
# [1] 74
# ------------------------------------------------------------------------------------------------------
# : Dutch
# [1] 42
# ------------------------------------------------------------------------------------------------------
# : English
# [1] 80
# ------------------------------------------------------------------------------------------------------
# : Even
# [1] 32
# ------------------------------------------------------------------------------------------------------
# : Hoocąk
# [1] 28
# ------------------------------------------------------------------------------------------------------
# : Nǁng
# [1] 7
# ------------------------------------------------------------------------------------------------------
# : Texistepec
# [1] 1

# Texts
by(combined.wordtimes.prewindows.publish$text,INDICES=list(combined.wordtimes.prewindows.publish$language),FUN=function(x) length(unique(x)))
# : Baure
# [1] 37
# ------------------------------------------------------------------------------------------------------
# : Bora
# [1] 37
# ------------------------------------------------------------------------------------------------------
# : Chintang
# [1] 40
# ------------------------------------------------------------------------------------------------------
# : Dutch
# [1] 17
# ------------------------------------------------------------------------------------------------------
# : English
# [1] 47
# ------------------------------------------------------------------------------------------------------
# : Even
# [1] 67
# ------------------------------------------------------------------------------------------------------
# : Hoocąk
# [1] 62
# ------------------------------------------------------------------------------------------------------
# : Nǁng
# [1] 33
# ------------------------------------------------------------------------------------------------------
# : Texistepec
# [1] 6

# Target words
by(combined.wordtimes.prewindows.publish$word_id,INDICES=list(combined.wordtimes.prewindows.publish$language),FUN=function(x) length(unique(x)))
# : Baure
# [1] 17652
# ------------------------------------------------------------------------------------------------------
# : Bora
# [1] 29802
# ------------------------------------------------------------------------------------------------------
# : Chintang
# [1] 37737
# ------------------------------------------------------------------------------------------------------
# : Dutch
# [1] 39519
# ------------------------------------------------------------------------------------------------------
# : English
# [1] 56135
# ------------------------------------------------------------------------------------------------------
# : Even
# [1] 37430
# ------------------------------------------------------------------------------------------------------
# : Hoocąk
# [1] 23191
# ------------------------------------------------------------------------------------------------------
# : Nǁng
# [1] 26061
# ------------------------------------------------------------------------------------------------------
# : Texistepec
# [1] 21321

# Utterances (annotation units)
by(combined.wordtimes.prewindows.publish$utterance_id,INDICES=list(combined.wordtimes.prewindows.publish$language),FUN=function(x) length(unique(x)))
# : Baure
# [1] 4343
# ------------------------------------------------------------------------------------------------------
# : Bora
# [1] 3979
# ------------------------------------------------------------------------------------------------------
# : Chintang
# [1] 9026
# ------------------------------------------------------------------------------------------------------
# : Dutch
# [1] 5822
# ------------------------------------------------------------------------------------------------------
# : English
# [1] 6941
# ------------------------------------------------------------------------------------------------------
# : Even
# [1] 4839
# ------------------------------------------------------------------------------------------------------
# : Hoocąk
# [1] 2936
# ------------------------------------------------------------------------------------------------------
# : Nǁng
# [1] 7990
# ------------------------------------------------------------------------------------------------------
# : Texistepec
# [1] 5461

# Words per utterance (annotation unit)
by(combined.wordtimes.prewindows.publish$word_id,INDICES=list(combined.wordtimes.prewindows.publish$language),FUN=function(x) length(unique(x))) / by(combined.wordtimes.prewindows.publish$utterance_id,INDICES=list(combined.wordtimes.prewindows.publish$language),FUN=function(x) length(unique(x)))
# : Baure
# [1] 4.064472
# ------------------------------------------------------------------------------------------------------
# : Bora
# [1] 7.489822
# ------------------------------------------------------------------------------------------------------
# : Chintang
# [1] 4.180922
# ------------------------------------------------------------------------------------------------------
# : Dutch
# [1] 6.787874
# ------------------------------------------------------------------------------------------------------
# : English
# [1] 8.087451
# ------------------------------------------------------------------------------------------------------
# : Even
# [1] 7.735069
# ------------------------------------------------------------------------------------------------------
# : Hoocąk
# [1] 7.898842
# ------------------------------------------------------------------------------------------------------
# : Nǁng
# [1] 3.261702
# ------------------------------------------------------------------------------------------------------
# : Texistepec
# [1] 3.90423

# Overall mean length of pre-word context windows
mean(combined.wordtimes.prewindows.publish$pre_word_window_length_seconds[!duplicated(combined.wordtimes.prewindows.publish$word_id)],na.rm=T)
# [1] 0.4559826

# Mean length of pre-word windows
by(combined.wordtimes.prewindows.publish,INDICES=list(combined.wordtimes.prewindows.publish$language),FUN=function(x) mean(x$pre_word_window_length_seconds[!duplicated(x$word_id)],na.rm=T))
# : Baure
# [1] 0.4766883
# ------------------------------------------------------------------------------------------------------
# : Bora
# [1] 0.4890157
# ------------------------------------------------------------------------------------------------------
# : Chintang
# [1] 0.4539256
# ------------------------------------------------------------------------------------------------------
# : Dutch
# [1] 0.4417042
# ------------------------------------------------------------------------------------------------------
# : English
# [1] 0.4568821
# ------------------------------------------------------------------------------------------------------
# : Even
# [1] 0.4850416
# ------------------------------------------------------------------------------------------------------
# : Hoocąk
# [1] 0.4948333
# ------------------------------------------------------------------------------------------------------
# : Nǁng
# [1] 0.3571397
# ------------------------------------------------------------------------------------------------------
# : Texistepec
# [1] 0.4193859

# Overall standard deviation of length of pre-word windows
sd(combined.wordtimes.prewindows.publish$pre_word_window_length_seconds[!duplicated(combined.wordtimes.prewindows.publish$word_id)],na.rm=T)
# [1] 0.1635519

# Standard deviation of length of pre-word windows
by(combined.wordtimes.prewindows.publish,INDICES=list(combined.wordtimes.prewindows.publish$language),FUN=function(x) sd(x$pre_word_window_length_seconds[!duplicated(x$word_id)],na.rm=T))
# : Baure
# [1] 0.200462
# ------------------------------------------------------------------------------------------------------
# : Bora
# [1] 0.1681685
# ------------------------------------------------------------------------------------------------------
# : Chintang
# [1] 0.1587798
# ------------------------------------------------------------------------------------------------------
# : Dutch
# [1] 0.1461674
# ------------------------------------------------------------------------------------------------------
# : English
# [1] 0.1394612
# ------------------------------------------------------------------------------------------------------
# : Even
# [1] 0.1480009
# ------------------------------------------------------------------------------------------------------
# : Hoocąk
# [1] 0.1919933
# ------------------------------------------------------------------------------------------------------
# : Nǁng
# [1] 0.166017
# ------------------------------------------------------------------------------------------------------
# : Texistepec
# [1] 0.1651179

# Excluded first words (is equal to the number of annotation units)
by(combined.wordtimes.prewindows.publish,INDICES=list(combined.wordtimes.prewindows.publish$language),FUN=function(x) length(which(is.na(x$pre_word_window_begin[!duplicated(x$word_id)]))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  4343     3979     9026     5822     6941     4839     2936     7990       5461

# Overall number of excluded words
sum(by(combined.wordtimes.prewindows.publish,INDICES=list(combined.wordtimes.prewindows.publish$language),FUN=function(x) length(which(is.na(x$pre_word_window_begin[!duplicated(x$word_id)])))))
# [1] 51337

# Overall percentage of excluded first words
length(which(is.na(combined.wordtimes.prewindows.publish$pre_word_window_length_seconds[!duplicated(combined.wordtimes.prewindows.publish$word_id)]))) * 100 / length(unique(combined.wordtimes.prewindows.publish$word_id))
# [1] 17.77302

# Excluded first words (percentage)
by(combined.wordtimes.prewindows.publish,INDICES=list(combined.wordtimes.prewindows.publish$language),FUN=function(x) length(which(is.na(x$pre_word_window_length_seconds[!duplicated(x$word_id)])))) * 100 / by(combined.wordtimes.prewindows.publish$word_id,INDICES=list(combined.wordtimes.prewindows.publish$language),FUN=function(x) length(unique(x)))
# : Baure
# [1] 24.60344
# ------------------------------------------------------------------------------------------------------
# : Bora
# [1] 13.35145
# ------------------------------------------------------------------------------------------------------
# : Chintang
# [1] 23.91817
# ------------------------------------------------------------------------------------------------------
# : Dutch
# [1] 14.73215
# ------------------------------------------------------------------------------------------------------
# : English
# [1] 12.36483
# ------------------------------------------------------------------------------------------------------
# : Even
# [1] 12.92813
# ------------------------------------------------------------------------------------------------------
# : Hoocąk
# [1] 12.66008
# ------------------------------------------------------------------------------------------------------
# : Nǁng
# [1] 30.65884
# ------------------------------------------------------------------------------------------------------
# : Texistepec
# [1] 25.61325

# Words left after excluding first words per language
with(subset(combined.wordtimes.prewindows.publish,subset=!is.na(pre_word_window_length_seconds)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   # 13309    25823    28711    33697    49194    32591    20255    18071      15860

# All languages combined
sum(with(subset(combined.wordtimes.prewindows.publish,subset=!is.na(pre_word_window_length_seconds)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 237511


### Analysis of articulation rate ###

## Information about the data ##

## Initial state of data before cleaning (including all parts-of-speech)

# Number of morphemes
with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language),FUN=function(x) length(x)))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   # 33116    66049    68501    39519    61560    71268    41045    29530      39688

# All languages
sum(with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language),FUN=function(x) length(x))))
# [1] 450276

# Individual word classes (not distinguishing auxiliaries, AUX)
with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(x)))[]
#               N     V  PRO OTHER FLDPS  BPN  BPP
# Baure      2811  5230  378 10410    NA 6861   NA
# Bora       5915  8270 4648  9306   592 5541 1148
# Chintang   6622  8775 5091 17473    NA 6307 1069
# Dutch      3973  6687 5768 21300  1791   NA   NA
# English    7777 12777 7937 27632   224   NA   NA
# Even       8835 10168 1640 16792    NA 5934 2242
# Hoocąk     3726  9104 2097 14348    NA 4215  157
# Nǁng       4416  7474 6421  7792    NA   NA   NA
# Texistepec 2932  8781 1892  8716    NA 6715  804

# All languages
colSums(with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(x))),na.rm=T)
 #     N      V    PRO  OTHER  FLDPS    BPN    BPP
 # 47007  77266  35872 133769   2607  35573   5420

# Individual word classes (distinguishing auxiliaries, AUX)
with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(x)))[]
#               N     V  AUX  PRO OTHER FLDPS  BPN  BPP
# Baure      2811  5230   NA  378 10410    NA 6861   NA
# Bora       5915  8270   NA 4648  9306   592 5541 1148
# Chintang   6622  8775   NA 5091 17473    NA 6307 1069
# Dutch      3973  6687   NA 5768 21300  1791   NA   NA
# English    7777 10903 1874 7937 27632   224   NA   NA
# Even       8835  9543  625 1640 16792    NA 5934 2242
# Hoocąk     3726  7104 2000 2097 14348    NA 4215  157
# Nǁng       4416  7474   NA 6421  7792    NA   NA   NA
# Texistepec 2932  6731 2050 1892  8716    NA 6715  804

# All languages
colSums(with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(x))),na.rm=T)
 #     N      V    AUX    PRO  OTHER  FLDPS    BPN    BPP
 # 47007  70717   6549  35872 133769   2607  35573   5420

# Number of words
with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   # 17652    29802    37737    39519    56135    37430    23191    26061      21321

# All languages
sum(with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 288848

# Number of words of different word classes (not distinguishing auxiliaries, AUX)
with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#               N     V  PRO OTHER FLDPS  BPN  BPP
# Baure      2778  5213  378 10237    NA 5376   NA
# Bora       5913  8269 4645  9298   592 5464 1148
# Chintang   6607  8659 5090 17470    NA 4010 1069
# Dutch      3973  6687 5768 21300  1791   NA   NA
# English    7777 12777 7936 27628   224   NA   NA
# Even       8835 10168 1640 16787    NA 5918 2202
# Hoocąk     3683  7967 2082 13844    NA 3570  150
# Nǁng       4415  7466 6421  7787    NA   NA   NA
# Texistepec 2738  8321 1892  8691    NA 5911  804

# All languages
colSums(with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
 #     N      V    PRO  OTHER  FLDPS    BPN    BPP
 # 46719  75527  35852 133042   2607  30249   5373

# Number of words of different word classes (distinguishing auxiliaries, AUX)
with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#               N     V  AUX  PRO OTHER FLDPS  BPN  BPP
# Baure      2778  5213   NA  378 10237    NA 5376   NA
# Bora       5913  8269   NA 4645  9298   592 5464 1148
# Chintang   6607  8659   NA 5090 17470    NA 4010 1069
# Dutch      3973  6687   NA 5768 21300  1791   NA   NA
# English    7777 10903 1874 7936 27628   224   NA   NA
# Even       8835  9543  625 1640 16787    NA 5918 2202
# Hoocąk     3683  6903 1550 2082 13844    NA 3570  150
# Nǁng       4415  7466   NA 6421  7787    NA   NA   NA
# Texistepec 2738  6272 2050 1892  8691    NA 5911  804

# All languages
colSums(with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
 #     N      V    AUX    PRO  OTHER  FLDPS    BPN    BPP
 # 46719  69915   6099  35852 133042   2607  30249   5373


## --- Relevant data set for main study excluding auxiliaries (AUX)

# Only keep N and V
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  7917    14181    15263    10660    18677    18378     9954    11881       8866

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 115777

# By word class
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#               N     V AUX PRO OTHER FLDPS BPN BPP
# Baure      2778  5213  NA  NA    NA    NA  NA  NA
# Bora       5913  8269  NA  NA    NA    NA  NA  NA
# Chintang   6607  8659  NA  NA    NA    NA  NA  NA
# Dutch      3973  6687  NA  NA    NA    NA  NA  NA
# English    7777 10903  NA  NA    NA    NA  NA  NA
# Even       8835  9543  NA  NA    NA    NA  NA  NA
# Hoocąk     3670  6417  NA  NA    NA    NA  NA  NA
# Nǁng       4415  7466  NA  NA    NA    NA  NA  NA
# Texistepec 2738  6271  NA  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP
# 46706 69428     0     0     0     0     0     0

# Exclude pre-word windows that include multiple different roots at the same time
ambiguous.words = with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all)),intersect(word_id[word_class_relevant_no_aux=="N"],word_id[word_class_relevant_no_aux=="V"]))

with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  7843    14180    15260    10660    18674    18378     9821    11881       8723

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 115420

# By word class
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#               N     V AUX PRO OTHER FLDPS BPN BPP
# Baure      2704  5139  NA  NA    NA    NA  NA  NA
# Bora       5912  8268  NA  NA    NA    NA  NA  NA
# Chintang   6604  8656  NA  NA    NA    NA  NA  NA
# Dutch      3973  6687  NA  NA    NA    NA  NA  NA
# English    7774 10900  NA  NA    NA    NA  NA  NA
# Even       8835  9543  NA  NA    NA    NA  NA  NA
# Hoocąk     3537  6284  NA  NA    NA    NA  NA  NA
# Nǁng       4415  7466  NA  NA    NA    NA  NA  NA
# Texistepec 2595  6128  NA  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP
# 46349 69071     0     0     0     0     0     0

# Excluding words without a pre-word window (first words in annotation units)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6474    13476    12364    10164    18315    17215     9149     9724       7603

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 104484

# By word class
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#               N     V AUX PRO OTHER FLDPS BPN BPP
# Baure      2454  4020  NA  NA    NA    NA  NA  NA
# Bora       5566  7910  NA  NA    NA    NA  NA  NA
# Chintang   4985  7379  NA  NA    NA    NA  NA  NA
# Dutch      3863  6301  NA  NA    NA    NA  NA  NA
# English    7542 10773  NA  NA    NA    NA  NA  NA
# Even       7980  9235  NA  NA    NA    NA  NA  NA
# Hoocąk     3091  6058  NA  NA    NA    NA  NA  NA
# Nǁng       3336  6388  NA  NA    NA    NA  NA  NA
# Texistepec 2393  5210  NA  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP
# 41210 63274     0     0     0     0     0     0

# Eliminate words with missing word frequency information
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6474    13476    12364    10164    18315    17215     9149     9722       7603

# Only happens in Nǁng. Only occurs with (acoustically) doubtful words or false starts (count as disfluencies for paper!)

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 104482

# By word class
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#               N     V AUX PRO OTHER FLDPS BPN BPP
# Baure      2454  4020  NA  NA    NA    NA  NA  NA
# Bora       5566  7910  NA  NA    NA    NA  NA  NA
# Chintang   4985  7379  NA  NA    NA    NA  NA  NA
# Dutch      3863  6301  NA  NA    NA    NA  NA  NA
# English    7542 10773  NA  NA    NA    NA  NA  NA
# Even       7980  9235  NA  NA    NA    NA  NA  NA
# Hoocąk     3091  6058  NA  NA    NA    NA  NA  NA
# Nǁng       3336  6386  NA  NA    NA    NA  NA  NA
# Texistepec 2393  5210  NA  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP
# 41210 63272     0     0     0     0     0     0

# Throw out pre-word windows before filled pauses and false starts
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6474    13472    12347    10164    18294    17129     9149     9630       7595

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 104254

# By word class
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#               N     V AUX PRO OTHER FLDPS BPN BPP
# Baure      2454  4020  NA  NA    NA    NA  NA  NA
# Bora       5566  7906  NA  NA    NA    NA  NA  NA
# Chintang   4969  7378  NA  NA    NA    NA  NA  NA
# Dutch      3863  6301  NA  NA    NA    NA  NA  NA
# English    7521 10773  NA  NA    NA    NA  NA  NA
# Even       7948  9181  NA  NA    NA    NA  NA  NA
# Hoocąk     3091  6058  NA  NA    NA    NA  NA  NA
# Nǁng       3296  6334  NA  NA    NA    NA  NA  NA
# Texistepec 2386  5209  NA  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP
# 41094 63160     0     0     0     0     0     0

# Eliminate words with a pre-word window of length 0 seconds
# (which can happen if the word before the target word is longer than one second and its midpoint thus occurs before the target
# pre-word window length of 0.5 seconds)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6364    13316    12283    10147    18282    17017     8825     9619       7586

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 103439

# By word class
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#               N     V AUX PRO OTHER FLDPS BPN BPP
# Baure      2427  3937  NA  NA    NA    NA  NA  NA
# Bora       5507  7809  NA  NA    NA    NA  NA  NA
# Chintang   4942  7341  NA  NA    NA    NA  NA  NA
# Dutch      3853  6294  NA  NA    NA    NA  NA  NA
# English    7516 10766  NA  NA    NA    NA  NA  NA
# Even       7892  9125  NA  NA    NA    NA  NA  NA
# Hoocąk     2968  5857  NA  NA    NA    NA  NA  NA
# Nǁng       3290  6329  NA  NA    NA    NA  NA  NA
# Texistepec 2382  5204  NA  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP
# 40777 62662     0     0     0     0     0     0

# Throw out empty pre-word windows (containing only silence, excluded from study of articulation rate)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  5751    10631    11462     9965    17719    14223     6412     9314       7200

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 92677

# By word class
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#               N     V AUX PRO OTHER FLDPS BPN BPP
# Baure      2167  3584  NA  NA    NA    NA  NA  NA
# Bora       4105  6526  NA  NA    NA    NA  NA  NA
# Chintang   4464  6998  NA  NA    NA    NA  NA  NA
# Dutch      3768  6197  NA  NA    NA    NA  NA  NA
# English    7246 10473  NA  NA    NA    NA  NA  NA
# Even       6137  8086  NA  NA    NA    NA  NA  NA
# Hoocąk     1767  4645  NA  NA    NA    NA  NA  NA
# Nǁng       3128  6186  NA  NA    NA    NA  NA  NA
# Texistepec 2154  5046  NA  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP
# 34936 57741     0     0     0     0     0     0

# Throw out pre-word windows containing disfluencies (filled pauses, such as "uhm", and false starts)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0 & filled_pauses_in_pre_word_window == 0 & false_starts_in_pre_word_window == 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  5573    10396    11091     9285    17210    12897     6195     9029       7156

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0 & filled_pauses_in_pre_word_window == 0 & false_starts_in_pre_word_window == 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 88832

# By word class
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0 & filled_pauses_in_pre_word_window == 0 & false_starts_in_pre_word_window == 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#               N     V AUX PRO OTHER FLDPS BPN BPP
# Baure      2099  3474  NA  NA    NA    NA  NA  NA
# Bora       3974  6422  NA  NA    NA    NA  NA  NA
# Chintang   4279  6812  NA  NA    NA    NA  NA  NA
# Dutch      3466  5819  NA  NA    NA    NA  NA  NA
# English    7029 10181  NA  NA    NA    NA  NA  NA
# Even       5342  7555  NA  NA    NA    NA  NA  NA
# Hoocąk     1646  4549  NA  NA    NA    NA  NA  NA
# Nǁng       2993  6036  NA  NA    NA    NA  NA  NA
# Texistepec 2136  5020  NA  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0 & filled_pauses_in_pre_word_window == 0 & false_starts_in_pre_word_window == 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP
# 32964 55868     0     0     0     0     0     0

# Check numbers in reduced data set
with(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,by(word_id,language,length))[]
# language
#    Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
#     5573    10396    11091     9285    17210    12897     6195     9029       7156

# By word class
with(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,by(word_id,list(language,word_class_relevant),length))[]
#               N     V
# Baure      2099  3474
# Bora       3974  6422
# Chintang   4279  6812
# Dutch      3466  5819
# English    7029 10181
# Even       5342  7555
# Hoocąk     1646  4549
# Nǁng       2993  6036
# Texistepec 2136  5020

# Reduction
100 - (with(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,by(word_id,language,function(x) length(unique(x))))[] * 100 / with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_no_aux %in% c("N","V") & !grepl("AUX", whole_word_word_class_all)),by(word_id,language,function (x) length(unique(x))))[])
# language
#     Baure      Bora  Chintang     Dutch   English      Even    Hoocąk      Nǁng  Texistepec
# 29.607174 26.690642 27.334076 12.898687  7.854581 29.823702 37.763713 24.004713   19.287164

# All languages
100 - (sum(with(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,by(word_id,language,function(x) length(unique(x))))) * 100 / sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_no_aux %in% c("N","V") & !grepl("AUX", whole_word_word_class_all)),by(word_id,language,function (x) length(unique(x))))))
# [1] 23.27319

# By word class
100 - (with(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,by(word_id,list(language,word_class_relevant),function(x) length(unique(x))))[] * 100 / with(droplevels(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_no_aux %in% c("N","V") & !grepl("AUX", whole_word_word_class_all))),by(word_id,list(language,word_class_relevant),function (x) length(unique(x))))[])
#                    N         V
# Baure      24.442045 33.358910
# Bora       32.792153 22.336437
# Chintang   35.235356 21.330408
# Dutch      12.761138 12.980410
# English     9.618105  6.622031
# Even       39.535937 20.832023
# Hoocąk     55.149864 29.110176
# Nǁng       32.208381 19.153496
# Texistepec 21.986852 19.948971

# All languages
100 - (colSums(with(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,by(word_id,list(language,word_class_relevant),function(x) length(unique(x)))),na.rm=T) * 100 / colSums(with(droplevels(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_no_aux %in% c("N","V") & !grepl("AUX", whole_word_word_class_all))),by(word_id,list(language,word_class_relevant),function (x) length(unique(x)))),na.rm=T))
#        N        V
# 29.42234 19.53102


## --- Relevant data set for alternative study including auxiliaries (AUX)

# Only keep N, V and AUX
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  7917    14181    15263    10660    20551    19003    11504    11881    10916

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 121876

# By word class (not distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V PRO OTHER FLDPS BPN BPP
# Baure    2778  5213  NA    NA    NA  NA  NA
# Bora     5913  8269  NA    NA    NA  NA  NA
# Chintang 6607  8659  NA    NA    NA  NA  NA
# Dutch    3973  6687  NA    NA    NA  NA  NA
# English  7777 12777  NA    NA    NA  NA  NA
# Even     8835 10168  NA    NA    NA  NA  NA
# Hoocąk   3683  7967  NA    NA    NA  NA  NA
# Nǁng     4415  7466  NA    NA    NA  NA  NA
# Texistepec 2738  8321  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   PRO OTHER FLDPS   BPN   BPP
# 46719 75527     0     0     0     0     0

# By word class (distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX PRO OTHER FLDPS BPN BPP
# Baure    2778  5213   NA  NA    NA    NA  NA  NA
# Bora     5913  8269   NA  NA    NA    NA  NA  NA
# Chintang 6607  8659   NA  NA    NA    NA  NA  NA
# Dutch    3973  6687   NA  NA    NA    NA  NA  NA
# English  7777 10903 1874  NA    NA    NA  NA  NA
# Even     8835  9543  625  NA    NA    NA  NA  NA
# Hoocąk   3683  6903 1550  NA    NA    NA  NA  NA
# Nǁng     4415  7466   NA  NA    NA    NA  NA  NA
# Texistepec 2738  6272 2050  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP
# 46719 69915  6099     0     0     0     0     0

# Exclude pre-word windows that include multiple different roots at the same time
ambiguous.words = with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),intersect(word_id[word_class_relevant_aux=="N"],word_id[word_class_relevant_aux=="V"]))

with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  7843    14180    15260    10660    20548    19003    11358    11881    10773

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 121506

# By word class (not distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V PRO OTHER FLDPS BPN BPP
# Baure    2704  5139  NA    NA    NA  NA  NA
# Bora     5912  8268  NA    NA    NA  NA  NA
# Chintang 6604  8656  NA    NA    NA  NA  NA
# Dutch    3973  6687  NA    NA    NA  NA  NA
# English  7774 12774  NA    NA    NA  NA  NA
# Even     8835 10168  NA    NA    NA  NA  NA
# Hoocąk   3537  7821  NA    NA    NA  NA  NA
# Nǁng     4415  7466  NA    NA    NA  NA  NA
# Texistepec 2595  8178  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   PRO OTHER FLDPS   BPN   BPP
# 46349 75157     0     0     0     0     0

# By word class (distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX PRO OTHER FLDPS BPN BPP
# Baure    2704  5139   NA  NA    NA    NA  NA  NA
# Bora     5912  8268   NA  NA    NA    NA  NA  NA
# Chintang 6604  8656   NA  NA    NA    NA  NA  NA
# Dutch    3973  6687   NA  NA    NA    NA  NA  NA
# English  7774 10900 1874  NA    NA    NA  NA  NA
# Even     8835  9543  625  NA    NA    NA  NA  NA
# Hoocąk   3537  6770 1537  NA    NA    NA  NA  NA
# Nǁng     4415  7466   NA  NA    NA    NA  NA  NA
# Texistepec 2595  6129 2050  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP
# 46349 69558  6086     0     0     0     0     0

# Excluding words without a pre-word window (first words in annotation units)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6474    13476    12364    10164    20185    17788    10647     9724     8959

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 109781

# By word class (not distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V PRO OTHER FLDPS BPN BPP
# Baure    2454  4020  NA    NA    NA  NA  NA
# Bora     5566  7910  NA    NA    NA  NA  NA
# Chintang 4985  7379  NA    NA    NA  NA  NA
# Dutch    3863  6301  NA    NA    NA  NA  NA
# English  7542 12643  NA    NA    NA  NA  NA
# Even     7980  9808  NA    NA    NA  NA  NA
# Hoocąk   3091  7556  NA    NA    NA  NA  NA
# Nǁng     3336  6388  NA    NA    NA  NA  NA
# Texistepec 2393  6566  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   PRO OTHER FLDPS   BPN   BPP
# 41210 68571     0     0     0     0     0

# By word class (distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX PRO OTHER FLDPS BPN BPP
# Baure    2454  4020   NA  NA    NA    NA  NA  NA
# Bora     5566  7910   NA  NA    NA    NA  NA  NA
# Chintang 4985  7379   NA  NA    NA    NA  NA  NA
# Dutch    3863  6301   NA  NA    NA    NA  NA  NA
# English  7542 10773 1870  NA    NA    NA  NA  NA
# Even     7980  9235  573  NA    NA    NA  NA  NA
# Hoocąk   3091  6531 1498  NA    NA    NA  NA  NA
# Nǁng     3336  6388   NA  NA    NA    NA  NA  NA
# Texistepec 2393  5211 1356  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP
# 41210 63748  5297     0     0     0     0     0

# Eliminate words with missing word frequency information
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6474    13476    12364    10164    20185    17788    10647     9722     8959

# Only happens in Nǁng! Only occurs with (acoustically) doubtful words or false starts (count as disfluencies for paper!)

# Throw out words with missing word frequency information
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 109779

# By word class (not distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V PRO OTHER FLDPS BPN BPP
# Baure    2454  4020  NA    NA    NA  NA  NA
# Bora     5566  7910  NA    NA    NA  NA  NA
# Chintang 4985  7379  NA    NA    NA  NA  NA
# Dutch    3863  6301  NA    NA    NA  NA  NA
# English  7542 12643  NA    NA    NA  NA  NA
# Even     7980  9808  NA    NA    NA  NA  NA
# Hoocąk   3091  7556  NA    NA    NA  NA  NA
# Nǁng     3336  6386  NA    NA    NA  NA  NA
# Texistepec 2393  6566  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   PRO OTHER FLDPS   BPN   BPP
# 41210 68569     0     0     0     0     0

# By word class (distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX PRO OTHER FLDPS BPN BPP
# Baure    2454  4020   NA  NA    NA    NA  NA  NA
# Bora     5566  7910   NA  NA    NA    NA  NA  NA
# Chintang 4985  7379   NA  NA    NA    NA  NA  NA
# Dutch    3863  6301   NA  NA    NA    NA  NA  NA
# English  7542 10773 1870  NA    NA    NA  NA  NA
# Even     7980  9235  573  NA    NA    NA  NA  NA
# Hoocąk   3091  6531 1498  NA    NA    NA  NA  NA
# Nǁng     3336  6386   NA  NA    NA    NA  NA  NA
# Texistepec 2393  5211 1356  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 41210 63746  5297     0     0     0     0     0 

# Throw out pre-word windows before filled pauses and false starts
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6474    13472    12347    10164    20161    17700    10647     9630     8948

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 109543

# By word class (not distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V PRO OTHER FLDPS BPN BPP
# Baure    2454  4020  NA    NA    NA  NA  NA
# Bora     5566  7906  NA    NA    NA  NA  NA
# Chintang 4969  7378  NA    NA    NA  NA  NA
# Dutch    3863  6301  NA    NA    NA  NA  NA
# English  7521 12640  NA    NA    NA  NA  NA
# Even     7948  9752  NA    NA    NA  NA  NA
# Hoocąk   3091  7556  NA    NA    NA  NA  NA
# Nǁng     3296  6334  NA    NA    NA  NA  NA
# Texistepec 2386  6562  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   PRO OTHER FLDPS   BPN   BPP 
# 41094 68449     0     0     0     0     0 

# By word class (distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX PRO OTHER FLDPS BPN BPP
# Baure    2454  4020   NA  NA    NA    NA  NA  NA
# Bora     5566  7906   NA  NA    NA    NA  NA  NA
# Chintang 4969  7378   NA  NA    NA    NA  NA  NA
# Dutch    3863  6301   NA  NA    NA    NA  NA  NA
# English  7521 10773 1867  NA    NA    NA  NA  NA
# Even     7948  9181  571  NA    NA    NA  NA  NA
# Hoocąk   3091  6531 1498  NA    NA    NA  NA  NA
# Nǁng     3296  6334   NA  NA    NA    NA  NA  NA
# Texistepec 2386  5210 1353  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 41094 63634  5289     0     0     0     0     0 

# Eliminate words with a pre-word window of length 0 seconds
# (which can happen if the word before the target word is longer than one second and its midpoint thus occurs before the target
# pre-word window length of 0.5 seconds)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6364    13316    12283    10147    20149    17588    10263     9619     8939

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 108668

# By word class (not distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V PRO OTHER FLDPS BPN BPP
# Baure    2427  3937  NA    NA    NA  NA  NA
# Bora     5507  7809  NA    NA    NA  NA  NA
# Chintang 4942  7341  NA    NA    NA  NA  NA
# Dutch    3853  6294  NA    NA    NA  NA  NA
# English  7516 12633  NA    NA    NA  NA  NA
# Even     7892  9696  NA    NA    NA  NA  NA
# Hoocąk   2968  7295  NA    NA    NA  NA  NA
# Nǁng     3290  6329  NA    NA    NA  NA  NA
# Texistepec 2382  6557  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   PRO OTHER FLDPS   BPN   BPP 
# 40777 67891     0     0     0     0     0 

# By word class (distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX PRO OTHER FLDPS BPN BPP
# Baure    2427  3937   NA  NA    NA    NA  NA  NA
# Bora     5507  7809   NA  NA    NA    NA  NA  NA
# Chintang 4942  7341   NA  NA    NA    NA  NA  NA
# Dutch    3853  6294   NA  NA    NA    NA  NA  NA
# English  7516 10766 1867  NA    NA    NA  NA  NA
# Even     7892  9125  571  NA    NA    NA  NA  NA
# Hoocąk   2968  6314 1438  NA    NA    NA  NA  NA
# Nǁng     3290  6329   NA  NA    NA    NA  NA  NA
# Texistepec 2382  5205 1353  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 40777 63120  5229     0     0     0     0     0 

# Throw out empty pre-word windows (containing only silence, excluded for study of articulation rate)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  5751    10631    11462     9965    19566    14741     7646     9314     8453

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 97529

# By word class (not distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V PRO OTHER FLDPS BPN BPP
# Baure    2167  3584  NA    NA    NA  NA  NA
# Bora     4105  6526  NA    NA    NA  NA  NA
# Chintang 4464  6998  NA    NA    NA  NA  NA
# Dutch    3768  6197  NA    NA    NA  NA  NA
# English  7246 12320  NA    NA    NA  NA  NA
# Even     6137  8604  NA    NA    NA  NA  NA
# Hoocąk   1767  5879  NA    NA    NA  NA  NA
# Nǁng     3128  6186  NA    NA    NA  NA  NA
# Texistepec 2154  6299  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   PRO OTHER FLDPS   BPN   BPP 
# 34936 62593     0     0     0     0     0 

# By word class (distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX PRO OTHER FLDPS BPN BPP
# Baure    2167  3584   NA  NA    NA    NA  NA  NA
# Bora     4105  6526   NA  NA    NA    NA  NA  NA
# Chintang 4464  6998   NA  NA    NA    NA  NA  NA
# Dutch    3768  6197   NA  NA    NA    NA  NA  NA
# English  7246 10473 1847  NA    NA    NA  NA  NA
# Even     6137  8086  518  NA    NA    NA  NA  NA
# Hoocąk   1767  5034 1234  NA    NA    NA  NA  NA
# Nǁng     3128  6186   NA  NA    NA    NA  NA  NA
# Texistepec 2154  5047 1253  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 34936 58131  4852     0     0     0     0     0 

# Throw out pre-word windows containing disfluencies (filled pauses, such as "uhm", or false starts)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0 & filled_pauses_in_pre_word_window == 0 & false_starts_in_pre_word_window == 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  5573    10396    11091     9285    19027    13379     7413     9029     8395

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0 & filled_pauses_in_pre_word_window == 0 & false_starts_in_pre_word_window == 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 93588

# By word class (not distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0 & filled_pauses_in_pre_word_window == 0 & false_starts_in_pre_word_window == 0),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V PRO OTHER FLDPS BPN BPP
# Baure    2099  3474  NA    NA    NA  NA  NA
# Bora     3974  6422  NA    NA    NA  NA  NA
# Chintang 4279  6812  NA    NA    NA  NA  NA
# Dutch    3466  5819  NA    NA    NA  NA  NA
# English  7029 11998  NA    NA    NA  NA  NA
# Even     5342  8037  NA    NA    NA  NA  NA
# Hoocąk   1646  5767  NA    NA    NA  NA  NA
# Nǁng     2993  6036  NA    NA    NA  NA  NA
# Texistepec 2136  6259  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0 & filled_pauses_in_pre_word_window == 0 & false_starts_in_pre_word_window == 0),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   PRO OTHER FLDPS   BPN   BPP 
# 32964 60624     0     0     0     0     0 

# By word class (distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0 & filled_pauses_in_pre_word_window == 0 & false_starts_in_pre_word_window == 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX PRO OTHER FLDPS BPN BPP
# Baure    2099  3474   NA  NA    NA    NA  NA  NA
# Bora     3974  6422   NA  NA    NA    NA  NA  NA
# Chintang 4279  6812   NA  NA    NA    NA  NA  NA
# Dutch    3466  5819   NA  NA    NA    NA  NA  NA
# English  7029 10181 1817  NA    NA    NA  NA  NA
# Even     5342  7555  482  NA    NA    NA  NA  NA
# Hoocąk   1646  4926 1218  NA    NA    NA  NA  NA
# Nǁng     2993  6036   NA  NA    NA    NA  NA  NA
# Texistepec 2136  5021 1239  NA    NA    NA  NA  NA

# All languages
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0 & pre_word_window_length_characters > 0 & filled_pauses_in_pre_word_window == 0 & false_starts_in_pre_word_window == 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 32964 56246  4756     0     0     0     0     0 

# Check numbers in reduced data set (not distinguishing auxiliaries, AUX)
with(combined.wordtimes.prewindows.publish.articulation_rate.aux,by(word_id,language,length))[]
# language
#    Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
#     5573    10396    11091     9285    19027    13379     7413     9029     8395

# By word class (not distinguishing auxiliaries, AUX)
with(combined.wordtimes.prewindows.publish.articulation_rate.aux,by(word_id,list(language,word_class_relevant_aux),length))[]
#             N     V
# Baure    2099  3474
# Bora     3974  6422
# Chintang 4279  6812
# Dutch    3466  5819
# English  7029 11998
# Even     5342  8037
# Hoocąk   1646  5767
# Nǁng     2993  6036
# Texistepec 2136  6259

# All languages
colSums(with(combined.wordtimes.prewindows.publish.articulation_rate.aux,by(word_id,list(language,word_class_relevant_aux),length))[],na.rm=T)
#     N     V 
# 32964 60624 

# By word class (distinguishing auxiliaries, AUX)
with(combined.wordtimes.prewindows.publish.articulation_rate.aux,by(word_id,list(language,word_class_relevant),length))[]
#             N     V  AUX
# Baure    2099  3474   NA
# Bora     3974  6422   NA
# Chintang 4279  6812   NA
# Dutch    3466  5819   NA
# English  7029 10181 1817
# Even     5342  7555  482
# Hoocąk   1646  4926  841
# Nǁng     2993  6036   NA
# Texistepec 2136  5021 1238

# All languages
colSums(with(combined.wordtimes.prewindows.publish.articulation_rate.aux,by(word_id,list(language,word_class_relevant),length))[],na.rm=T)
#     N     V   AUX 
# 32964 56246  4378 

# Reduction
100 - (with(combined.wordtimes.prewindows.publish.articulation_rate.aux,by(word_id,language,function(x) length(unique(x))))[] * 100 / with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_aux %in% c("N","V")),by(word_id,language,function (x) length(unique(x))))[])
# language
#     Baure      Bora  Chintang     Dutch   English      Even    Hoocąk      Nǁng  Texistepec
# 29.607174 26.690642 27.334076 12.898687  7.415698 29.595327 35.561544 24.004713 23.094540

# All languages
100 - (sum(with(combined.wordtimes.prewindows.publish.articulation_rate.aux,by(word_id,language,function(x) length(unique(x))))) * 100 / sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_aux %in% c("N","V")),by(word_id,language,function (x) length(unique(x))))))
# [1] 23.21048

# By word class (not distinguishing auxiliaries, AUX)
100 - (with(combined.wordtimes.prewindows.publish.articulation_rate.aux,by(word_id,list(language,word_class_relevant_aux),function(x) length(unique(x))))[] * 100 / with(droplevels(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_aux %in% c("N","V"))),by(word_id,list(language,word_class_relevant_aux),function (x) length(unique(x))))[])
#                  N         V
# Baure    24.442045 33.358910
# Bora     32.792153 22.336437
# Chintang 35.235356 21.330408
# Dutch    12.761138 12.980410
# English   9.618105  6.096893
# Even     39.535937 20.957907
# Hoocąk   55.308173 27.613907
# Nǁng     32.208381 19.153496
# Texistepec 21.986852 24.780675

# All languages
100 - (colSums(with(combined.wordtimes.prewindows.publish.articulation_rate.aux,by(word_id,list(language,word_class_relevant_aux),function(x) length(unique(x)))),na.rm=T) * 100 / colSums(with(droplevels(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_aux %in% c("N","V"))),by(word_id,list(language,word_class_relevant_aux),function (x) length(unique(x)))),na.rm=T))
#        N        V 
# 29.44198 19.73202 

# By word class (distinguishing auxiliaries, AUX)
100 - (with(combined.wordtimes.prewindows.publish.articulation_rate.aux,by(word_id,list(language,word_class_relevant),function(x) length(unique(x))))[] * 100 / with(droplevels(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_aux %in% c("N","V"))),by(word_id,list(language,word_class_relevant),function (x) length(unique(x))))[])
#                  N         V       AUX
# Baure    24.442045 33.358910        NA
# Bora     32.792153 22.336437        NA
# Chintang 35.235356 21.330408        NA
# Dutch    12.761138 12.980410        NA
# English   9.618105  6.622031  3.041622
# Even     39.535937 20.832023 22.880000
# Hoocąk   55.308173 28.639722 45.741935    # corrected to: 20.958647
# Nǁng     32.208381 19.153496        NA
# Texistepec 21.986852 19.945791 39.609756  # corrected to: 39.580283

# AUX percentages for Hoocąk and Texistepec needed to be corrected because of words containing AUX and V roots at the same time
# which were only included as V in the reduced data set (combined.wordtimes.prewindows.publish.articulation_rate.aux) but are still included
# with both roots in the original data set (combined.wordtimes.prewindows.publish)

# All languages
100 - (colSums(with(combined.wordtimes.prewindows.publish.articulation_rate.aux,by(word_id,list(language,word_class_relevant),function(x) length(unique(x)))),na.rm=T) * 100 / colSums(with(droplevels(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_aux %in% c("N","V"))),by(word_id,list(language,word_class_relevant),function (x) length(unique(x)))),na.rm=T))
#        N        V      AUX 
# 29.44198 19.55088 28.21774 # corrected to: 21.988596

# AUX percentages needed to be corrected because of words containing AUX and V roots at the same time
# which were only included as V in the reduced data set (combined.wordtimes.prewindows.publish.articulation_rate.aux)
# but are still included with both roots in the original data set (combined.wordtimes.prewindows.publish)


## --- Statistics for main study excluding auxiliaries (AUX)

# Overall number of relevant pre-word windows examined (of categories N or V excluding AUX)
length(unique(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_id))
# [1] 88832

# Distribution of examined pre-word windows by language
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_id,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code,FUN=length))
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code
#   boa   brg   ctn   eng   eve   ngh   nld   poq   win 
# 10396  5573 11091 17210 12897  9029  9285  7156  6195 

# Distribution of examined pre-word windows by part-of-speech of target word
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_id,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux,FUN=length))
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux
#     N     V 
# 32964 55868 

# Distribution of examined pre-word windows by part-of-speech of target word (percentages)
prop.table(as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_id,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux,FUN=length)))*100
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux
#        N        V 
# 37.10825 62.89175 

# Distribution of examined pre-word windows by language and part-of-speech of target word
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_id,list(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux),FUN=length))
#         N     V
# boa  3974  6422
# brg  2099  3474
# ctn  4279  6812
# eng  7029 10181
# eve  5342  7555
# ngh  2993  6036
# nld  3466  5819
# poq  2136  5020
# win  1646  4549

# Distribution of examined pre-word windows by language and part-of-speech of target word (percentages)
prop.table(as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_id,list(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux),FUN=length)),1)*100
#            N        V
# boa 38.22624 61.77376
# brg 37.66374 62.33626
# ctn 38.58083 61.41917
# eng 40.84253 59.15747
# eve 41.42049 58.57951
# ngh 33.14874 66.85126
# nld 37.32903 62.67097
# poq 29.84908 70.15092
# win 26.56981 73.43019

# Summary of raw articulation rate
summary(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate)
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 1.165  12.821  16.327  17.167  20.474 129.032 

sd(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate)
# [1] 6.574954

# Mean articulation rate per language
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code,FUN=mean))
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code
#      boa      brg      ctn      eng      eve      ngh      nld      poq      win 
# 17.21410 13.91456 17.30936 19.00823 14.87612 16.23419 20.84983 19.21853 12.87698 

# Standard deviation of articulation rate per language
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code,FUN=sd))
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code
#      boa      brg      ctn      eng      eve      ngh      nld      poq      win 
# 6.129984 4.861641 6.360406 7.348992 3.819777 6.421582 7.251643 6.601628 4.330531 

# Median articulation rate per language
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code,FUN=median))
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code
#      boa      brg      ctn      eng      eve      ngh      nld      poq      win 
# 16.27907 13.51351 17.07317 18.42105 14.82702 15.38462 20.03643 18.43318 12.44813 

# Minimum articulation rate per language
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code,FUN=min))
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code
#      boa      brg      ctn      eng      eve      ngh      nld      poq      win 
# 1.721170 2.197802 1.165501 1.453488 2.347418 2.551020 1.980198 3.735990 2.484472 

# Maximum articulation rate per language
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code,FUN=max))
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code
#       boa       brg       ctn       eng       eve       ngh       nld       poq       win 
# 108.69565  55.55556 104.65116  85.10638  37.63441  80.00000 129.03226  93.75000  82.08955 

# Mean articulation rate per part-of-speech
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux,FUN=mean))
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux
#        N        V 
# 16.85858 17.34829 

# Standard deviation of articulation rate per part-of-speech
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux,FUN=sd))
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux
#        N        V 
# 6.142068 6.811014 

# Median
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux,FUN=median))
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux
#        N        V 
# 16.21622 16.39344 

# Mean articulation rate by language and part-of-speech of target word
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate,list(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux),FUN=mean))
#            N        V
# boa 17.01844 17.33518
# brg 13.60156 14.10368
# ctn 16.49568 17.82048
# eng 18.76923 19.17324
# eve 14.50810 15.13634
# ngh 16.24058 16.23102
# nld 20.78932 20.88588
# poq 18.15111 19.67272
# win 12.20812 13.11900

# Standard deviation of articulation rate by language and part-of-speech of target word
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate,list(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux),FUN=sd))
#            N        V
# boa 5.876537 6.279099
# brg 4.527633 5.043991
# ctn 6.583600 6.161889
# eng 6.275566 8.002686
# eve 4.072893 3.607855
# ngh 5.889747 6.670056
# nld 6.374002 7.727478
# poq 5.694295 6.902516
# win 4.032862 4.408807

as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate,list(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language_iso_code,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux),FUN=median))
#            N        V
# boa 16.12903 16.39344
# brg 13.38432 13.63636
# ctn 16.12903 17.64706
# eng 18.40491 18.46154
# eve 14.45435 15.07538
# ngh 15.62500 15.38462
# nld 20.27027 19.84127
# poq 17.74194 18.75000
# win 11.97605 12.55230


## --- Statistics for alternative study including auxiliaries (AUX)

# Overall number of relevant pre-word windows examined (of categories N or V including AUX)
length(unique(combined.wordtimes.prewindows.publish.articulation_rate.aux$word_id))
# [1] 93588

# Distribution of examined pre-word windows by language
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$word_id,combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code,FUN=length))
# combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code
#   boa   brg   ctn   eng   eve   ngh   nld   poq   win 
# 10396  5573 11091 19027 13379  9029  9285  8395  7413 

# Distribution of examined pre-word windows by part-of-speech of target word
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$word_id,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux,FUN=length))
# combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux
#     N     V 
# 32964 60624 

# Distribution of examined pre-word windows by part-of-speech of target word (percentages)
prop.table(as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$word_id,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux,FUN=length)))*100
# combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux
#        N        V 
# 35.22246 64.77754 

# Distribution of examined pre-word windows by part-of-speech of target word (AUX separately)
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$word_id,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant,FUN=length))
# combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant
#     N     V   AUX 
# 32964 56246  4378 

# Distribution of examined pre-word windows by part-of-speech of target word (percentages) (AUX separately)
prop.table(as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$word_id,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant,FUN=length)))*100
# combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant
#        N        V      AUX 
# 35.22246 60.09959  4.67795 

# Summary of raw articulation rate
summary(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate)
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 1.165  12.821  16.327  17.173  20.513 129.032 

sd(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate)
# [1] 6.592026

min(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate)
# [1] 1.165501

max(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate)
# [1] 129.0323

# Mean articulation rate per language
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code,FUN=mean))
# combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code
#      boa      brg      ctn      eng      eve      ngh      nld      poq      win 
# 17.21410 13.91456 17.30936 19.03949 14.91928 16.23419 20.84983 19.18358 12.89774 

# Standard deviation of articulation rate per language
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code,FUN=sd))
# combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code
#      boa      brg      ctn      eng      eve      ngh      nld      poq      win 
# 6.129984 4.861641 6.360406 7.376106 3.831354 6.421582 7.251643 6.675026 4.240489 

# Median articulation rate per language
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code,FUN=median))
# combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code
#      boa      brg      ctn      eng      eve      ngh      nld      poq      win 
# 16.27907 13.51351 17.07317 18.45638 14.89362 15.38462 20.03643 18.42105 12.50000 

# Minimum articulation rate per language
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code,FUN=min))
# combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code
#      boa      brg      ctn      eng      eve      ngh      nld      poq      win 
# 1.721170 2.197802 1.165501 1.453488 2.347418 2.551020 1.980198 3.025719 2.484472 

# Maximum articulation rate per language
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code,FUN=max))
# combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code
#       boa       brg       ctn       eng       eve       ngh       nld       poq       win 
# 108.69565  55.55556 104.65116  85.10638  37.63441  80.00000 129.03226  93.75000  82.08955 

# Mean articulation rate per part-of-speech
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux,FUN=mean))
# combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux
#        N        V 
# 16.85858 17.34381 

# Standard deviation of articulation rate per part-of-speech
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux,FUN=sd))
# combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux
#        N        V 
# 6.142068 6.818219 

# Median articulation rate per part-of-speech
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux,FUN=median))
# combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux
#        N        V 
# 16.21622 16.39344 

# Mean articulation rate per part-of-speech (AUX separately)
# Note: Table S7 in the supplement wrongly states a mean articulation rate for auxiliaries
#       of 18.65 characters / second, when it is actually 17.65 characters / second
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant,FUN=mean))
# combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant
#        N        V      AUX 
# 16.85858 17.31985 17.65165 

# Standard deviation of articulation rate per part-of-speech (AUX separately)
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant,FUN=sd))
# combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant
#        N        V      AUX 
# 6.142068 6.804463 6.986028 

# Median articulation rate per part-of-speech (AUX separately)
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant,FUN=median))
# combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant
#        N        V      AUX 
# 16.21622 16.39344 16.66667 

# Mean articulation rate by language and part-of-speech of target word
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,list(combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux),FUN=mean))
#            N        V
# boa 17.01844 17.33518
# brg 13.60156 14.10368
# ctn 16.49568 17.82048
# eng 18.76923 19.19782
# eve 14.50810 15.19259
# ngh 16.24058 16.23102
# nld 20.78932 20.88588
# poq 18.15111 19.53592
# win 12.20812 13.09457

# Standard deviation of articulation rate by language and part-of-speech of target word
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,list(combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux),FUN=sd))
#            N        V
# boa 5.876537 6.279099
# brg 4.527633 5.043991
# ctn 6.583600 6.161889
# eng 6.275566 7.946383
# eve 4.072893 3.636631
# ngh 5.889747 6.670056
# nld 6.374002 7.727478
# poq 5.694295 6.943610
# win 4.032862 4.277899

# Median articulation rate by language and part-of-speech of target word
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,list(combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux),FUN=median))
#            N        V
# boa 16.12903 16.39344
# brg 13.38432 13.63636
# ctn 16.12903 17.64706
# eng 18.40491 18.51852
# eve 14.45435 15.11879
# ngh 15.62500 15.38462
# nld 20.27027 19.84127
# poq 17.74194 18.64407
# win 11.97605 12.58741

# Mean articulation rate by language and part-of-speech of target word (AUX separately)
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,list(combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant),FUN=mean))
#            N        V      AUX
# boa 17.01844 17.33518         
# brg 13.60156 14.10368         
# ctn 16.49568 17.82048         
# eng 18.76923 19.17324 19.33557
# eve 14.50810 15.13634 16.07412
# ngh 16.24058 16.23102         
# nld 20.78932 20.88588         
# poq 18.15111 19.67256 18.98176
# win 12.20812 13.11761 12.95963

# Standard deviation of articulation rate by language and part-of-speech of target word (AUX separately)
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,list(combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant),FUN=sd))
#            N        V      AUX
# boa 5.876537 6.279099         
# brg 4.527633 5.043991         
# ctn 6.583600 6.161889         
# eng 6.275566 8.002686 7.623879
# eve 4.072893 3.607855 3.962086
# ngh 5.889747 6.670056         
# nld 6.374002 7.727478         
# poq 5.694295 6.901838 7.086369
# win 4.032862 4.372558 3.674221

# Median articulation rate by language and part-of-speech of target word (AUX separately)
as.table(by(combined.wordtimes.prewindows.publish.articulation_rate.aux$pre_word_window_articulation_rate,list(combined.wordtimes.prewindows.publish.articulation_rate.aux$language_iso_code,combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant),FUN=median))
#            N        V      AUX
# boa 16.12903 16.39344         
# brg 13.38432 13.63636         
# ctn 16.12903 17.64706         
# eng 18.40491 18.46154 18.67816
# eve 14.45435 15.07538 16.00712
# ngh 15.62500 15.38462         
# nld 20.27027 19.84127         
# poq 17.74194 18.75000 18.18182
# win 11.97605 12.56732 12.72265


### Multivariate modeling

## Upward selection process ##

## Main study excluding auxiliaries (AUX)
prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F)

# Try adding word_length_characters_normalized
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL2:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# MODEL2:     (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL1:     word_length_characters_normalized + word_class_relevant_no_aux * 
# MODEL1:     language_iso_code + (1 | speaker) + (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)    
# MODEL2 22 567374 567580 -283665   567330                             
# MODEL1 23 567294 567510 -283624   567248 81.641      1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Try adding word_position_normalized
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_position_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL2:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# MODEL2:     (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL1:     word_position_normalized + word_class_relevant_no_aux * language_iso_code + 
# MODEL1:     (1 | speaker) + (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)   
# MODEL2 22 567374 567580 -283665   567330                            
# MODEL1 23 567366 567582 -283660   567320 9.9446      1   0.001613 **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Thus add word_length_characters_normalized
prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F)

# Try adding word_position_normalized
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL2:     word_length_characters_normalized + word_class_relevant_no_aux * 
# MODEL2:     language_iso_code + (1 | speaker) + (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL1:     word_length_characters_normalized + word_position_normalized + 
# MODEL1:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# MODEL1:     (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)    
# MODEL2 23 567294 567510 -283624   567248                             
# MODEL1 24 567282 567508 -283617   567234 13.933      1  0.0001894 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Try adding interaction of word class and word length
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_length_characters_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL2:     word_length_characters_normalized + word_class_relevant_no_aux * 
# MODEL2:     language_iso_code + (1 | speaker) + (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# MODEL1:     word_length_characters_normalized + word_class_relevant_no_aux * 
# MODEL1:     language_iso_code + (1 | speaker) + (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)
# MODEL2 23 567294 567510 -283624   567248                         
# MODEL1 24 567295 567521 -283624   567247 0.5121      1     0.4742

# Thus add word_position_normalized
prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F)

# Try adding interaction of word class and word length
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_length_characters_normalized + word_position_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL2:     word_length_characters_normalized + word_position_normalized + 
# MODEL2:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# MODEL2:     (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# MODEL1:     word_length_characters_normalized + word_position_normalized + 
# MODEL1:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# MODEL1:     (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)
# MODEL2 24 567282 567508 -283617   567234                         
# MODEL1 25 567283 567518 -283617   567233 0.6741      1     0.4116

# Try adding interaction of word class and word position
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + word_class_relevant_no_aux * word_position_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL2:     word_length_characters_normalized + word_position_normalized + 
# MODEL2:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# MODEL2:     (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL1:     word_length_characters_normalized + word_class_relevant_no_aux * 
# MODEL1:     word_position_normalized + word_class_relevant_no_aux * language_iso_code + 
# MODEL1:     (1 | speaker) + (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)   
# MODEL2 24 567282 567508 -283617   567234                            
# MODEL1 25 567277 567512 -283614   567227 6.9677      1   0.008299 **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Try adding interaction of word length and word position
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL2:     word_length_characters_normalized + word_position_normalized + 
# MODEL2:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# MODEL2:     (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL1:     word_length_characters_normalized * word_position_normalized + 
# MODEL1:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# MODEL1:     (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)  
# MODEL2 24 567282 567508 -283617   567234                           
# MODEL1 25 567279 567514 -283615   567229 4.6526      1    0.03101 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Thus add interaction of word class and word position
prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_no_aux:word_position_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F)

# Try adding interaction of word class and word length
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_length_characters_normalized + word_class_relevant_no_aux * word_position_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL2:     word_length_characters_normalized + word_position_normalized + 
# MODEL2:     word_class_relevant_no_aux:word_position_normalized + word_class_relevant_no_aux * 
# MODEL2:     language_iso_code + (1 | speaker) + (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# MODEL1:     word_length_characters_normalized + word_class_relevant_no_aux * 
# MODEL1:     word_position_normalized + word_class_relevant_no_aux * language_iso_code + 
# MODEL1:     (1 | speaker) + (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)
# MODEL2 25 567277 567512 -283614   567227                         
# MODEL1 26 567278 567522 -283613   567226 0.9122      1     0.3395

# Try adding interaction of word length and word position
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + word_class_relevant_no_aux * word_position_normalized + word_length_characters_normalized:word_position_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL2:     word_length_characters_normalized + word_position_normalized + 
# MODEL2:     word_class_relevant_no_aux:word_position_normalized + word_class_relevant_no_aux * 
# MODEL2:     language_iso_code + (1 | speaker) + (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL1:     word_length_characters_normalized + word_class_relevant_no_aux * 
# MODEL1:     word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# MODEL1:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# MODEL1:     (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)  
# MODEL2 25 567277 567512 -283614   567227                           
# MODEL1 26 567275 567519 -283611   567223 4.2851      1    0.03845 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Thus add interaction of word length and word position (final model)
prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_no_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F)

anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_no_aux:word_length_characters_normalized + word_class_relevant_no_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL2:     word_length_characters_normalized + word_position_normalized + 
# MODEL2:     word_class_relevant_no_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# MODEL2:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# MODEL2:     (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# MODEL1:     word_length_characters_normalized + word_position_normalized + 
# MODEL1:     word_class_relevant_no_aux:word_length_characters_normalized + 
# MODEL1:     word_class_relevant_no_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# MODEL1:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# MODEL1:     (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)
# MODEL2 26 567275 567519 -283611   567223                         
# MODEL1 27 567276 567530 -283611   567222 0.7861      1     0.3753


## Alternative study including auxiliaries (AUX)

# Upward selection process
prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F)

# Try adding word length
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL2:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# MODEL2:     (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL1:     word_length_characters_normalized + word_class_relevant_aux * 
# MODEL1:     language_iso_code + (1 | speaker) + (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)    
# MODEL2 22 598231 598439 -299094   598187                             
# MODEL1 23 598155 598372 -299055   598109 78.222      1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Try adding word position
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_position_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL2:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# MODEL2:     (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL1:     word_position_normalized + word_class_relevant_aux * language_iso_code + 
# MODEL1:     (1 | speaker) + (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)    
# MODEL2 22 598231 598439 -299094   598187                             
# MODEL1 23 598221 598438 -299088   598175 12.401      1  0.0004291 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Thus add word length
prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F)

# Try adding word position
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL2:     word_length_characters_normalized + word_class_relevant_aux * 
# MODEL2:     language_iso_code + (1 | speaker) + (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL1:     word_length_characters_normalized + word_position_normalized + 
# MODEL1:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# MODEL1:     (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)    
# MODEL2 23 598155 598372 -299055   598109                             
# MODEL1 24 598140 598367 -299046   598092 17.078      1  3.587e-05 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Try adding interaction of word class and word length
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_length_characters_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL2:     word_length_characters_normalized + word_class_relevant_aux * 
# MODEL2:     language_iso_code + (1 | speaker) + (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# MODEL1:     word_length_characters_normalized + word_class_relevant_aux * 
# MODEL1:     language_iso_code + (1 | speaker) + (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)
# MODEL2 23 598155 598372 -299055   598109                         
# MODEL1 24 598157 598384 -299055   598109 0.1728      1     0.6776

# Thus add word position
prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F)

# Try adding interaction of word class and word length
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_length_characters_normalized + word_position_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL2:     word_length_characters_normalized + word_position_normalized + 
# MODEL2:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# MODEL2:     (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# MODEL1:     word_length_characters_normalized + word_position_normalized + 
# MODEL1:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# MODEL1:     (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)
# MODEL2 24 598140 598367 -299046   598092                         
# MODEL1 25 598142 598378 -299046   598092 0.2965      1     0.5861

# Try adding interaction of word class and word position
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + word_class_relevant_aux * word_position_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL2:     word_length_characters_normalized + word_position_normalized + 
# MODEL2:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# MODEL2:     (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL1:     word_length_characters_normalized + word_class_relevant_aux * 
# MODEL1:     word_position_normalized + word_class_relevant_aux * language_iso_code + 
# MODEL1:     (1 | speaker) + (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)   
# MODEL2 24 598140 598367 -299046   598092                            
# MODEL1 25 598134 598370 -299042   598084 8.1387      1   0.004333 **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Try adding interaction of word length and word position
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL2:     word_length_characters_normalized + word_position_normalized + 
# MODEL2:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# MODEL2:     (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL1:     word_length_characters_normalized * word_position_normalized + 
# MODEL1:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# MODEL1:     (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)   
# MODEL2 24 598140 598367 -299046   598092                            
# MODEL1 25 598135 598371 -299042   598085 7.3994      1   0.006525 **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Thus add interaction of word class and word position
prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_aux:word_position_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F)

# Try adding interaction of word class and word length
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_length_characters_normalized + word_class_relevant_aux * word_position_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL2:     word_length_characters_normalized + word_position_normalized + 
# MODEL2:     word_class_relevant_aux:word_position_normalized + word_class_relevant_aux * 
# MODEL2:     language_iso_code + (1 | speaker) + (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# MODEL1:     word_length_characters_normalized + word_class_relevant_aux * 
# MODEL1:     word_position_normalized + word_class_relevant_aux * language_iso_code + 
# MODEL1:     (1 | speaker) + (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)
# MODEL2 25 598134 598370 -299042   598084                         
# MODEL1 26 598135 598381 -299042   598083 0.4808      1      0.488

# Try adding interaction of word length and word position
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + word_class_relevant_aux * word_position_normalized + word_length_characters_normalized:word_position_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F),prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL2:     word_length_characters_normalized + word_position_normalized + 
# MODEL2:     word_class_relevant_aux:word_position_normalized + word_class_relevant_aux * 
# MODEL2:     language_iso_code + (1 | speaker) + (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL1:     word_length_characters_normalized + word_class_relevant_aux * 
# MODEL1:     word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# MODEL1:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# MODEL1:     (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)  
# MODEL2 25 598134 598370 -299042   598084                           
# MODEL1 26 598129 598375 -299039   598077 6.5989      1     0.0102 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Thus add interaction of word length and word position
prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F)

# Try adding interaction of word class and word length
anova(lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_length_characters_normalized + word_position_normalized + word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux,REML=F),prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# MODEL2: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# MODEL2:     word_length_characters_normalized + word_position_normalized + 
# MODEL2:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# MODEL2:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# MODEL2:     (1 | text) + (1 | word_type)
# MODEL1: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# MODEL1:     word_length_characters_normalized + word_position_normalized + 
# MODEL1:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# MODEL1:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# MODEL1:     (1 | text) + (1 | word_type)
# Df    AIC    BIC  logLik deviance Chisq Chi Df Pr(>Chisq)
# MODEL2 26 598129 598375 -299039   598077                        
# MODEL1 27 598131 598386 -299038   598077  0.38      1     0.5376


## Final models ##

## Main study excluding auxiliaries (AUX)

prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + word_length_characters_normalized + word_length_characters_normalized:word_position_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.reml)
# Linear mixed model fit by REML. t-tests use Satterthwaite's method ['lmerModLmerTest']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_no_aux *  
# word_position_normalized + word_length_characters_normalized +  
# word_length_characters_normalized:word_position_normalized +  
# word_class_relevant_no_aux * language_iso_code + (1 | speaker) +      (1 | text) + (1 | word_type)
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# 
# REML criterion at convergence: 567251.1
# 
# Scaled residuals: 
# Min      1Q  Median      3Q     Max 
# -3.5572 -0.5908 -0.0686  0.4803 16.9115 
# 
# Random effects:
# Groups    Name        Variance Std.Dev.
# word_type (Intercept)  1.4910  1.2211  
# text      (Intercept)  0.8132  0.9018  
# speaker   (Intercept)  3.1910  1.7863  
# Residual              33.1762  5.7599  
# Number of obs: 88832, groups:  word_type, 29784; text, 346; speaker, 310
# 
# Fixed effects:
# Estimate  Std. Error          df t value
# (Intercept)                                                   16.97076     0.42380   452.00000  40.044
# word_class_relevant_no_auxV                                    0.51466     0.16084 42951.00000   3.200
# word_position_normalized                                      -0.10109     0.12496 87438.00000  -0.809
# word_length_characters_normalized                              0.13267     0.05317 64188.00000   2.495
# language_iso_codebrg                                          -3.76861     0.79079   281.00000  -4.766
# language_iso_codectn                                          -0.77183     0.52331   405.00000  -1.475
# language_iso_codeeng                                           1.47451     0.49012   405.00000   3.008
# language_iso_codeeve                                          -2.47298     0.56206   321.00000  -4.400
# language_iso_codengh                                          -0.87744     0.82819   214.00000  -1.059
# language_iso_codenld                                           3.92455     0.56404   407.00000   6.958
# language_iso_codepoq                                           1.11314     1.87998   160.00000   0.592
# language_iso_codewin                                          -4.49742     0.59972   351.00000  -7.499
# word_class_relevant_no_auxV:word_position_normalized          -0.37720     0.14676 87043.00000  -2.570
# word_position_normalized:word_length_characters_normalized     0.14436     0.06975 84634.00000   2.070
# word_class_relevant_no_auxV:language_iso_codebrg               0.25279     0.22603 27476.00000   1.118
# word_class_relevant_no_auxV:language_iso_codectn               0.95770     0.18641 26267.00000   5.138
# word_class_relevant_no_auxV:language_iso_codeeng               0.01069     0.18935 16180.00000   0.056
# word_class_relevant_no_auxV:language_iso_codeeve               0.31295     0.17937 29173.00000   1.745
# word_class_relevant_no_auxV:language_iso_codengh              -0.25563     0.21799 14868.00000  -1.173
# word_class_relevant_no_auxV:language_iso_codenld               0.19568     0.20944 17647.00000   0.934
# word_class_relevant_no_auxV:language_iso_codepoq               1.14520     0.22561 17264.00000   5.076
# word_class_relevant_no_auxV:language_iso_codewin               0.44985     0.23114 28031.00000   1.946
# Pr(>|t|)    
# (Intercept)                                                < 0.0000000000000002 ***
# word_class_relevant_no_auxV                                             0.00138 ** 
# word_position_normalized                                                0.41853    
# word_length_characters_normalized                                       0.01260 *  
# language_iso_codebrg                                          0.000003021327767 ***
# language_iso_codectn                                                    0.14101    
# language_iso_codeeng                                                    0.00279 ** 
# language_iso_codeeve                                          0.000014761584556 ***
# language_iso_codengh                                                    0.29059    
# language_iso_codenld                                          0.000000000013880 ***
# language_iso_codepoq                                                    0.55462    
# language_iso_codewin                                          0.000000000000531 ***
# word_class_relevant_no_auxV:word_position_normalized                    0.01017 *  
# word_position_normalized:word_length_characters_normalized              0.03849 *  
# word_class_relevant_no_auxV:language_iso_codebrg                        0.26340    
# word_class_relevant_no_auxV:language_iso_codectn              0.000000280093619 ***
# word_class_relevant_no_auxV:language_iso_codeeng                        0.95500    
# word_class_relevant_no_auxV:language_iso_codeeve                        0.08104 .  
# word_class_relevant_no_auxV:language_iso_codengh                        0.24096    
# word_class_relevant_no_auxV:language_iso_codenld                        0.35015    
# word_class_relevant_no_auxV:language_iso_codepoq              0.000000389447330 ***
# word_class_relevant_no_auxV:language_iso_codewin                        0.05164 .  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation matrix not shown by default, as p = 22 > 12.
# Use print(x, correlation=TRUE)  or
# 	 vcov(x)	 if you need it

lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.reml)
#                                word_class_relevant_no_auxV                                   word_position_normalized 
#                                                0.037814559                                               -0.004596880 
#                          word_length_characters_normalized                                       language_iso_codebrg 
#                                                0.020063776                                               -0.138989376 
#                                       language_iso_codectn                                       language_iso_codeeng 
#                                               -0.038803597                                                0.088634249 
#                                       language_iso_codeeve                                       language_iso_codengh 
#                                               -0.132502988                                               -0.040325960 
#                                       language_iso_codenld                                       language_iso_codepoq 
#                                                0.182613503                                                0.046075940 
#                                       language_iso_codewin       word_class_relevant_no_auxV:word_position_normalized 
#                                               -0.174225309                                               -0.022395609 
# word_position_normalized:word_length_characters_normalized           word_class_relevant_no_auxV:language_iso_codebrg 
#                                                0.016538831                                                0.007453211 
#           word_class_relevant_no_auxV:language_iso_codectn           word_class_relevant_no_auxV:language_iso_codeeng 
#                                                0.038758616                                                0.000517714 
#           word_class_relevant_no_auxV:language_iso_codeeve           word_class_relevant_no_auxV:language_iso_codengh 
#                                                0.013277403                                               -0.009784178 
#           word_class_relevant_no_auxV:language_iso_codenld           word_class_relevant_no_auxV:language_iso_codepoq 
#                                                0.007363487                                                0.040218673 
#           word_class_relevant_no_auxV:language_iso_codewin 
#                                                0.015081218 

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- combined.wordtimes.prewindows.publish.articulation_rate.no_aux
model <- prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.reml

data$P <- fixef(model)['word_class_relevant_no_auxV:word_position_normalized']
data$V <- fixef(model)['word_class_relevant_no_auxV']

min(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.1374581

max(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.5113475

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_no_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']))
# [1] 1.364419

# Beyond maximal position of 1

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#  TRUE 
# 88832 

table(data$word_class_relevant_no_aux,fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#    TRUE
# N 32964
# V 55868

prop.table(table(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
# TRUE 
#  100 

prop.table(table(data$word_class_relevant_no_aux,fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1)*100
#   TRUE
# N  100
# V  100

# Comparison model to gauge the overall effect of word class (including language as a random effect instead of in a fixed effects interaction)
summary(lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_no_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + (1 + word_class_relevant_no_aux|language_iso_code) + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=T))
# Linear mixed model fit by REML. t-tests use Satterthwaite's method ['lmerModLmerTest']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_no_aux +  
# word_length_characters_normalized + word_position_normalized +  
# word_class_relevant_no_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized +  
# (1 + word_class_relevant_no_aux | language_iso_code) + (1 |      speaker) + (1 | text) + (1 | word_type)
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# 
# REML criterion at convergence: 567304.1
# 
# Scaled residuals: 
# Min      1Q  Median      3Q     Max 
# -3.5577 -0.5911 -0.0684  0.4804 16.9121 
# 
# Random effects:
# Groups            Name                        Variance Std.Dev. Corr 
# word_type         (Intercept)                  1.4907  1.2210        
# text              (Intercept)                  0.8143  0.9024        
# speaker           (Intercept)                  3.1855  1.7848        
# language_iso_code (Intercept)                  6.9365  2.6337        
# word_class_relevant_no_auxV                    0.1788  0.4228   -0.08
# Residual                                      33.1764  5.7599        
# Number of obs: 88832, groups:  word_type, 29784; text, 346; speaker, 310; language_iso_code, 9
# 
# Fixed effects:
# Estimate  Std. Error          df t value     Pr(>|t|)    
# (Intercept)                                                   16.25962     0.91079     8.00000  17.852 0.0000000608 ***
# word_class_relevant_no_auxV                                    0.85565     0.17831    15.00000   4.799     0.000216 ***
# word_length_characters_normalized                              0.13423     0.05314 63715.00000   2.526     0.011547 *  
# word_position_normalized                                      -0.09480     0.12455 60483.00000  -0.761     0.446584    
# word_class_relevant_no_auxV:word_position_normalized          -0.38261     0.14637 67978.00000  -2.614     0.008952 ** 
# word_length_characters_normalized:word_position_normalized     0.14588     0.06974 84577.00000   2.092     0.036454 *  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
# (Intr) wr____V wrd___ wrd_p_ w____V:
# wrd_cls___V -0.106                              
# wrd_lngth__ -0.033  0.013                       
# wrd_pstn_nr -0.089  0.410   0.289               
# wrd____V:__  0.068 -0.538  -0.039 -0.764        
# wrd_ln__:__  0.029 -0.020  -0.886 -0.337  0.033 


## Alternative study including auxiliaries (AUX)

prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + word_length_characters_normalized + word_class_relevant_aux*language_iso_code + word_length_characters_normalized:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.reml)
# Linear mixed model fit by REML. t-tests use Satterthwaite's method ['lmerModLmerTest']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_aux *  
#     word_position_normalized + word_length_characters_normalized +  
#     word_class_relevant_aux * language_iso_code + word_length_characters_normalized:word_position_normalized +  
#     (1 | speaker) + (1 | text) + (1 | word_type)
#    Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# 
# REML criterion at convergence: 598106.1
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -3.5729 -0.5909 -0.0684  0.4806 16.8698 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  1.392   1.1798  
#  text      (Intercept)  0.809   0.8994  
#  speaker   (Intercept)  3.215   1.7932  
#  Residual              33.455   5.7841  
# Number of obs: 93588, groups:  word_type, 30526; text, 346; speaker, 310
# 
# Fixed effects:
#                                                               Estimate  Std. Error          df t value
# (Intercept)                                                   16.98204     0.42466   457.00000  39.989
# word_class_relevant_auxV                                       0.52949     0.16014 44702.00000   3.306
# word_position_normalized                                      -0.11749     0.12480 91865.00000  -0.941
# word_length_characters_normalized                              0.10518     0.05151 63783.00000   2.042
# language_iso_codebrg                                          -3.76403     0.79284   284.00000  -4.748
# language_iso_codectn                                          -0.76459     0.52433   409.00000  -1.458
# language_iso_codeeng                                           1.49778     0.49096   408.00000   3.051
# language_iso_codeeve                                          -2.44810     0.56323   324.00000  -4.347
# language_iso_codengh                                          -0.86736     0.83058   216.00000  -1.044
# language_iso_codenld                                           3.94259     0.56496   411.00000   6.979
# language_iso_codepoq                                           1.07365     1.88620   162.00000   0.569
# language_iso_codewin                                          -4.56117     0.59968   352.00000  -7.606
# word_class_relevant_auxV:word_position_normalized             -0.39460     0.14561 91432.00000  -2.710
# word_class_relevant_auxV:language_iso_codebrg                  0.24724     0.22560 28967.00000   1.096
# word_class_relevant_auxV:language_iso_codectn                  0.95381     0.18602 27577.00000   5.127
# word_class_relevant_auxV:language_iso_codeeng                  0.05059     0.18700 16311.00000   0.271
# word_class_relevant_auxV:language_iso_codeeve                  0.35372     0.17832 30036.00000   1.984
# word_class_relevant_auxV:language_iso_codengh                 -0.25848     0.21701 15405.00000  -1.191
# word_class_relevant_auxV:language_iso_codenld                  0.18077     0.20862 18297.00000   0.866
# word_class_relevant_auxV:language_iso_codepoq                  1.09858     0.22365 17588.00000   4.912
# word_class_relevant_auxV:language_iso_codewin                  0.48386     0.22581 29134.00000   2.143
# word_position_normalized:word_length_characters_normalized     0.17327     0.06746 88531.00000   2.568
#                                                                        Pr(>|t|)    
# (Intercept)                                                < 0.0000000000000002 ***
# word_class_relevant_auxV                                               0.000945 ***
# word_position_normalized                                               0.346487    
# word_length_characters_normalized                                      0.041170 *  
# language_iso_codebrg                                           0.00000326771995 ***
# language_iso_codectn                                                   0.145544    
# language_iso_codeeng                                                   0.002432 ** 
# language_iso_codeeve                                           0.00001853758707 ***
# language_iso_codengh                                                   0.297521    
# language_iso_codenld                                           0.00000000001202 ***
# language_iso_codepoq                                                   0.570001    
# language_iso_codewin                                           0.00000000000026 ***
# word_class_relevant_auxV:word_position_normalized                      0.006732 ** 
# word_class_relevant_auxV:language_iso_codebrg                          0.273123    
# word_class_relevant_auxV:language_iso_codectn                  0.00000029581921 ***
# word_class_relevant_auxV:language_iso_codeeng                          0.786747    
# word_class_relevant_auxV:language_iso_codeeve                          0.047311 *  
# word_class_relevant_auxV:language_iso_codengh                          0.233633    
# word_class_relevant_auxV:language_iso_codenld                          0.386231    
# word_class_relevant_auxV:language_iso_codepoq                  0.00000090927421 ***
# word_class_relevant_auxV:language_iso_codewin                          0.032138 *  
# word_position_normalized:word_length_characters_normalized             0.010223 *  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation matrix not shown by default, as p = 22 > 12.
# Use print(x, correlation=TRUE)  or
# 	 vcov(x)	 if you need it

lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.reml)
#                                   word_class_relevant_auxV                                   word_position_normalized 
#                                                0.038367257                                               -0.005324503 
#                          word_length_characters_normalized                                       language_iso_codebrg 
#                                                0.016188608                                               -0.135126247 
#                                       language_iso_codectn                                       language_iso_codeeng 
#                                               -0.037488320                                                0.091443179 
#                                       language_iso_codeeve                                       language_iso_codengh 
#                                               -0.129991518                                               -0.038847410 
#                                       language_iso_codenld                                       language_iso_codepoq 
#                                                0.178795647                                                0.046541269 
#                                       language_iso_codewin          word_class_relevant_auxV:word_position_normalized 
#                                               -0.186864516                                               -0.023142945 
#              word_class_relevant_auxV:language_iso_codebrg              word_class_relevant_auxV:language_iso_codectn 
#                                                0.007090897                                                0.037589124 
#              word_class_relevant_auxV:language_iso_codeeng              word_class_relevant_auxV:language_iso_codeeve 
#                                                0.002565678                                                0.015034246 
#              word_class_relevant_auxV:language_iso_codengh              word_class_relevant_auxV:language_iso_codenld 
#                                               -0.009631545                                                0.006621988 
#              word_class_relevant_auxV:language_iso_codepoq              word_class_relevant_auxV:language_iso_codewin 
#                                                0.041631957                                                0.017650332 
# word_position_normalized:word_length_characters_normalized 
#                                                0.019889396 

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- combined.wordtimes.prewindows.publish.articulation_rate.aux
model <- prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.reml

data$P <- fixef(model)['word_class_relevant_auxV:word_position_normalized']
data$V <- fixef(model)['word_class_relevant_auxV']

min(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.1348898

max(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.5260256

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']))
# [1] 1.341842

# Beyond maximal position of 1

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#  TRUE 
# 93588 

table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#    TRUE
# N 32964
# V 60624

prop.table(table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
# TRUE 
#  100 

prop.table(table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1)*100
#   TRUE
# N  100
# V  100

# Comparison model to gauge the overall effect of word class (including language as a random effect instead of in a fixed effects interaction)
summary(lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + (1 + word_class_relevant_aux|language_iso_code) + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=T))
# Linear mixed model fit by REML. t-tests use Satterthwaite's method ['lmerModLmerTest']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_aux +  
#     word_length_characters_normalized + word_position_normalized +  
#     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized +  
#     (1 + word_class_relevant_aux | language_iso_code) + (1 |      speaker) + (1 | text) + (1 | word_type)
#    Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# 
# REML criterion at convergence: 598158.6
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -3.5734 -0.5904 -0.0681  0.4801 16.8704 
# 
# Random effects:
#  Groups            Name                     Variance Std.Dev. Corr 
#  word_type         (Intercept)               1.3917  1.1797        
#  text              (Intercept)               0.8100  0.9000        
#  speaker           (Intercept)               3.2103  1.7917        
#  language_iso_code (Intercept)               6.9956  2.6449        
#                    word_class_relevant_auxV  0.1686  0.4106   -0.11
#  Residual                                   33.4555  5.7841        
# Number of obs: 93588, groups:  word_type, 30526; text, 346; speaker, 310; language_iso_code, 9
# 
# Fixed effects:
#                                                               Estimate  Std. Error          df t value    Pr(>|t|)    
# (Intercept)                                                   16.26538     0.91452     8.00000  17.786 0.000000061 ***
# word_class_relevant_auxV                                       0.87674     0.17445    16.00000   5.026    0.000129 ***
# word_length_characters_normalized                              0.10652     0.05149 63283.00000   2.069    0.038563 *  
# word_position_normalized                                      -0.11010     0.12436 60010.00000  -0.885    0.375979    
# word_class_relevant_auxV:word_position_normalized             -0.40149     0.14521 69231.00000  -2.765    0.005697 ** 
# word_length_characters_normalized:word_position_normalized     0.17485     0.06745 88478.00000   2.592    0.009542 ** 
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___ wrd_p_ w___V:
# wrd_clss__V -0.134                            
# wrd_lngth__ -0.032  0.026                     
# wrd_pstn_nr -0.088  0.426  0.278              
# wrd_c__V:__  0.069 -0.545 -0.059 -0.781       
# wrd_ln__:__  0.028 -0.033 -0.883 -0.326  0.055


## Tests of fixed effects in final model ##

## Main study excluding auxiliaries (AUX)

# Test word class
prewindow.articulation_speed.n_vs_v.aux_other.no_pos.language = lmer(pre_word_window_articulation_rate ~ word_position_normalized * word_length_characters_normalized + language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_pos.language,prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.language: pre_word_window_articulation_rate ~ word_position_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.language:     word_length_characters_normalized + language_iso_code + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.language:     speaker) + (1 | text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_class_relevant_no_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     (1 | text) + (1 | word_type)
#                                                                   Df    AIC    BIC  logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.language     16 567471 567621 -283719   567439              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward 26 567275 567519 -283611   567223 215.89     10
#                                                                   Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.language                   
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="word class"] = pchisq(215.89,10,lower.tail=FALSE)

# Test interactions
drop1(prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
#     (1 | text) + (1 | word_type)
#                                                            Df    AIC    LRT   Pr(Chi)    
# <none>                                                        567275                     
# word_class_relevant_no_aux:word_position_normalized         1 567279  6.600   0.01020 *  
# word_length_characters_normalized:word_position_normalized  1 567277  4.285   0.03845 *  
# word_class_relevant_no_aux:language_iso_code                8 567326 67.256 1.725e-11 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="word class:position"] = pchisq(6.600,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="word length:position"] = pchisq(4.285,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="word class:language"] = pchisq(67.256,8,lower.tail=FALSE)

# Test position
prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_position = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F)

anova(prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_position,prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_position: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_position:     word_length_characters_normalized + word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_position:     language_iso_code + (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_class_relevant_no_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     (1 | text) + (1 | word_type)
#                                                                        Df    AIC    BIC  logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_position 23 567294 567510 -283624   567248              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward      26 567275 567519 -283611   567223 25.186      3
#                                                                        Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_position               
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward       1.412e-05 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="position"] = pchisq(25.186,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_word_length = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F)

anova(prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_word_length,prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_word_length: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_word_length:     word_position_normalized + word_class_relevant_no_aux * language_iso_code + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_word_length:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_class_relevant_no_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     (1 | text) + (1 | word_type)
#                                                                           Df    AIC    BIC  logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_word_length 24 567362 567587 -283657   567314              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward         26 567275 567519 -283611   567223 90.961      2
#                                                                           Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_word_length               
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward          < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="word length"] = pchisq(90.961,2,lower.tail=FALSE)

# Test language
prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_language = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F)

anova(prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_language,prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_language: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_language:     word_position_normalized + word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_language:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_language:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_class_relevant_no_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     (1 | text) + (1 | word_type)
#                                                                        Df    AIC    BIC  logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_language 10 567538 567632 -283759   567518              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward      26 567275 567519 -283611   567223 295.38     16
#                                                                        Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.no_language               
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward       < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="language"] = pchisq(295.38,16,lower.tail=FALSE)


## Alternative study including auxiliaries (AUX)

# Test word class
prewindow.articulation_speed.n_vs_v.aux_v.no_pos.language = lmer(pre_word_window_articulation_rate ~ word_position_normalized * word_length_characters_normalized + language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_pos.language,prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.language: pre_word_window_articulation_rate ~ word_position_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.language:     word_length_characters_normalized + language_iso_code + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.language:     speaker) + (1 | text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     (1 | text) + (1 | word_type)
#                                                               Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.language     16 598334 598485 -299151   598302                         
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward 26 598129 598375 -299039   598077 224.61     10  < 2.2e-16
#                                                                  
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.language        
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="word class"] = pchisq(224.61,10,lower.tail=FALSE)

# Test interactions
drop1(prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
#     (1 | text) + (1 | word_type)
#                                                            Df    AIC    LRT   Pr(Chi)    
# <none>                                                        598129                     
# word_class_relevant_aux:word_position_normalized            1 598135  7.338  0.006751 ** 
# word_length_characters_normalized:word_position_normalized  1 598134  6.599  0.010204 *  
# word_class_relevant_aux:language_iso_code                   8 598178 64.995 4.838e-11 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="word class:position"] = pchisq(7.338,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="word length:position"] = pchisq(6.599,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="word class:language"] = pchisq(64.995,8,lower.tail=FALSE)

# Test language
prewindow.articulation_speed.n_vs_v.aux_v.pos.no_language = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F)

anova(prewindow.articulation_speed.n_vs_v.aux_v.pos.no_language,prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.pos.no_language: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.no_language:     word_position_normalized + word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.no_language:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.no_language:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     (1 | text) + (1 | word_type)
#                                                               Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.no_language     10 598392 598486 -299186   598372                         
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward 26 598129 598375 -299039   598077 294.48     16  < 2.2e-16
#                                                                  
# prewindow.articulation_speed.n_vs_v.aux_v.pos.no_language        
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="language"] = pchisq(294.48,16,lower.tail=FALSE)

# Test position
prewindow.articulation_speed.n_vs_v.aux_v.pos.language.no_position = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F)

anova(prewindow.articulation_speed.n_vs_v.aux_v.pos.language.no_position,prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.no_position: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.no_position:     word_length_characters_normalized + word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.no_position:     language_iso_code + (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     (1 | text) + (1 | word_type)
#                                                                    Df    AIC    BIC  logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.no_position 23 598155 598372 -299055   598109              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward      26 598129 598375 -299039   598077 31.816      3
#                                                                    Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.no_position               
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward       5.722e-07 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="position"] = pchisq(31.816,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_v.pos.language.no_word_length = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F)

anova(prewindow.articulation_speed.n_vs_v.aux_v.pos.language.no_word_length,prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.no_word_length: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.no_word_length:     word_position_normalized + word_class_relevant_aux * language_iso_code + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.no_word_length:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     (1 | text) + (1 | word_type)
#                                                                       Df    AIC    BIC  logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.no_word_length 24 598216 598443 -299084   598168              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward         26 598129 598375 -299039   598077 90.729      2
#                                                                       Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.no_word_length               
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward          < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="word length"] = pchisq(90.729,2,lower.tail=FALSE)


## Tests of random effects in final model ##

## Main study excluding auxiliaries (AUX)

prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_speaker = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + word_length_characters_normalized + word_position_normalized:word_length_characters_normalized + word_class_relevant_no_aux*language_iso_code + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F)

prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_text = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + word_length_characters_normalized + word_position_normalized:word_length_characters_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F)

prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_word_type = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + word_length_characters_normalized + word_position_normalized:word_length_characters_normalized + word_class_relevant_no_aux*language_iso_code + (1|speaker) + (1|text), data=combined.wordtimes.prewindows.publish.articulation_rate.no_aux, REML=F)

# Test speaker
anova(prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_speaker,prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_speaker: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_speaker:     word_position_normalized + word_length_characters_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_speaker:     word_position_normalized:word_length_characters_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_speaker:     word_class_relevant_no_aux * language_iso_code + (1 | text) + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_speaker:     (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_class_relevant_no_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     (1 | text) + (1 | word_type)
#                                                                             Df    AIC    BIC  logLik deviance  Chisq
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_speaker 25 568359 568594 -284154   568309       
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward           26 567275 567519 -283611   567223 1085.8
#                                                                             Chi Df Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_speaker                      
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward                1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="speaker"] = pchisq(1085.8,1,lower.tail=FALSE)

# Test text
anova(prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_text,prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_text: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_text:     word_position_normalized + word_length_characters_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_text:     word_position_normalized:word_length_characters_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_text:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_text:     (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_class_relevant_no_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     (1 | text) + (1 | word_type)
#                                                                          Df    AIC    BIC  logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_text 25 567757 567992 -283854   567707              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward        26 567275 567519 -283611   567223 484.45      1
#                                                                          Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_text               
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward         < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="text"] = pchisq(484.45,1,lower.tail=FALSE)

# Test word type
anova(prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_word_type,prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.no_aux
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_word_type: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_word_type:     word_position_normalized + word_length_characters_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_word_type:     word_position_normalized:word_length_characters_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_word_type:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_word_type:     (1 | text)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_class_relevant_no_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     word_class_relevant_no_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward:     (1 | text) + (1 | word_type)
#                                                                               Df    AIC    BIC  logLik deviance  Chisq
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_word_type 25 569112 569346 -284531   569062       
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward             26 567275 567519 -283611   567223 1838.8
#                                                                               Chi Df Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.final.no_word_type                      
# prewindow.articulation_speed.n_vs_v.aux_other.pos.language.upward                  1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="word type"] = pchisq(1838.8,1,lower.tail=FALSE)


## Alternative study including auxiliaries (AUX)

prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_speaker = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + word_length_characters_normalized + word_position_normalized * word_length_characters_normalized + word_class_relevant_aux*language_iso_code + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F)

prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_text = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + word_length_characters_normalized + word_position_normalized * word_length_characters_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|word_type), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F)

prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_word_type = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + word_length_characters_normalized + word_position_normalized * word_length_characters_normalized + word_class_relevant_aux*language_iso_code + (1|speaker) + (1|text), data=combined.wordtimes.prewindows.publish.articulation_rate.aux, REML=F)

# Test speaker
anova(prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_speaker,prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_speaker: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_speaker:     word_position_normalized + word_length_characters_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_speaker:     word_position_normalized * word_length_characters_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_speaker:     word_class_relevant_aux * language_iso_code + (1 | text) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_speaker:     (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     (1 | text) + (1 | word_type)
#                                                                         Df    AIC    BIC  logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_speaker 25 599292 599528 -299621   599242              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward           26 598129 598375 -299039   598077 1164.2      1
#                                                                         Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_speaker               
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward            < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="speaker"] = pchisq(1164.2,1,lower.tail=FALSE)

# Test text
anova(prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_text,prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_text: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_text:     word_position_normalized + word_length_characters_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_text:     word_position_normalized * word_length_characters_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_text:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_text:     (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     (1 | text) + (1 | word_type)
#                                                                      Df    AIC    BIC  logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_text 25 598625 598861 -299288   598575              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward        26 598129 598375 -299039   598077 497.73      1
#                                                                      Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_text               
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward         < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="text"] = pchisq(497.73,1,lower.tail=FALSE)

# Test word type
anova(prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_word_type,prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.articulation_rate.aux
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_word_type: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_word_type:     word_position_normalized + word_length_characters_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_word_type:     word_position_normalized * word_length_characters_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_word_type:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_word_type:     (1 | text)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux * language_iso_code + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward:     (1 | text) + (1 | word_type)
#                                                                           Df    AIC    BIC  logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_word_type 25 599936 600172 -299943   599886              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward             26 598129 598375 -299039   598077 1808.8      1
#                                                                           Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.final.no_word_type               
# prewindow.articulation_speed.n_vs_v.aux_v.pos.language.upward              < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="word type"] = pchisq(1808.8,1,lower.tail=FALSE)


## Additional models for individual languages ##

## Main study excluding auxiliaries (AUX)

# Baure
prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_no_aux:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="brg")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_other.no_pos.baure.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="brg")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_no_aux:word_position_normalized + (1 |      speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  
#     subset = language_iso_code == "brg"))
# 
# REML criterion at convergence: 33219.5
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.7083 -0.6072 -0.0695  0.5028  8.5189 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  2.5955  1.6110  
#  text      (Intercept)  0.7027  0.8382  
#  speaker   (Intercept)  0.0000  0.0000  
#  Residual              20.4177  4.5186  
# Number of obs: 5573, groups:  word_type, 2761; text, 37; speaker, 10
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                13.48444    0.35233   38.27
# word_class_relevant_no_auxV                                 0.59520    0.38968    1.53
# word_length_characters_normalized                           0.02516    0.19624    0.13
# word_position_normalized                                   -0.28062    0.37581   -0.75
# word_length_characters_normalized:word_position_normalized  0.23473    0.25189    0.93
# word_class_relevant_no_auxV:word_position_normalized        0.02427    0.48673    0.05
# 
# Correlation of Fixed Effects:
#             (Intr) wr____V wrd___ wrd_p_ w___:_
# wrd_cls___V -0.666                             
# wrd_lngth__ -0.130 -0.322                      
# wrd_pstn_nr -0.814  0.671   0.133              
# wrd_ln__:__  0.103  0.305  -0.889 -0.155       
# wrd____V:__  0.580 -0.900   0.308 -0.694 -0.360

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml)
#                                word_class_relevant_no_auxV                          word_length_characters_normalized 
#                                                0.059327125                                                0.004655940 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                               -0.017550123                                                0.034395836 
#       word_class_relevant_no_auxV:word_position_normalized 
#                                                0.001993117 

# Test random effects
library(lmerTest)

# Output has changed slightly from last version of lmerTest (both format and numbers)
ranova(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>            10 -16610 33239                          
# (1 | speaker)      9 -16610 33237   0.000  1          1    
# (1 | text)         9 -16638 33294  56.021  1  7.169e-14 ***
# (1 | word_type)    9 -16682 33382 144.539  1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="speaker"] = pchisq(0.000,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="text"] = pchisq(56.021,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word type"] = pchisq(144.539,1,lower.tail=FALSE)

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized + (1 | 
#     speaker) + (1 | text) + (1 | word_type)
#                                                            Df   AIC     LRT Pr(Chi)
# <none>                                                        33231                
# word_length_characters_normalized:word_position_normalized  1 33230 0.86796  0.3515
# word_class_relevant_no_aux:word_position_normalized         1 33229 0.00268  0.9587

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word length:position"] = pchisq(0.86796,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word class:position"] = pchisq(0.00268,1,lower.tail=FALSE)

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_other.no_pos.baure.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.baure.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.baure.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.baure.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                    Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.baure.reml     8 33240 33293 -16612    33224                         
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml 10 33231 33297 -16606    33211 13.004      2     0.0015
#                                                                      
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.baure.reml      
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word class"] = pchisq(13.004,2,lower.tail=FALSE)

# Test word position
prewindow.articulation_speed.n_vs_v.aux_other.no_position.baure.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="brg")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_position.baure.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.baure.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.baure.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.baure.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                      Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.baure.reml  7 33226 33273 -16606    33212              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml   10 33231 33297 -16606    33211 1.2636      3
#                                                                      Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.baure.reml           
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml       0.7378

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="position"] = pchisq(1.2636,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.baure.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="brg")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.baure.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.baure.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.baure.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.baure.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                         Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.baure.reml  8 33232 33285 -16608    33216              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml      10 33231 33297 -16606    33211 5.2189      2
#                                                                         Pr(>Chisq)  
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.baure.reml             
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml         0.07357 .
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word length"] = pchisq(5.2189,2,lower.tail=FALSE)

# Check effect of interaction (see Baure section in alternative study including auxiliaries below, no auxiliaries in Baure)


# Bora
prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_no_aux:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="boa")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_other.no_pos.bora.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="boa")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_no_aux:word_position_normalized + (1 |      speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  
#     subset = language_iso_code == "boa"))
# 
# REML criterion at convergence: 65915.7
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.8317 -0.5588 -0.1346  0.3814 14.0731 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  2.840   1.685   
#  speaker   (Intercept) 15.153   3.893   
#  text      (Intercept)  1.077   1.038   
#  Residual              30.398   5.513   
# Number of obs: 10396, groups:  word_type, 5002; speaker, 43; text, 37
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                17.33048    0.73753  23.498
# word_class_relevant_no_auxV                                 0.14497    0.28948   0.501
# word_length_characters_normalized                           0.41350    0.15127   2.734
# word_position_normalized                                   -0.40326    0.33289  -1.211
# word_length_characters_normalized:word_position_normalized  0.21600    0.20642   1.046
# word_class_relevant_no_auxV:word_position_normalized       -0.02107    0.41114  -0.051
# 
# Correlation of Fixed Effects:
#             (Intr) wr____V wrd___ wrd_p_ w___:_
# wrd_cls___V -0.225                             
# wrd_lngth__ -0.045 -0.146                      
# wrd_pstn_nr -0.275  0.650   0.117              
# wrd_ln__:__  0.039  0.117  -0.881 -0.139       
# wrd____V:__  0.206 -0.876   0.125 -0.770 -0.151

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml)
#                                word_class_relevant_no_auxV                          word_length_characters_normalized 
#                                                0.011492738                                                0.063169815 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                               -0.019618457                                                0.024047625 
#       word_class_relevant_no_auxV:word_position_normalized 
#                                               -0.001370713 

# Test random effects
library(lmerTest)

# Output has changed slightly from last version of lmerTest (both format and numbers)
ranova(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>            10 -32958 65936                          
# (1 | speaker)      9 -33003 66023  89.635  1  < 2.2e-16 ***
# (1 | text)         9 -33001 66021  87.197  1  < 2.2e-16 ***
# (1 | word_type)    9 -33010 66037 103.293  1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="speaker"] = pchisq(89.635,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="text"] = pchisq(87.197,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word type"] = pchisq(103.293,1,lower.tail=FALSE)

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized + (1 | 
#     speaker) + (1 | text) + (1 | word_type)
#                                                            Df   AIC     LRT Pr(Chi)
# <none>                                                        65929                
# word_length_characters_normalized:word_position_normalized  1 65928 1.09624  0.2951
# word_class_relevant_no_aux:word_position_normalized         1 65927 0.00254  0.9598

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word length:position"] = pchisq(1.09624,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word class:position"] = pchisq(0.00254,1,lower.tail=FALSE)

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_other.no_pos.bora.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.bora.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.bora.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.bora.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                   Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.bora.reml     8 65925 65983 -32955    65909                         
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml 10 65929 66001 -32954    65909 0.8966      2     0.6387

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word class"] = pchisq(0.8966,2,lower.tail=FALSE)

# Test word position
prewindow.articulation_speed.n_vs_v.aux_other.no_position.bora.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="boa")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_position.bora.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.bora.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.bora.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.bora.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                     Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.bora.reml  7 65926 65977 -32956    65912              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml   10 65929 66001 -32954    65909 3.9197      3
#                                                                     Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.bora.reml           
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml       0.2703

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="position"] = pchisq(3.9197,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.bora.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="boa")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.bora.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.bora.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.bora.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.bora.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                        Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.bora.reml  8 65985 66043 -32984    65969              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml      10 65929 66001 -32954    65909 60.267      2
#                                                                        Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.bora.reml               
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml        8.19e-14 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word length"] = pchisq(60.267,2,lower.tail=FALSE)

# Check effect of interaction (see Bora section in alternative study including auxiliaries below, no auxiliaries in Bora)


# Chintang
prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_no_aux:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="ctn")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_other.no_pos.chintang.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="ctn")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_no_aux:word_position_normalized + (1 |      speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  
#     subset = language_iso_code == "ctn"))
# 
# REML criterion at convergence: 71704.6
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.8230 -0.6421 -0.0411  0.6032 13.2801 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  1.8278  1.3520  
#  speaker   (Intercept)  2.7855  1.6690  
#  text      (Intercept)  0.9473  0.9733  
#  Residual              35.5085  5.9589  
# Number of obs: 11091, groups:  word_type, 4707; speaker, 68; text, 40
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                16.12746    0.37503   43.00
# word_class_relevant_no_auxV                                 1.30964    0.31881    4.11
# word_length_characters_normalized                           0.22441    0.17127    1.31
# word_position_normalized                                   -0.04501    0.35378   -0.13
# word_length_characters_normalized:word_position_normalized  0.12682    0.22210    0.57
# word_class_relevant_no_auxV:word_position_normalized       -0.20591    0.45641   -0.45
# 
# Correlation of Fixed Effects:
#             (Intr) wr____V wrd___ wrd_p_ w___:_
# wrd_cls___V -0.391                             
# wrd_lngth__ -0.162 -0.173                      
# wrd_pstn_nr -0.548  0.561   0.191              
# wrd_ln__:__  0.145  0.180  -0.918 -0.205       
# wrd____V:__  0.371 -0.890   0.170 -0.695 -0.222

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml)
#                                word_class_relevant_no_auxV                          word_length_characters_normalized 
#                                                0.100235841                                                0.034696871 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                               -0.002005709                                                0.015841745 
#       word_class_relevant_no_auxV:word_position_normalized 
#                                               -0.013426101 

# Test random effects
# Output has changed slightly from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>            10 -35852 71725                          
# (1 | speaker)      9 -35937 71892 169.114  1  < 2.2e-16 ***
# (1 | text)         9 -35868 71754  31.407  1  2.093e-08 ***
# (1 | word_type)    9 -35897 71812  89.733  1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="speaker"] = pchisq(169.114,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="text"] = pchisq(31.407,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word type"] = pchisq(89.733,1,lower.tail=FALSE)

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized + (1 | 
#     speaker) + (1 | text) + (1 | word_type)
#                                                            Df   AIC     LRT Pr(Chi)
# <none>                                                        71716                
# word_length_characters_normalized:word_position_normalized  1 71714 0.32609  0.5680
# word_class_relevant_no_aux:word_position_normalized         1 71714 0.20380  0.6517

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word length:position"] = pchisq(0.32609,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word class:position"] = pchisq(0.20380,1,lower.tail=FALSE)

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_other.no_pos.chintang.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.chintang.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.chintang.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.chintang.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                       Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.chintang.reml     8 71778 71837 -35881    71762              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml 10 71716 71789 -35848    71696 66.195      2
#                                                                       Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.chintang.reml                  
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml  4.226e-15 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word class"] = pchisq(66.195,2,lower.tail=FALSE)

# Test word position
prewindow.articulation_speed.n_vs_v.aux_other.no_position.chintang.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="ctn")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_position.chintang.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.chintang.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.chintang.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.chintang.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                         Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.chintang.reml  7 71711 71762 -35848    71697              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml   10 71716 71789 -35848    71696 0.6199      3
#                                                                         Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.chintang.reml           
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml       0.8919

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="position"] = pchisq(0.6199,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.chintang.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="ctn")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.chintang.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.chintang.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.chintang.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.chintang.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                            Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.chintang.reml  8 71734 71792 -35859    71718              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml      10 71716 71789 -35848    71696 21.757      2
#                                                                            Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.chintang.reml               
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml       1.886e-05 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word length"] = pchisq(21.757,2,lower.tail=FALSE)

# Check effect of interaction (see Chintang section in alternative study including auxiliaries below, no auxiliaries in Chintang)


# Dutch
prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_no_aux:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="nld")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_other.no_pos.dutch.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="nld")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_no_aux:word_position_normalized + (1 |      speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  
#     subset = language_iso_code == "nld"))
# 
# REML criterion at convergence: 62382.7
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.9096 -0.5939 -0.0906  0.4909 14.3112 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  1.626   1.275   
#  speaker   (Intercept)  2.511   1.584   
#  text      (Intercept)  1.902   1.379   
#  Residual              46.693   6.833   
# Number of obs: 9285, groups:  word_type, 2382; speaker, 42; text, 17
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                 21.0532     0.5675   37.10
# word_class_relevant_no_auxV                                  1.2707     0.4111    3.09
# word_length_characters_normalized                           -0.1204     0.1804   -0.67
# word_position_normalized                                    -0.3159     0.5108   -0.62
# word_length_characters_normalized:word_position_normalized   0.4236     0.2365    1.79
# word_class_relevant_no_auxV:word_position_normalized        -1.4302     0.5553   -2.58
# 
# Correlation of Fixed Effects:
#             (Intr) wr____V wrd___ wrd_p_ w___:_
# wrd_cls___V -0.553                             
# wrd_lngth__ -0.384  0.392                      
# wrd_pstn_nr -0.594  0.759   0.502              
# wrd_ln__:__  0.346 -0.372  -0.895 -0.575       
# wrd____V:__  0.506 -0.887  -0.357 -0.829  0.375

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml)
#                                word_class_relevant_no_auxV                          word_length_characters_normalized 
#                                                 0.08476204                                                -0.01901462 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                                -0.01351140                                                 0.05037751 
#       word_class_relevant_no_auxV:word_position_normalized 
#                                                -0.07184220 

# Test random effects
# Output has changed slightly from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>            10 -31191 62403                          
# (1 | speaker)      9 -31261 62540 139.422  1    < 2e-16 ***
# (1 | text)         9 -31193 62404   3.231  1    0.07225 .  
# (1 | word_type)    9 -31251 62520 118.823  1    < 2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="speaker"] = pchisq(139.422,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="text"] = pchisq(3.231,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word type"] = pchisq(118.823,1,lower.tail=FALSE)

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized + (1 | 
#     speaker) + (1 | text) + (1 | word_type)
#                                                            Df   AIC    LRT Pr(Chi)  
# <none>                                                        62397                 
# word_length_characters_normalized:word_position_normalized  1 62398 3.1967 0.07379 .
# word_class_relevant_no_aux:word_position_normalized         1 62401 6.6244 0.01006 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word length:position"] = pchisq(3.1967,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word class:position"] = pchisq(6.6244,1,lower.tail=FALSE)

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_other.no_pos.dutch.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.dutch.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.dutch.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.dutch.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                    Df   AIC   BIC logLik deviance Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.dutch.reml     8 62402 62459 -31193    62386                        
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml 10 62397 62468 -31188    62377 9.652      2   0.008019
#                                                                      
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.dutch.reml      
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word class"] = pchisq(9.652,2,lower.tail=FALSE)

# Test word position
prewindow.articulation_speed.n_vs_v.aux_other.no_position.dutch.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="nld")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_position.dutch.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.dutch.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.dutch.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.dutch.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                      Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.dutch.reml  7 62421 62471 -31204    62407              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml   10 62397 62468 -31188    62377 30.899      3
#                                                                      Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.dutch.reml               
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml    8.926e-07 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="position"] = pchisq(30.899,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.dutch.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="nld")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.dutch.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.dutch.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.dutch.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.dutch.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                         Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.dutch.reml  8 62400 62457 -31192    62384              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml      10 62397 62468 -31188    62377 7.5891      2
#                                                                         Pr(>Chisq)  
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.dutch.reml             
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml         0.02249 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word length"] = pchisq(7.5891,2,lower.tail=FALSE)

# Check effect of interaction (see Dutch section in alternative study including auxiliaries below, no auxiliaries annotated in Dutch)


# English
prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_no_aux:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="eng")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_other.no_pos.english.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="eng")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_no_aux:word_position_normalized + (1 |      speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  
#     subset = language_iso_code == "eng"))
# 
# REML criterion at convergence: 115529.6
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.9720 -0.6393 -0.0627  0.5293  9.5288 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  2.5382  1.5932  
#  speaker   (Intercept)  3.1777  1.7826  
#  text      (Intercept)  0.6016  0.7756  
#  Residual              46.1605  6.7941  
# Number of obs: 17210, groups:  word_type, 2783; speaker, 80; text, 47
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                 18.9596     0.3558   53.29
# word_class_relevant_no_auxV                                 -0.3328     0.3085   -1.08
# word_length_characters_normalized                           -0.2771     0.1462   -1.90
# word_position_normalized                                    -0.5736     0.3502   -1.64
# word_length_characters_normalized:word_position_normalized   0.4879     0.1936    2.52
# word_class_relevant_no_auxV:word_position_normalized         1.0226     0.4158    2.46
# 
# Correlation of Fixed Effects:
#             (Intr) wr____V wrd___ wrd_p_ w___:_
# wrd_cls___V -0.584                             
# wrd_lngth__ -0.403  0.285                      
# wrd_pstn_nr -0.654  0.711   0.446              
# wrd_ln__:__  0.330 -0.293  -0.857 -0.529       
# wrd____V:__  0.530 -0.845  -0.320 -0.798  0.363

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml)
#                                word_class_relevant_no_auxV                          word_length_characters_normalized 
#                                                -0.02226339                                                -0.03988796 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                                -0.02299903                                                 0.04926202 
#       word_class_relevant_no_auxV:word_position_normalized 
#                                                 0.04638324 

# Test random effects
# Output has changed slighlty from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized
#                 npar logLik    AIC    LRT Df Pr(>Chisq)    
# <none>            10 -57765 115550                         
# (1 | speaker)      9 -57934 115887 339.09  1  < 2.2e-16 ***
# (1 | text)         9 -57771 115560  12.32  1  0.0004471 ***
# (1 | word_type)    9 -58188 116394 846.25  1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="speaker"] = pchisq(339.09,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="text"] = pchisq(12.32,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="word type"] = pchisq(846.25,1,lower.tail=FALSE)

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="eng"))
model <- prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml

data$P <- ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized'])
data$V <- fixef(model)['word_class_relevant_no_auxV']

min(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] -0.3135539

max(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.689717

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_no_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']))
# [1] 0.3255027

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
# FALSE  TRUE 
#  4191 13019 

table(data$word_class_relevant_no_aux,fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#   FALSE TRUE
# N  1036 5993
# V  3155 7026

prop.table(table(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
#    FALSE     TRUE 
# 24.35212 75.64788 

prop.table(table(data$word_class_relevant_no_aux,fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1) * 100
#      FALSE     TRUE
# N 14.73894 85.26106
# V 30.98910 69.01090

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized + (1 | 
#     speaker) + (1 | text) + (1 | word_type)
#                                                            Df    AIC    LRT Pr(Chi)  
# <none>                                                        115541                 
# word_length_characters_normalized:word_position_normalized  1 115545 6.3536 0.01171 *
# word_class_relevant_no_aux:word_position_normalized         1 115545 6.0489 0.01391 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="word length:position"] = pchisq(6.3536,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="word class:position"] = pchisq(6.0489,1,lower.tail=FALSE)

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_other.no_pos.english.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.english.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.english.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.english.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                      Df    AIC    BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.english.reml     8 115546 115608 -57765   115530              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml 10 115541 115618 -57760   115521 9.5432      2
#                                                                      Pr(>Chisq)   
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.english.reml                 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml   0.008467 **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="word class"] = pchisq(9.5432,2,lower.tail=FALSE)

# Test word position
prewindow.articulation_speed.n_vs_v.aux_other.no_position.english.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="eng")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_position.english.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.english.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.english.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.english.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                        Df    AIC    BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.english.reml  7 115546 115600 -57766   115532              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml   10 115541 115618 -57760   115521 11.093      3
#                                                                        Pr(>Chisq)  
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.english.reml             
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml      0.01123 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="position"] = pchisq(11.093,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.english.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="eng")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.english.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.english.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.english.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.english.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                           Df    AIC    BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.english.reml  8 115543 115605 -57764   115527              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml      10 115541 115618 -57760   115521 6.6145      2
#                                                                           Pr(>Chisq)  
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.english.reml             
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml         0.03662 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="word length"] = pchisq(6.6145,2,lower.tail=FALSE)


# Even
prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_no_aux:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="eve")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_other.no_pos.even.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="eve")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_no_aux:word_position_normalized + (1 |      speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  
#     subset = language_iso_code == "eve"))
# 
# REML criterion at convergence: 69915.8
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -3.4744 -0.6120  0.0031  0.6109  6.3665 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  1.0133  1.0066  
#  text      (Intercept)  0.5737  0.7574  
#  speaker   (Intercept)  1.2797  1.1312  
#  Residual              12.2534  3.5005  
# Number of obs: 12897, groups:  word_type, 5720; text, 67; speaker, 31
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                14.19264    0.27065   52.44
# word_class_relevant_no_auxV                                 0.56189    0.15913    3.53
# word_length_characters_normalized                           0.31318    0.08782    3.57
# word_position_normalized                                    0.36049    0.17921    2.01
# word_length_characters_normalized:word_position_normalized -0.09194    0.12348   -0.74
# word_class_relevant_no_auxV:word_position_normalized       -0.03389    0.22781   -0.15
# 
# Correlation of Fixed Effects:
#             (Intr) wr____V wrd___ wrd_p_ w___:_
# wrd_cls___V -0.283                             
# wrd_lngth__ -0.124 -0.160                      
# wrd_pstn_nr -0.373  0.566   0.198              
# wrd_ln__:__  0.100  0.132  -0.875 -0.246       
# wrd____V:__  0.258 -0.868   0.146 -0.701 -0.150

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml)
#                                word_class_relevant_no_auxV                          word_length_characters_normalized 
#                                                0.072462399                                                0.073471197 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                                0.028153820                                               -0.015434293 
#       word_class_relevant_no_auxV:word_position_normalized 
#                                               -0.003581873 

# Test random effects
# Output has changed slighlty from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>            10 -34958 69936                          
# (1 | speaker)      9 -34988 69994  59.882  1  1.007e-14 ***
# (1 | text)         9 -35039 70096 161.939  1  < 2.2e-16 ***
# (1 | word_type)    9 -34990 69997  63.411  1  1.678e-15 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="speaker"] = pchisq(59.882,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="text"] = pchisq(161.939,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="word type"] = pchisq(63.411,1,lower.tail=FALSE)

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="eve"))
model <- prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml

data$P <- ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized'])
data$V <- fixef(model)['word_class_relevant_no_auxV']

min(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.5279983

max(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.5612532

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_no_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']))
# [1] 16.57774

# Beyond maximal position of 1

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#  TRUE 
# 12897 

table(data$word_class_relevant_no_aux,fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#   TRUE
# N 5342
# V 7555

prop.table(table(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
# TRUE 
#  100 

prop.table(table(data$word_class_relevant_no_aux,fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1) * 100
#   TRUE
# N  100
# V  100

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized + (1 | 
#     speaker) + (1 | text) + (1 | word_type)
#                                                            Df   AIC     LRT Pr(Chi)
# <none>                                                        69921                
# word_length_characters_normalized:word_position_normalized  1 69920 0.55549  0.4561
# word_class_relevant_no_aux:word_position_normalized         1 69919 0.02205  0.8820

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="word length:position"] = pchisq(0.55549,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="word class:position"] = pchisq(0.02205,1,lower.tail=FALSE)

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_other.no_pos.even.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.even.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.even.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.even.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                   Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.even.reml     8 69964 70023 -34974    69948                         
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml 10 69921 69996 -34951    69901 46.664      2  7.363e-11
#                                                                      
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.even.reml       
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="word class"] = pchisq(46.664,2,lower.tail=FALSE)

# Test word position
prewindow.articulation_speed.n_vs_v.aux_other.no_position.even.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="eve")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_position.even.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.even.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.even.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.even.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                     Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.even.reml  7 69923 69975 -34954    69909              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml   10 69921 69996 -34951    69901 7.5909      3
#                                                                     Pr(>Chisq)  
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.even.reml             
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml      0.05527 .
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="position"] = pchisq(7.5909,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.even.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="eve")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.even.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.even.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.even.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.even.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                        Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.even.reml  8 69954 70013 -34969    69938              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml      10 69921 69996 -34951    69901 36.713      2
#                                                                        Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.even.reml               
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml       1.066e-08 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="word length"] = pchisq(36.713,2,lower.tail=FALSE)


# Hoocąk
prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_no_aux:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="win")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_other.no_pos.hoocak.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="win")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_no_aux:word_position_normalized + (1 |      speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  
#     subset = language_iso_code == "win"))
# 
# REML criterion at convergence: 34695.8
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -3.2060 -0.5906 -0.0521  0.4876 15.8379 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  0.8189  0.9049  
#  text      (Intercept)  1.5156  1.2311  
#  speaker   (Intercept)  3.3071  1.8185  
#  Residual              14.6569  3.8284  
# Number of obs: 6195, groups:  word_type, 3209; text, 62; speaker, 28
# 
# Fixed effects:
#                                                             Estimate Std. Error t value
# (Intercept)                                                12.144892   0.465431  26.094
# word_class_relevant_no_auxV                                 0.495198   0.254522   1.946
# word_length_characters_normalized                           0.005578   0.122122   0.046
# word_position_normalized                                    0.663480   0.368394   1.801
# word_length_characters_normalized:word_position_normalized  0.100143   0.171118   0.585
# word_class_relevant_no_auxV:word_position_normalized        0.162823   0.422000   0.386
# 
# Correlation of Fixed Effects:
#             (Intr) wr____V wrd___ wrd_p_ w___:_
# wrd_cls___V -0.340                             
# wrd_lngth__ -0.077 -0.141                      
# wrd_pstn_nr -0.372  0.651   0.119              
# wrd_ln__:__  0.069  0.131  -0.887 -0.130       
# wrd____V:__  0.305 -0.850   0.110 -0.840 -0.140

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml)
#                                word_class_relevant_no_auxV                          word_length_characters_normalized 
#                                                0.050513164                                                0.001292053 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                                0.045853015                                                0.016950405 
#       word_class_relevant_no_auxV:word_position_normalized 
#                                                0.014408816 

# Test random effects
# Output has changed slighlty from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>            10 -17348 34716                          
# (1 | speaker)      9 -17370 34758  43.873  1  3.504e-11 ***
# (1 | text)         9 -17431 34880 166.524  1  < 2.2e-16 ***
# (1 | word_type)    9 -17364 34747  33.095  1  8.774e-09 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="speaker"] = pchisq(43.873,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="text"] = pchisq(166.524,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="word type"] = pchisq(33.095,1,lower.tail=FALSE)

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="win"))
model <- prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml

data$P <- ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized'])
data$V <- fixef(model)['word_class_relevant_no_auxV']

min(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.4970485

max(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.6580209

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_no_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']))
# [1] -3.041334

# Below minimal position of 0

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
# TRUE 
# 6195 

table(data$word_class_relevant_no_aux,fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#   TRUE
# N 1646
# V 4549

prop.table(table(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
# TRUE 
#  100 

prop.table(table(data$word_class_relevant_no_aux,fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1) * 100
#   TRUE
# N  100
# V  100

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized + (1 | 
#     speaker) + (1 | text) + (1 | word_type)
#                                                            Df   AIC     LRT Pr(Chi)
# <none>                                                        34706                
# word_length_characters_normalized:word_position_normalized  1 34705 0.34283  0.5582
# word_class_relevant_no_aux:word_position_normalized         1 34705 0.14859  0.6999

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="word length:position"] = pchisq(0.34283,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="word class:position"] = pchisq(0.14859,1,lower.tail=FALSE)

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_other.no_pos.hoocak.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.hoocak.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.hoocak.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.hoocak.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                     Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.hoocak.reml     8 34721 34775 -17353    34705              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml 10 34706 34774 -17343    34686 18.769      2
#                                                                     Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.hoocak.reml                  
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml  8.403e-05 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="word class"] = pchisq(18.769,2,lower.tail=FALSE)

# Test word position
prewindow.articulation_speed.n_vs_v.aux_other.no_position.hoocak.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="win")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_position.hoocak.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.hoocak.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.hoocak.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.hoocak.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                       Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.hoocak.reml  7 34724 34771 -17355    34710              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml   10 34706 34774 -17343    34686 23.143      3
#                                                                       Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.hoocak.reml               
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml     3.77e-05 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="position"] = pchisq(23.143,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.hoocak.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="win")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.hoocak.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.hoocak.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.hoocak.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.hoocak.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                          Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.hoocak.reml  8 34704 34758 -17344    34688              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml      10 34706 34774 -17343    34686 1.8298      2
#                                                                          Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.hoocak.reml           
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml          0.4005

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="word length"] = pchisq(1.8298,2,lower.tail=FALSE)


# Nǁng
prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_no_aux:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="ngh")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_other.no_pos.nuu.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="ngh")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_no_aux:word_position_normalized + (1 |      speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  
#     subset = language_iso_code == "ngh"))
# 
# REML criterion at convergence: 58220.9
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.5065 -0.5934 -0.1112  0.4386 10.7282 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  1.591   1.261   
#  text      (Intercept)  1.512   1.230   
#  speaker   (Intercept)  3.289   1.814   
#  Residual              35.604   5.967   
# Number of obs: 9029, groups:  word_type, 1097; text, 33; speaker, 7
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                16.95072    0.86850  19.517
# word_class_relevant_no_auxV                                 0.14442    0.48332   0.299
# word_length_characters_normalized                           0.32211    0.27100   1.189
# word_position_normalized                                   -1.12141    0.53527  -2.095
# word_length_characters_normalized:word_position_normalized -0.04722    0.30448  -0.155
# word_class_relevant_no_auxV:word_position_normalized       -0.38113    0.55768  -0.683
# 
# Correlation of Fixed Effects:
#             (Intr) wr____V wrd___ wrd_p_ w___:_
# wrd_cls___V -0.450                             
# wrd_lngth__ -0.296  0.262                      
# wrd_pstn_nr -0.501  0.787   0.492              
# wrd_ln__:__  0.272 -0.258  -0.924 -0.549       
# wrd____V:__  0.416 -0.927  -0.253 -0.824  0.277

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml)
#                                word_class_relevant_no_auxV                          word_length_characters_normalized 
#                                                0.010587771                                                0.043739158 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                               -0.048620860                                               -0.005700973 
#       word_class_relevant_no_auxV:word_position_normalized 
#                                               -0.024409696 

# Test random effects
# Output has changed slighlty from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>            10 -29110 58241                          
# (1 | speaker)      9 -29131 58280  41.455  1  1.206e-10 ***
# (1 | text)         9 -29222 58462 222.780  1  < 2.2e-16 ***
# (1 | word_type)    9 -29161 58340 101.197  1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & grepl("^N",p.values$model) & p.values$variable=="speaker"] = pchisq(41.455,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & grepl("^N",p.values$model) & p.values$variable=="text"] = pchisq(222.780,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & grepl("^N",p.values$model) & p.values$variable=="word type"] = pchisq(101.197,1,lower.tail=FALSE)

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized + (1 | 
#     speaker) + (1 | text) + (1 | word_type)
#                                                            Df   AIC     LRT Pr(Chi)
# <none>                                                        58237                
# word_length_characters_normalized:word_position_normalized  1 58235 0.02445  0.8757
# word_class_relevant_no_aux:word_position_normalized         1 58235 0.46912  0.4934

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & grepl("^N",p.values$model) & p.values$variable=="word length:position"] = pchisq(0.02445,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & grepl("^N",p.values$model) & p.values$variable=="word class:position"] = pchisq(0.46912,1,lower.tail=FALSE)

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_other.no_pos.nuu.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.nuu.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.nuu.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.nuu.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                  Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.nuu.reml     8 58234 58291 -29109    58218                         
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml 10 58237 58308 -29108    58217 1.2718      2     0.5294

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & grepl("^N",p.values$model) & p.values$variable=="word class"] = pchisq(1.2718,2,lower.tail=FALSE)

# Test word position
prewindow.articulation_speed.n_vs_v.aux_other.no_position.nuu.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="ngh")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_position.nuu.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.nuu.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.nuu.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.nuu.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                    Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.nuu.reml  7 58264 58314 -29125    58250                         
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml   10 58237 58308 -29108    58217 33.625      3  2.377e-07
#                                                                       
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.nuu.reml    
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml   ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & grepl("^N",p.values$model) & p.values$variable=="position"] = pchisq(33.625,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.nuu.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="ngh")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.nuu.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.nuu.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.nuu.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.nuu.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml:     speaker) + (1 | text) + (1 | word_type)
#                                                                       Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.nuu.reml  8 58240 58297 -29112    58224              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml      10 58237 58308 -29108    58217 7.4765      2
#                                                                       Pr(>Chisq)  
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.nuu.reml             
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml          0.0238 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & grepl("^N",p.values$model) & p.values$variable=="word length"] = pchisq(7.4765,2,lower.tail=FALSE)

# Check effect of interaction (see Nǁng section in alternative study including auxiliaries below, no auxiliaries in Nǁng)


# Texistepec Popoluca
prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_no_aux:word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="poq")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_other.no_pos.popoluca.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="poq")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_no_aux:word_position_normalized + (1 |      text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  
#     subset = language_iso_code == "poq"))
# 
# REML criterion at convergence: 47039.8
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.6000 -0.6698 -0.0992  0.5629 10.7263 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  3.2411  1.8003  
#  text      (Intercept)  0.1207  0.3474  
#  Residual              39.4682  6.2824  
# Number of obs: 7156, groups:  word_type, 2123; text, 6
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                 17.4141     0.4647   37.47
# word_class_relevant_no_auxV                                  3.7737     0.5112    7.38
# word_length_characters_normalized                            0.5646     0.2131    2.65
# word_position_normalized                                     0.8543     0.5302    1.61
# word_length_characters_normalized:word_position_normalized  -0.4325     0.2733   -1.58
# word_class_relevant_no_auxV:word_position_normalized        -3.3974     0.6300   -5.39
# 
# Correlation of Fixed Effects:
#             (Intr) wr____V wrd___ wrd_p_ w___:_
# wrd_cls___V -0.767                             
# wrd_lngth__ -0.148 -0.121                      
# wrd_pstn_nr -0.851  0.739   0.152              
# wrd_ln__:__  0.126  0.102  -0.904 -0.181       
# wrd____V:__  0.683 -0.904   0.097 -0.793 -0.109

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml)
#                                word_class_relevant_no_auxV                          word_length_characters_normalized 
#                                                 0.26159228                                                 0.09039249 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                                 0.03551812                                                -0.05341004 
#       word_class_relevant_no_auxV:word_position_normalized 
#                                                -0.19680702 

# Test random effects
# Output has changed slighlty from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized
#                 npar logLik   AIC    LRT Df Pr(>Chisq)    
# <none>             9 -23520 47058                         
# (1 | text)         8 -23524 47063   7.69  1   0.005552 ** 
# (1 | word_type)    8 -23577 47169 113.56  1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="text"] = pchisq(7.69,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="word type"] = pchisq(113.56,1,lower.tail=FALSE)

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="poq"))
model <- prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml

data$P <- ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized'])
data$V <- fixef(model)['word_class_relevant_no_auxV']

min(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.3762986

max(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 3.547175

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_no_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']))
# [1] 1.110762

# Beyond maximal position of 1

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
# TRUE 
# 7156 

table(data$word_class_relevant_no_aux,fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#   TRUE
# N 2136
# V 5020

prop.table(table(fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
# TRUE 
#  100 

prop.table(table(data$word_class_relevant_no_aux,fixef(model)['word_class_relevant_no_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_no_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_no_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1) * 100
#   TRUE
# N  100
# V  100

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_no_aux:word_position_normalized + (1 | 
#     text) + (1 | word_type)
#                                                            Df   AIC     LRT   Pr(Chi)    
# <none>                                                        47051                      
# word_length_characters_normalized:word_position_normalized  1 47052  2.5182    0.1125    
# word_class_relevant_no_aux:word_position_normalized         1 47078 28.9218 7.536e-08 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="word length:position"] = pchisq(2.5182,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="word class:position"] = pchisq(28.9218,1,lower.tail=FALSE)

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_other.no_pos.popoluca.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.popoluca.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.popoluca.reml:     word_position_normalized + (1 | text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml:     text) + (1 | word_type)
#                                                                       Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.popoluca.reml     7 47110 47158 -23548    47096              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml  9 47051 47113 -23517    47033 62.759      2
#                                                                       Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.no_pos.popoluca.reml                  
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml  2.355e-14 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="word class"] = pchisq(62.759,2,lower.tail=FALSE)

# Test word position
prewindow.articulation_speed.n_vs_v.aux_other.no_position.popoluca.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux + word_length_characters_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="poq")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_position.popoluca.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.popoluca.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.popoluca.reml:     word_length_characters_normalized + (1 | text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml:     text) + (1 | word_type)
#                                                                         Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.popoluca.reml  6 47114 47156 -23551    47102              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml    9 47051 47113 -23517    47033 68.906      3
#                                                                         Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_other.no_position.popoluca.reml               
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml    7.321e-15 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="position"] = pchisq(68.906,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.popoluca.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_no_aux * word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=language_iso_code=="poq")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.popoluca.reml,prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.popoluca.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux * 
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.popoluca.reml:     word_position_normalized + (1 | text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml: pre_word_window_articulation_rate ~ word_class_relevant_no_aux + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml:     word_class_relevant_no_aux:word_position_normalized + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml:     text) + (1 | word_type)
#                                                                            Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.popoluca.reml  7 47058 47106 -23522    47044              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml       9 47051 47113 -23517    47033 10.687      2
#                                                                            Pr(>Chisq)   
# prewindow.articulation_speed.n_vs_v.aux_other.no_word_length.popoluca.reml              
# prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml        0.004779 **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="word length"] = pchisq(10.687,2,lower.tail=FALSE)


## Alternative study including auxiliaries (AUX)

# Baure (same as main study, no auxiliaries in Baure)
prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + word_length_characters_normalized:word_position_normalized + word_class_relevant_aux:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="brg")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_v.no_pos.baure.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="brg")),REML=F)

summary(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_aux +  
#     word_length_characters_normalized + word_position_normalized +  
#     word_length_characters_normalized:word_position_normalized +  
#     word_class_relevant_aux:word_position_normalized + (1 | speaker) +      (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  
#     subset = language_iso_code == "brg"))
# 
# REML criterion at convergence: 33219.5
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.7083 -0.6072 -0.0695  0.5028  8.5189 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  2.5955  1.6110  
#  text      (Intercept)  0.7027  0.8382  
#  speaker   (Intercept)  0.0000  0.0000  
#  Residual              20.4177  4.5186  
# Number of obs: 5573, groups:  word_type, 2761; text, 37; speaker, 10
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                13.48444    0.35233   38.27
# word_class_relevant_auxV                                    0.59520    0.38968    1.53
# word_length_characters_normalized                           0.02516    0.19624    0.13
# word_position_normalized                                   -0.28062    0.37581   -0.75
# word_length_characters_normalized:word_position_normalized  0.23473    0.25189    0.93
# word_class_relevant_auxV:word_position_normalized           0.02427    0.48673    0.05
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___ wrd_p_ w___:_
# wrd_clss__V -0.666                            
# wrd_lngth__ -0.130 -0.322                     
# wrd_pstn_nr -0.814  0.671  0.133              
# wrd_ln__:__  0.103  0.305 -0.889 -0.155       
# wrd_c__V:__  0.580 -0.900  0.308 -0.694 -0.360

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml)
#                                   word_class_relevant_auxV                          word_length_characters_normalized 
#                                                0.059327125                                                0.004655940 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                               -0.017550123                                                0.034395836 
#          word_class_relevant_auxV:word_position_normalized 
#                                                0.001993117 

# Test random effects with function from lmerTests
# Output has changed slighlty from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>            10 -16610 33239                          
# (1 | speaker)      9 -16610 33237   0.000  1          1    
# (1 | text)         9 -16638 33294  56.021  1  7.169e-14 ***
# (1 | word_type)    9 -16682 33382 144.539  1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="brg"))
model <- prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml

data$P <- ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized'])
data$V <- fixef(model)['word_class_relevant_auxV']

min(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.5967197

max(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.6194702

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']))
# [1] -24.52705

# Below minimal position of 0

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
# TRUE 
# 5573 

table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#   TRUE
# N 2099
# V 3474

prop.table(table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
# TRUE 
#  100 

prop.table(table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1)*100
#   TRUE
# N  100
# V  100

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
#     (1 | text) + (1 | word_type)
#                                                            Df   AIC     LRT Pr(Chi)
# <none>                                                        33231                
# word_length_characters_normalized:word_position_normalized  1 33230 0.86796  0.3515
# word_class_relevant_aux:word_position_normalized            1 33229 0.00268  0.9587

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_v.no_pos.baure.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.baure.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.baure.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.baure.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml:     word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml:     (1 | text) + (1 | word_type)
#                                                                Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)   
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.baure.reml     8 33240 33293 -16612    33224                            
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml 10 33231 33297 -16606    33211 13.004      2     0.0015 **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Test word position
prewindow.articulation_speed.n_vs_v.aux_v.no_position.baure.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="brg")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_position.baure.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.baure.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.baure.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.baure.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml:     word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml:     (1 | text) + (1 | word_type)
#                                                                  Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.baure.reml  7 33226 33273 -16606    33212                         
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml   10 33231 33297 -16606    33211 1.2636      3     0.7378

# Test word length
prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.baure.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="brg")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.baure.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.baure.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.baure.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.baure.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml:     word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml:     (1 | text) + (1 | word_type)
#                                                                     Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.baure.reml  8 33232 33285 -16608    33216              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml      10 33231 33297 -16606    33211 5.2189      2
#                                                                     Pr(>Chisq)  
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.baure.reml             
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml         0.07357 .
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# Bora (same as main study, no auxiliaries in Bora)
prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="boa")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_v.no_pos.bora.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="boa")),REML=F)

summary(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_aux +  
#     word_length_characters_normalized + word_position_normalized +  
#     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized +  
#     (1 | speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  
#     subset = language_iso_code == "boa"))
# 
# REML criterion at convergence: 65915.7
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.8317 -0.5588 -0.1346  0.3814 14.0731 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  2.840   1.685   
#  speaker   (Intercept) 15.153   3.893   
#  text      (Intercept)  1.077   1.038   
#  Residual              30.398   5.513   
# Number of obs: 10396, groups:  word_type, 5002; speaker, 43; text, 37
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                17.33048    0.73753  23.498
# word_class_relevant_auxV                                    0.14497    0.28948   0.501
# word_length_characters_normalized                           0.41350    0.15127   2.734
# word_position_normalized                                   -0.40326    0.33289  -1.211
# word_class_relevant_auxV:word_position_normalized          -0.02107    0.41114  -0.051
# word_length_characters_normalized:word_position_normalized  0.21600    0.20642   1.046
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___ wrd_p_ w___V:
# wrd_clss__V -0.225                            
# wrd_lngth__ -0.045 -0.146                     
# wrd_pstn_nr -0.275  0.650  0.117              
# wrd_c__V:__  0.206 -0.876  0.125 -0.770       
# wrd_ln__:__  0.039  0.117 -0.881 -0.139 -0.151

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml)
#                                   word_class_relevant_auxV                          word_length_characters_normalized 
#                                                0.011492738                                                0.063169815 
#                                   word_position_normalized          word_class_relevant_auxV:word_position_normalized 
#                                               -0.019618457                                               -0.001370713 
# word_length_characters_normalized:word_position_normalized 
#                                                0.024047625 

# Test random effects
# Output has changed slighlty from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_class_relevant_aux:word_position_normalized + 
#     word_length_characters_normalized:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>            10 -32958 65936                          
# (1 | speaker)      9 -33003 66023  89.635  1  < 2.2e-16 ***
# (1 | text)         9 -33001 66021  87.197  1  < 2.2e-16 ***
# (1 | word_type)    9 -33010 66037 103.293  1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="boa"))
model <- prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml

data$P <- ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized'])
data$V <- fixef(model)['word_class_relevant_auxV']

min(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.1238985

max(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.1444803

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']))
# [1] 6.879827

# Higher than maximal position of 1

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#  TRUE 
# 10396 

table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#   TRUE
# N 3974
# V 6422

prop.table(table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
# TRUE 
#  100 

prop.table(table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1)*100
#   TRUE
# N  100
# V  100

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                            Df   AIC     LRT Pr(Chi)
# <none>                                                        65929                
# word_class_relevant_aux:word_position_normalized            1 65927 0.00254  0.9598
# word_length_characters_normalized:word_position_normalized  1 65928 1.09624  0.2951

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_v.no_pos.bora.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.bora.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.bora.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.bora.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                               Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.bora.reml     8 65925 65983 -32955    65909                         
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml 10 65929 66001 -32954    65909 0.8966      2     0.6387

# Test word position
prewindow.articulation_speed.n_vs_v.aux_v.no_position.bora.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="boa")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_position.bora.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.bora.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.bora.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.bora.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                 Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.bora.reml  7 65926 65977 -32956    65912                         
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml   10 65929 66001 -32954    65909 3.9197      3     0.2703

prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.bora.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="boa")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.bora.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.bora.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.bora.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.bora.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                    Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.bora.reml  8 65985 66043 -32984    65969                         
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml      10 65929 66001 -32954    65909 60.267      2   8.19e-14
#                                                                       
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.bora.reml    
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml      ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# Chintang (same as main study, no auxiliaries in Chintang)
prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="ctn")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_v.no_pos.chintang.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="ctn")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_aux +  
#     word_length_characters_normalized + word_position_normalized +  
#     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized +  
#     (1 | speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  
#     subset = language_iso_code == "ctn"))
# 
# REML criterion at convergence: 71704.6
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.8230 -0.6421 -0.0411  0.6032 13.2801 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  1.8278  1.3520  
#  speaker   (Intercept)  2.7855  1.6690  
#  text      (Intercept)  0.9473  0.9733  
#  Residual              35.5085  5.9589  
# Number of obs: 11091, groups:  word_type, 4707; speaker, 68; text, 40
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                16.12746    0.37503   43.00
# word_class_relevant_auxV                                    1.30964    0.31881    4.11
# word_length_characters_normalized                           0.22441    0.17127    1.31
# word_position_normalized                                   -0.04501    0.35378   -0.13
# word_class_relevant_auxV:word_position_normalized          -0.20591    0.45641   -0.45
# word_length_characters_normalized:word_position_normalized  0.12682    0.22210    0.57
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___ wrd_p_ w___V:
# wrd_clss__V -0.391                            
# wrd_lngth__ -0.162 -0.173                     
# wrd_pstn_nr -0.548  0.561  0.191              
# wrd_c__V:__  0.371 -0.890  0.170 -0.695       
# wrd_ln__:__  0.145  0.180 -0.918 -0.205 -0.222

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml)
#                                   word_class_relevant_auxV                          word_length_characters_normalized 
#                                                 0.10023584                                                 0.03469687 
#                                   word_position_normalized          word_class_relevant_auxV:word_position_normalized 
#                                                -0.00200571                                                -0.01342610 
# word_length_characters_normalized:word_position_normalized 
#                                                 0.01584175 

# Test random effects
# Output has changed slighlty from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_class_relevant_aux:word_position_normalized + 
#     word_length_characters_normalized:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>            10 -35852 71725                          
# (1 | speaker)      9 -35937 71892 169.114  1  < 2.2e-16 ***
# (1 | text)         9 -35868 71754  31.407  1  2.093e-08 ***
# (1 | word_type)    9 -35897 71812  89.733  1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="ctn"))
model <- prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml

data$P <- ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized'])
data$V <- fixef(model)['word_class_relevant_auxV']

min(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 1.103721

max(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 1.298196

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']))
# [1] 6.360095

# Higher than the maximal position of 1

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#  TRUE 
# 11091 

table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#   TRUE
# N 4279
# V 6812

prop.table(table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
# TRUE 
#  100 

prop.table(table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1)*100
#   TRUE
# N  100
# V  100

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                            Df   AIC     LRT Pr(Chi)
# <none>                                                        71716                
# word_class_relevant_aux:word_position_normalized            1 71714 0.20380  0.6517
# word_length_characters_normalized:word_position_normalized  1 71714 0.32609  0.5680

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_v.no_pos.chintang.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.chintang.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.chintang.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.chintang.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                   Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.chintang.reml     8 71778 71837 -35881    71762                         
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml 10 71716 71789 -35848    71696 66.195      2  4.226e-15
#                                                                      
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.chintang.reml       
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Test word position
prewindow.articulation_speed.n_vs_v.aux_v.no_position.chintang.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="ctn")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_position.chintang.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.chintang.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.chintang.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.chintang.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                     Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.chintang.reml  7 71711 71762 -35848    71697              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml   10 71716 71789 -35848    71696 0.6199      3
#                                                                     Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.chintang.reml           
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml       0.8919

# Test word length
prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.chintang.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="ctn")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.chintang.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.chintang.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.chintang.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.chintang.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml:     word_length_characters_normalized + word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml:     word_class_relevant_aux:word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                        Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.chintang.reml  8 71734 71792 -35859    71718              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml      10 71716 71789 -35848    71696 21.757      2
#                                                                        Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.chintang.reml               
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml       1.886e-05 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# Dutch (same as main study, no auxiliaries annotated in Dutch)
prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_aux:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="nld")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_v.no_pos.dutch.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="nld")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_aux:word_position_normalized + (1 | speaker) +      (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  
#     subset = language_iso_code == "nld"))
# 
# REML criterion at convergence: 62382.7
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.9096 -0.5939 -0.0906  0.4909 14.3112 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  1.626   1.275   
#  speaker   (Intercept)  2.511   1.584   
#  text      (Intercept)  1.902   1.379   
#  Residual              46.693   6.833   
# Number of obs: 9285, groups:  word_type, 2382; speaker, 42; text, 17
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                 21.0532     0.5675   37.10
# word_class_relevant_auxV                                     1.2707     0.4111    3.09
# word_length_characters_normalized                           -0.1204     0.1804   -0.67
# word_position_normalized                                    -0.3159     0.5108   -0.62
# word_length_characters_normalized:word_position_normalized   0.4236     0.2365    1.79
# word_class_relevant_auxV:word_position_normalized           -1.4302     0.5553   -2.58
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___ wrd_p_ w___:_
# wrd_clss__V -0.553                            
# wrd_lngth__ -0.384  0.392                     
# wrd_pstn_nr -0.594  0.759  0.502              
# wrd_ln__:__  0.346 -0.372 -0.895 -0.575       
# wrd_c__V:__  0.506 -0.887 -0.357 -0.829  0.375

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml)
#                                   word_class_relevant_auxV                          word_length_characters_normalized 
#                                                 0.08476204                                                -0.01901462 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                                -0.01351140                                                 0.05037751 
#          word_class_relevant_auxV:word_position_normalized 
#                                                -0.07184220 

# Test random effects
# Output has changed slighlty from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>            10 -31191 62403                          
# (1 | speaker)      9 -31261 62540 139.422  1    < 2e-16 ***
# (1 | text)         9 -31193 62404   3.231  1    0.07225 .  
# (1 | word_type)    9 -31251 62520 118.823  1    < 2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="nld"))
model <- prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml

data$P <- ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized'])
data$V <- fixef(model)['word_class_relevant_auxV']

min(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] -0.1594685

max(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 1.258198

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']))
# [1] 0.8885001

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
# FALSE  TRUE 
#  2337  6948 

table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#   FALSE TRUE
# N  1000 2466
# V  1337 4482

prop.table(table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
#    FALSE     TRUE 
# 25.16963 74.83037 

prop.table(table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1) * 100
#      FALSE     TRUE
# N 28.85170 71.14830
# V 22.97646 77.02354

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
#     (1 | text) + (1 | word_type)
#                                                            Df   AIC    LRT Pr(Chi)  
# <none>                                                        62397                 
# word_length_characters_normalized:word_position_normalized  1 62398 3.1967 0.07379 .
# word_class_relevant_aux:word_position_normalized            1 62401 6.6244 0.01006 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_v.no_pos.dutch.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.dutch.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.dutch.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.dutch.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml:     (1 | text) + (1 | word_type)
#                                                                Df   AIC   BIC logLik deviance Chisq Chi Df Pr(>Chisq)   
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.dutch.reml     8 62402 62459 -31193    62386                           
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml 10 62397 62468 -31188    62377 9.652      2   0.008019 **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Test word position
prewindow.articulation_speed.n_vs_v.aux_v.no_position.dutch.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="nld")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_position.dutch.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.dutch.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.dutch.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.dutch.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml:     (1 | text) + (1 | word_type)
#                                                                  Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.dutch.reml  7 62421 62471 -31204    62407                         
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml   10 62397 62468 -31188    62377 30.899      3  8.926e-07
#                                                                     
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.dutch.reml    
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml   ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Test word length
prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.dutch.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="nld")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.dutch.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.dutch.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.dutch.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.dutch.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml:     (1 | text) + (1 | word_type)
#                                                                     Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.dutch.reml  8 62400 62457 -31192    62384              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml      10 62397 62468 -31188    62377 7.5891      2
#                                                                     Pr(>Chisq)  
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.dutch.reml             
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml         0.02249 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# English
prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_aux:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="eng")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_v.no_pos.english.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="eng")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_aux:word_position_normalized + (1 | speaker) +      (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  
#     subset = language_iso_code == "eng"))
# 
# REML criterion at convergence: 127926.5
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.9853 -0.6440 -0.0635  0.5306  9.4461 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  2.461   1.5689  
#  speaker   (Intercept)  3.337   1.8269  
#  text      (Intercept)  0.594   0.7707  
#  Residual              46.808   6.8416  
# Number of obs: 19027, groups:  word_type, 2794; speaker, 80; text, 47
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                 19.0318     0.3562   53.43
# word_class_relevant_auxV                                    -0.2910     0.3064   -0.95
# word_length_characters_normalized                           -0.3498     0.1389   -2.52
# word_position_normalized                                    -0.6450     0.3463   -1.86
# word_length_characters_normalized:word_position_normalized   0.5796     0.1827    3.17
# word_class_relevant_auxV:word_position_normalized            1.0075     0.4133    2.44
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___ wrd_p_ w___:_
# wrd_clss__V -0.598                            
# wrd_lngth__ -0.384  0.316                     
# wrd_pstn_nr -0.646  0.736  0.420              
# wrd_ln__:__  0.309 -0.323 -0.845 -0.505       
# wrd_c__V:__  0.541 -0.848 -0.347 -0.825  0.399

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml)
#                                   word_class_relevant_auxV                          word_length_characters_normalized 
#                                                -0.01904027                                                -0.05240247 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                                -0.02571379                                                 0.05853871 
#          word_class_relevant_auxV:word_position_normalized 
#                                                 0.04486380 

# Test random effects
# Output has changed slighlty from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized
#                 npar logLik    AIC    LRT Df Pr(>Chisq)    
# <none>            10 -63963 127947                         
# (1 | speaker)      9 -64157 128333 388.29  1  < 2.2e-16 ***
# (1 | text)         9 -63970 127958  13.10  1  0.0002946 ***
# (1 | word_type)    9 -64385 128788 843.42  1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="speaker"] = pchisq(388.29,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="text"] = pchisq(13.10,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="word type"] = pchisq(843.42,1,lower.tail=FALSE)

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="eng"))
model <- prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml

data$P <- ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized'])
data$V <- fixef(model)['word_class_relevant_auxV']

min(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] -0.2719679

max(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.7164858

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']))
# [1] 0.2888213

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
# FALSE  TRUE 
#  4415 14612 
   
table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#   FALSE TRUE
# N   878 6151
# V  3537 8461

prop.table(table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
#    FALSE     TRUE 
# 23.20387 76.79613 

prop.table(table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1) * 100
#      FALSE     TRUE
# N 12.49111 87.50889
# V 29.47991 70.52009

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
#     (1 | text) + (1 | word_type)
#                                                            Df    AIC     LRT Pr(Chi)   
# <none>                                                        127937                   
# word_length_characters_normalized:word_position_normalized  1 127945 10.0664 0.00151 **
# word_class_relevant_aux:word_position_normalized            1 127941  5.9427 0.01478 * 
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="word length:position"] = pchisq(10.0664,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="word class:position"] = pchisq(5.9427,1,lower.tail=FALSE)

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_v.no_pos.english.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.english.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.english.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.english.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml:     (1 | text) + (1 | word_type)
#                                                                  Df    AIC    BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.english.reml     8 127944 128006 -63964   127928                         
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml 10 127937 128016 -63959   127917 10.351      2   0.005653
#                                                                    
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.english.reml      
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="word class"] = pchisq(10.351,2,lower.tail=FALSE)

# Test word position
prewindow.articulation_speed.n_vs_v.aux_v.no_position.english.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="eng")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_position.english.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.english.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.english.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.english.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml:     (1 | text) + (1 | word_type)
#                                                                    Df    AIC    BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.english.reml  7 127944 127999 -63965   127930              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml   10 127937 128016 -63959   127917 12.998      3
#                                                                    Pr(>Chisq)   
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.english.reml              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml     0.004641 **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="position"] = pchisq(12.998,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.english.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="eng")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.english.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.english.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.english.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.english.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml:     (1 | text) + (1 | word_type)
#                                                                       Df    AIC    BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.english.reml  8 127943 128006 -63964   127927              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml      10 127937 128016 -63959   127917 10.163      2
#                                                                       Pr(>Chisq)   
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.english.reml              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml        0.006212 **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="word length"] = pchisq(10.163,2,lower.tail=FALSE)


# Even
prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_aux:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="eve")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_v.no_pos.even.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="eve")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_aux:word_position_normalized + (1 | speaker) +      (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  
#     subset = language_iso_code == "eve"))
# 
# REML criterion at convergence: 72569.7
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -3.4699 -0.6095  0.0012  0.6046  6.3514 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  1.0458  1.023   
#  text      (Intercept)  0.5761  0.759   
#  speaker   (Intercept)  1.3535  1.163   
#  Residual              12.2807  3.504   
# Number of obs: 13379, groups:  word_type, 5787; text, 67; speaker, 31
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                14.22151    0.27537   51.65
# word_class_relevant_auxV                                    0.60001    0.15686    3.83
# word_length_characters_normalized                           0.29539    0.08593    3.44
# word_position_normalized                                    0.37095    0.17928    2.07
# word_length_characters_normalized:word_position_normalized -0.10932    0.12075   -0.91
# word_class_relevant_auxV:word_position_normalized          -0.02215    0.22508   -0.10
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___ wrd_p_ w___:_
# wrd_clss__V -0.288                            
# wrd_lngth__ -0.120 -0.130                     
# wrd_pstn_nr -0.367  0.583  0.193              
# wrd_ln__:__  0.096  0.106 -0.874 -0.241       
# wrd_c__V:__  0.261 -0.866  0.120 -0.719 -0.123

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml)
#                                   word_class_relevant_auxV                          word_length_characters_normalized 
#                                                0.076701000                                                0.069609877 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                                0.028757664                                               -0.018369477 
#          word_class_relevant_auxV:word_position_normalized 
#                                               -0.002320067 

# Test random effects
# Output has changed slighlty from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>            10 -36285 72590                          
# (1 | speaker)      9 -36319 72655  67.430  1  < 2.2e-16 ***
# (1 | text)         9 -36367 72751 163.330  1  < 2.2e-16 ***
# (1 | word_type)    9 -36326 72670  82.132  1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="speaker"] = pchisq(67.430,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="text"] = pchisq(163.330,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="word type"] = pchisq(82.132,1,lower.tail=FALSE)

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="eve"))
model <- prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml

data$P <- ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized'])
data$V <- fixef(model)['word_class_relevant_auxV']

min(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.5778678

max(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.5995967

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']))
# [1] 27.09268

# Higher than maximal position of 1

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#  TRUE 
# 13379 

table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#   TRUE
# N 5342
# V 8037

prop.table(table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
# TRUE 
#  100 

prop.table(table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1) * 100
#   TRUE
# N  100
# V  100

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
#     (1 | text) + (1 | word_type)
#                                                            Df   AIC     LRT Pr(Chi)
# <none>                                                        72575                
# word_length_characters_normalized:word_position_normalized  1 72574 0.82083  0.3649
# word_class_relevant_aux:word_position_normalized            1 72573 0.00968  0.9216

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="word length:position"] = pchisq(0.82083,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="word class:position"] = pchisq(0.00968,1,lower.tail=FALSE)

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_v.no_pos.even.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.even.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.even.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.even.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml:     (1 | text) + (1 | word_type)
#                                                               Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.even.reml     8 72626 72686 -36305    72610                             
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml 10 72575 72650 -36277    72555 55.371      2  9.468e-13 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="word class"] = pchisq(55.371,2,lower.tail=FALSE)

# Test word position
prewindow.articulation_speed.n_vs_v.aux_v.no_position.even.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="eve")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_position.even.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.even.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.even.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.even.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml:     (1 | text) + (1 | word_type)
#                                                                 Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)  
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.even.reml  7 72577 72630 -36282    72563                           
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml   10 72575 72650 -36277    72555 8.5518      3    0.03588 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="position"] = pchisq(8.5518,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.even.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="eve")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.even.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.even.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.even.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.even.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml:     (1 | text) + (1 | word_type)
#                                                                    Df   AIC   BIC logLik deviance Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.even.reml  8 72601 72661 -36293    72585                        
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml      10 72575 72650 -36277    72555 30.53      2  2.347e-07
#                                                                       
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.even.reml    
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml      ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="word length"] = pchisq(30.53,2,lower.tail=FALSE)


# Hoocąk
prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_aux:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="win")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_v.no_pos.hoocak.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="win")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_aux:word_position_normalized + (1 | speaker) +      (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  
#     subset = language_iso_code == "win"))
# 
# REML criterion at convergence: 41196.2
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -3.1013 -0.5999 -0.0517  0.4901 16.3966 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  0.7523  0.8674  
#  text      (Intercept)  1.3730  1.1718  
#  speaker   (Intercept)  2.9353  1.7133  
#  Residual              14.1145  3.7569  
# Number of obs: 7413, groups:  word_type, 3843; text, 62; speaker, 28
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                12.05920    0.44216  27.273
# word_class_relevant_auxV                                    0.67783    0.24135   2.808
# word_length_characters_normalized                           0.07401    0.11115   0.666
# word_position_normalized                                    0.67578    0.36036   1.875
# word_length_characters_normalized:word_position_normalized -0.01153    0.15259  -0.076
# word_class_relevant_auxV:word_position_normalized          -0.05159    0.40360  -0.128
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___ wrd_p_ w___:_
# wrd_clss__V -0.362                            
# wrd_lngth__ -0.074 -0.144                     
# wrd_pstn_nr -0.383  0.674  0.110              
# wrd_ln__:__  0.067  0.135 -0.891 -0.120       
# wrd_c__V:__  0.325 -0.851  0.112 -0.864 -0.141

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml)
#                                   word_class_relevant_auxV                          word_length_characters_normalized 
#                                                0.066439758                                                0.017605994 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                                0.047861127                                               -0.002059933 
#          word_class_relevant_auxV:word_position_normalized 
#                                               -0.004627366 

# Test random effects
# Output has changed slighlty from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>            10 -20598 41216                          
# (1 | speaker)      9 -20628 41274  59.548  1  1.194e-14 ***
# (1 | text)         9 -20704 41427 212.593  1  < 2.2e-16 ***
# (1 | word_type)    9 -20616 41250  36.203  1  1.778e-09 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="speaker"] = pchisq(59.548,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="text"] = pchisq(212.593,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="word type"] = pchisq(36.203,1,lower.tail=FALSE)

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="win"))
model <- prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml

data$P <- ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized'])
data$V <- fixef(model)['word_class_relevant_auxV']

min(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.6262362

max(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.6772406

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']))
# [1] 13.13857

# Higher than maximal position of 1

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
# TRUE 
# 7413 

table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#   TRUE
# N 1646
# V 5767

prop.table(table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
# TRUE 
#  100 

prop.table(table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1) * 100
#   TRUE
# N  100
# V  100

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
#     (1 | text) + (1 | word_type)
#                                                            Df   AIC       LRT Pr(Chi)
# <none>                                                        41206                  
# word_length_characters_normalized:word_position_normalized  1 41204 0.0055704  0.9405
# word_class_relevant_aux:word_position_normalized            1 41204 0.0165147  0.8977

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="word length:position"] = pchisq(0.0055704,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="word class:position"] = pchisq(0.0165147,1,lower.tail=FALSE)

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_v.no_pos.hoocak.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.hoocak.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.hoocak.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.hoocak.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml:     (1 | text) + (1 | word_type)
#                                                                 Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.hoocak.reml     8 41228 41283 -20606    41212                         
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml 10 41206 41275 -20593    41186 26.306      2  1.939e-06
#                                                                    
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.hoocak.reml       
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="word class"] = pchisq(26.306,2,lower.tail=FALSE)

# Test word position
prewindow.articulation_speed.n_vs_v.aux_v.no_position.hoocak.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="win")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_position.hoocak.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.hoocak.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.hoocak.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.hoocak.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml:     (1 | text) + (1 | word_type)
#                                                                   Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.hoocak.reml  7 41215 41264 -20601    41201                         
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml   10 41206 41275 -20593    41186 15.645      3   0.001341
#                                                                     
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.hoocak.reml   
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml   **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="position"] = pchisq(15.645,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.hoocak.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="win")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.hoocak.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.hoocak.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.hoocak.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.hoocak.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml:     (1 | text) + (1 | word_type)
#                                                                      Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.hoocak.reml  8 41204 41259 -20594    41188              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml      10 41206 41275 -20593    41186 1.7446      2
#                                                                      Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.hoocak.reml           
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml           0.418

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="word length"] = pchisq(1.7446,2,lower.tail=FALSE)


# Nǁng (same as main study, no auxiliaries in Nǁng)
prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_aux:word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="ngh")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_v.no_pos.nuu.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="ngh")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_aux:word_position_normalized + (1 | speaker) +      (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  
#     subset = language_iso_code == "ngh"))
# 
# REML criterion at convergence: 58220.9
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.5065 -0.5934 -0.1112  0.4386 10.7282 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  1.591   1.261   
#  text      (Intercept)  1.512   1.230   
#  speaker   (Intercept)  3.289   1.814   
#  Residual              35.604   5.967   
# Number of obs: 9029, groups:  word_type, 1097; text, 33; speaker, 7
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                16.95072    0.86850  19.517
# word_class_relevant_auxV                                    0.14442    0.48332   0.299
# word_length_characters_normalized                           0.32211    0.27100   1.189
# word_position_normalized                                   -1.12141    0.53527  -2.095
# word_length_characters_normalized:word_position_normalized -0.04722    0.30448  -0.155
# word_class_relevant_auxV:word_position_normalized          -0.38113    0.55768  -0.683
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___ wrd_p_ w___:_
# wrd_clss__V -0.450                            
# wrd_lngth__ -0.296  0.262                     
# wrd_pstn_nr -0.501  0.787  0.492              
# wrd_ln__:__  0.272 -0.258 -0.924 -0.549       
# wrd_c__V:__  0.416 -0.927 -0.253 -0.824  0.277

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml)
#                                   word_class_relevant_auxV                          word_length_characters_normalized 
#                                                0.010587771                                                0.043739158 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                               -0.048620860                                               -0.005700973 
#          word_class_relevant_auxV:word_position_normalized 
#                                               -0.024409696 

# Test random effects
# Output has changed slighlty from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>            10 -29110 58241                          
# (1 | speaker)      9 -29131 58280  41.455  1  1.206e-10 ***
# (1 | text)         9 -29222 58462 222.780  1  < 2.2e-16 ***
# (1 | word_type)    9 -29161 58340 101.197  1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="ngh"))
model <- prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml

data$P <- ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized'])
data$V <- fixef(model)['word_class_relevant_auxV']

min(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] -0.2367082

max(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.1253658

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']))
# [1] 0.3789314

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
# FALSE  TRUE 
#  7753  1276 

table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#   FALSE TRUE
# N  2678  315
# V  5075  961

prop.table(table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
#    FALSE     TRUE 
# 85.86776 14.13224 

prop.table(table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1) * 100
#      FALSE     TRUE
# N 89.47544 10.52456
# V 84.07886 15.92114

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
#     (1 | text) + (1 | word_type)
#                                                            Df   AIC     LRT Pr(Chi)
# <none>                                                        58237                
# word_length_characters_normalized:word_position_normalized  1 58235 0.02445  0.8757
# word_class_relevant_aux:word_position_normalized            1 58235 0.46912  0.4934

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_v.no_pos.nuu.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.nuu.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.nuu.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.nuu.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml:     (1 | text) + (1 | word_type)
#                                                              Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.nuu.reml     8 58234 58291 -29109    58218                         
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml 10 58237 58308 -29108    58217 1.2718      2     0.5294

# Test word position
prewindow.articulation_speed.n_vs_v.aux_v.no_position.nuu.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="ngh")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_position.nuu.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.nuu.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.nuu.reml:     word_length_characters_normalized + (1 | speaker) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.nuu.reml:     text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml:     (1 | text) + (1 | word_type)
#                                                                Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.nuu.reml  7 58264 58314 -29125    58250                             
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml   10 58237 58308 -29108    58217 33.625      3  2.377e-07 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Test word length
prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.nuu.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="ngh")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.nuu.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.nuu.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.nuu.reml:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.nuu.reml:     word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml:     word_class_relevant_aux:word_position_normalized + (1 | speaker) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml:     (1 | text) + (1 | word_type)
#                                                                   Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.nuu.reml  8 58240 58297 -29112    58224                         
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml      10 58237 58308 -29108    58217 7.4765      2     0.0238
#                                                                    
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.nuu.reml  
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml      *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# Texistepec Popoluca
prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized * word_position_normalized + word_class_relevant_aux:word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="poq")),REML=T)

prewindow.articulation_speed.n_vs_v.aux_v.no_pos.popoluca.reml = lmer(pre_word_window_articulation_rate ~ word_length_characters_normalized * word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="poq")),REML=T)

summary(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml)
# Linear mixed model fit by REML ['lmerMod']
# Formula: pre_word_window_articulation_rate ~ word_class_relevant_aux +  
#     word_length_characters_normalized * word_position_normalized +  
#     word_class_relevant_aux:word_position_normalized + (1 | text) +      (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  
#     subset = language_iso_code == "poq"))
# 
# REML criterion at convergence: 55434.7
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.5587 -0.6717 -0.0958  0.5670 11.1545 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept)  2.6531  1.6288  
#  text      (Intercept)  0.1182  0.3438  
#  Residual              41.3111  6.4274  
# Number of obs: 8395, groups:  word_type, 2153; text, 6
# 
# Fixed effects:
#                                                            Estimate Std. Error t value
# (Intercept)                                                 17.4430     0.4674   37.32
# word_class_relevant_auxV                                     3.7716     0.5036    7.49
# word_length_characters_normalized                            0.4991     0.1990    2.51
# word_position_normalized                                     0.7799     0.5374    1.45
# word_length_characters_normalized:word_position_normalized  -0.2839     0.2560   -1.11
# word_class_relevant_auxV:word_position_normalized           -3.5040     0.6231   -5.62
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___ wrd_p_ w___:_
# wrd_clss__V -0.802                            
# wrd_lngth__ -0.136 -0.046                     
# wrd_pstn_nr -0.858  0.778  0.138              
# wrd_ln__:__  0.116  0.028 -0.897 -0.167       
# wrd_c__V:__  0.720 -0.905  0.020 -0.832 -0.029

# Standardized coefficients
lm.beta.lmer(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml)
#                                   word_class_relevant_auxV                          word_length_characters_normalized 
#                                                 0.24610971                                                 0.08117600 
#                                   word_position_normalized word_length_characters_normalized:word_position_normalized 
#                                                 0.03213008                                                -0.03415842 
#          word_class_relevant_auxV:word_position_normalized 
#                                                -0.18955375 

# Test random effects
# Output has changed slighlty from last version of lmerTest (both format and numbers)
library(lmerTest)
ranova(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml)
# ANOVA-like table for random-effects: Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | text) + (1 | word_type) + word_length_characters_normalized:word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized
#                 npar logLik   AIC     LRT Df Pr(>Chisq)    
# <none>             9 -27717 55453                          
# (1 | text)         8 -27722 55459   8.671  1   0.003234 ** 
# (1 | word_type)    8 -27768 55552 100.989  1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Need to unload lmerTest in order to use drop1 with Chisq-Test option
detach("package:lmerTest", unload=TRUE)

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="text"] = pchisq(8.671,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="word type"] = pchisq(100.989,1,lower.tail=FALSE)

# Check effect of interaction, following suggestions by Balthasar Bickel and Damian Blasi
data <- droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="poq"))
model <- prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml

data$P <- ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized'])
data$V <- fixef(model)['word_class_relevant_auxV']

min(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 0.2675795

max(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized)
# [1] 3.58716

# Point of reversing articulation rate difference between verbs and nouns?
as.numeric(-1 * fixef(model)['word_class_relevant_auxV'] / ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']))
# [1] 1.076364

# Beyond maximal position of 1

# Amount of data on either side of potential reversal
table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
# TRUE 
# 8395 

table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0)
#   TRUE
# N 2136
# V 6259

prop.table(table(fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0))*100
# TRUE 
#  100 

prop.table(table(data$word_class_relevant_aux,fixef(model)['word_class_relevant_auxV'] + ifelse(is.na(fixef(model)['word_class_relevant_auxV:word_position_normalized']),0,fixef(model)['word_class_relevant_auxV:word_position_normalized']) * data$word_position_normalized >= 0),1) * 100
#   TRUE
# N  100
# V  100

# Test fixed effects
drop1(prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml,test="Chisq")
# Single term deletions
# 
# Model:
# pre_word_window_articulation_rate ~ word_class_relevant_aux + 
#     word_length_characters_normalized * word_position_normalized + 
#     word_class_relevant_aux:word_position_normalized + (1 | text) + 
#     (1 | word_type)
#                                                            Df   AIC     LRT   Pr(Chi)    
# <none>                                                        55446                      
# word_length_characters_normalized:word_position_normalized  1 55445  1.2423     0.265    
# word_class_relevant_aux:word_position_normalized            1 55475 31.4705 2.025e-08 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="word length:position"] = pchisq(1.2423,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="word class:position"] = pchisq(31.4705,1,lower.tail=FALSE)

# Test word class
anova(prewindow.articulation_speed.n_vs_v.aux_v.no_pos.popoluca.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.popoluca.reml: pre_word_window_articulation_rate ~ word_length_characters_normalized * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.popoluca.reml:     word_position_normalized + (1 | text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml:     word_class_relevant_aux:word_position_normalized + (1 | text) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml:     (1 | word_type)
#                                                                   Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.popoluca.reml     7 55505 55554 -27746    55491                         
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml  9 55446 55509 -27714    55428 62.994      2  2.094e-14
#                                                                      
# prewindow.articulation_speed.n_vs_v.aux_v.no_pos.popoluca.reml       
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="word class"] = pchisq(62.994,2,lower.tail=FALSE)

# Test word position
prewindow.articulation_speed.n_vs_v.aux_v.no_position.popoluca.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux + word_length_characters_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="poq")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_position.popoluca.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.popoluca.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.popoluca.reml:     word_length_characters_normalized + (1 | text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml:     word_class_relevant_aux:word_position_normalized + (1 | text) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml:     (1 | word_type)
#                                                                     Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.popoluca.reml  6 55517 55559 -27753    55505              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml    9 55446 55509 -27714    55428 77.297      3
#                                                                     Pr(>Chisq)    
# prewindow.articulation_speed.n_vs_v.aux_v.no_position.popoluca.reml               
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml    < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="position"] = pchisq(77.297,3,lower.tail=FALSE)

# Test word length
prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.popoluca.reml = lmer(pre_word_window_articulation_rate ~ word_class_relevant_aux * word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=language_iso_code=="poq")),REML=T)

anova(prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.popoluca.reml,prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml,test="Chisq")
# refitting model(s) with ML (instead of REML)
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,  ...
# Models:
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.popoluca.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux * 
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.popoluca.reml:     word_position_normalized + (1 | text) + (1 | word_type)
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml: pre_word_window_articulation_rate ~ word_class_relevant_aux + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml:     word_length_characters_normalized * word_position_normalized + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml:     word_class_relevant_aux:word_position_normalized + (1 | text) + 
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml:     (1 | word_type)
#                                                                        Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.popoluca.reml  7 55455 55504 -27720    55441              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml       9 55446 55509 -27714    55428 12.942      2
#                                                                        Pr(>Chisq)   
# prewindow.articulation_speed.n_vs_v.aux_v.no_word_length.popoluca.reml              
# prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml        0.001547 **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Collect p values in data frame for multiple testing correction
p.values$p.value[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="word length"] = pchisq(12.942,2,lower.tail=FALSE)


### Further information about pre-word context windows for study of articulation rate ###

# Number of orthographic characters per pre-word context window
summary(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_length_characters)
#  Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 1.000   4.000   7.000   6.989   9.000  45.000 

sd(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_length_characters)
# [1] 3.357432

by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_length_characters,INDICES=combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language,summary)
# 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Baure
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   2.000   4.000   5.000   5.957   8.000  18.000 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Bora
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   1.000   5.000   7.000   7.604  10.000  45.000 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Chintang
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   1.000   5.000   7.000   7.251   9.000  21.000 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Dutch
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   1.000   5.000   8.000   8.131  11.000  24.000 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : English
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   1.000   5.000   8.000   7.617  10.000  22.000 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Even
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   1.000   5.000   7.000   6.811   9.000  19.000 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Hoocąk
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   1.000   4.000   6.000   6.292   8.000  44.000 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Nǁng
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   1.000   3.000   5.000   5.033   7.000  17.000 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Texistepec
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   1.000   4.000   6.000   6.893   9.000  23.000 

# Articulation rate
summary(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate)
#  Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 1.165  12.821  16.327  17.167  20.474 129.032 

sd(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate)
# [1] 6.574954

by(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_articulation_rate,INDICES=combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language,summary)
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Baure
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   2.198  10.769  13.514  13.915  16.667  55.556 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Bora
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   1.721  13.462  16.279  17.214  19.802 108.696 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Chintang
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   1.165  12.903  17.073  17.309  21.311 104.651 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Dutch
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#    1.98   16.44   20.04   20.85   24.48  129.03 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : English
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   1.453  14.286  18.421  19.008  23.077  85.106 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Even
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   2.347  12.422  14.827  14.876  17.241  37.634 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Hoocąk
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   2.484  10.161  12.448  12.877  14.981  82.090 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Nǁng
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   2.551  12.195  15.385  16.234  19.048  80.000 
# --------------------------------------------------------------------------------------------------- 
# combined.wordtimes.prewindows.publish.articulation_rate.no_aux : Texistepec
#    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#   3.736  14.642  18.433  19.219  23.077  93.750 


  
### Analysis of pause probability ###

## Information about data ##

# Initial state of data before cleaning (including all parts-of-speech)

# Morphemes
with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language),FUN=function(x) length(x)))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   # 33116    66049    68501    39519    61560    71268    41045    29530    39688

sum(with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language),FUN=function(x) length(x))))
# [1] 450276

# Parts-of-speech by language (not distinguishing auxiliaries, AUX)
with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(x)))[]
#             N     V  PRO OTHER FLDPS  BPN  BPP
# Baure    2811  5230  378 10410    NA 6861   NA
# Bora     5915  8270 4648  9306   592 5541 1148
# Chintang 6622  8775 5091 17473    NA 6307 1069
# Dutch    3973  6687 5768 21300  1791   NA   NA
# English  7777 12777 7937 27632   224   NA   NA
# Even     8835 10168 1640 16792    NA 5934 2242
# Hoocąk   3726  9104 2097 14348    NA 4215  157
# Nǁng     4416  7474 6421  7792    NA   NA   NA
# Texistepec 2932  8781 1892  8716    NA 6715  804

# Parts-of-speech overall
colSums(with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(x))),na.rm=T)
 #     N      V    PRO  OTHER  FLDPS    BPN    BPP 
 # 47007  77266  35872 133769   2607  35573   5420 

# Parts-of-speech by language (distinguishing auxiliaries, AUX)
with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(x)))[]
#             N     V  AUX  PRO OTHER FLDPS  BPN  BPP
# Baure    2811  5230   NA  378 10410    NA 6861   NA
# Bora     5915  8270   NA 4648  9306   592 5541 1148
# Chintang 6622  8775   NA 5091 17473    NA 6307 1069
# Dutch    3973  6687   NA 5768 21300  1791   NA   NA
# English  7777 10903 1874 7937 27632   224   NA   NA
# Even     8835  9543  625 1640 16792    NA 5934 2242
# Hoocąk   3726  7104 2000 2097 14348    NA 4215  157
# Nǁng     4416  7474   NA 6421  7792    NA   NA   NA
# Texistepec 2932  6731 2050 1892  8716    NA 6715  804

# Parts-of-speech overall (distinguishing auxiliaries, AUX)
colSums(with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(x))),na.rm=T)
 #     N      V    AUX    PRO  OTHER  FLDPS    BPN    BPP 
 # 47007  70717   6549  35872 133769   2607  35573   5420 

# Words
with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   # 17652    29802    37737    39519    56135    37430    23191    26061    21321

# All languages
sum(with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 288848

# Word classes by language (not distinguishing auxiliaries, AUX)
with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V  PRO OTHER FLDPS  BPN  BPP
# Baure    2778  5213  378 10237    NA 5376   NA
# Bora     5913  8269 4645  9298   592 5464 1148
# Chintang 6607  8659 5090 17470    NA 4010 1069
# Dutch    3973  6687 5768 21300  1791   NA   NA
# English  7777 12777 7936 27628   224   NA   NA
# Even     8835 10168 1640 16787    NA 5918 2202
# Hoocąk   3683  7967 2082 13844    NA 3570  150
# Nǁng     4415  7466 6421  7787    NA   NA   NA
# Texistepec 2738  8321 1892  8691    NA 5911  804

# Word classes overall (not distinguishing auxiliaries, AUX)
colSums(with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N      V    PRO  OTHER  FLDPS    BPN    BPP 
# 46719  75527  35852 133042   2607  30249   5373 

# Word classes by language (distinguishing auxiliaries, AUX)
with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX  PRO OTHER FLDPS  BPN  BPP
# Baure    2778  5213   NA  378 10237    NA 5376   NA
# Bora     5913  8269   NA 4645  9298   592 5464 1148
# Chintang 6607  8659   NA 5090 17470    NA 4010 1069
# Dutch    3973  6687   NA 5768 21300  1791   NA   NA
# English  7777 10903 1874 7936 27628   224   NA   NA
# Even     8835  9543  625 1640 16787    NA 5918 2202
# Hoocąk   3683  6903 1550 2082 13844    NA 3570  150
# Nǁng     4415  7466   NA 6421  7787    NA   NA   NA
# Texistepec 2738  6272 2050 1892  8691    NA 5911  804

# Word classes overall (distinguishing auxiliaries, AUX)
colSums(with(combined.wordtimes.prewindows.publish,by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
 #     N      V    AUX    PRO  OTHER  FLDPS    BPN    BPP 
 # 46719  69915   6099  35852 133042   2607  30249   5373 


## --- Relevant data set for main study excluding auxiliaries (AUX)

# Only keep N and V
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  7917    14181    15263    10660    18677    18378     9954    11881     8866

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 115777

# Word classes by language
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V AUX PRO OTHER FLDPS BPN BPP
# Baure    2778  5213  NA  NA    NA    NA  NA  NA
# Bora     5913  8269  NA  NA    NA    NA  NA  NA
# Chintang 6607  8659  NA  NA    NA    NA  NA  NA
# Dutch    3973  6687  NA  NA    NA    NA  NA  NA
# English  7777 10903  NA  NA    NA    NA  NA  NA
# Even     8835  9543  NA  NA    NA    NA  NA  NA
# Hoocąk   3670  6417  NA  NA    NA    NA  NA  NA
# Nǁng     4415  7466  NA  NA    NA    NA  NA  NA
# Texistepec 2738  6271  NA  NA    NA    NA  NA  NA

# Word classes overall
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 46706 69428     0     0     0     0     0     0 

# Exclude pre-word windows that include multiple different roots at the same time
ambiguous.words = with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all)),intersect(word_id[word_class_relevant_no_aux=="N"],word_id[word_class_relevant_no_aux=="V"]))

with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  7843    14180    15260    10660    18674    18378     9821    11881     8723

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 115420

# Word classes by language
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V AUX PRO OTHER FLDPS BPN BPP
# Baure    2704  5139  NA  NA    NA    NA  NA  NA
# Bora     5912  8268  NA  NA    NA    NA  NA  NA
# Chintang 6604  8656  NA  NA    NA    NA  NA  NA
# Dutch    3973  6687  NA  NA    NA    NA  NA  NA
# English  7774 10900  NA  NA    NA    NA  NA  NA
# Even     8835  9543  NA  NA    NA    NA  NA  NA
# Hoocąk   3537  6284  NA  NA    NA    NA  NA  NA
# Nǁng     4415  7466  NA  NA    NA    NA  NA  NA
# Texistepec 2595  6128  NA  NA    NA    NA  NA  NA

# Word classes overall
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 46349 69071     0     0     0     0     0     0 

# Excluding words without a pre-word window (first words in annotation units)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6474    13476    12364    10164    18315    17215     9149     9724     7603

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 104484

# Word classes by language
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V AUX PRO OTHER FLDPS BPN BPP
# Baure    2454  4020  NA  NA    NA    NA  NA  NA
# Bora     5566  7910  NA  NA    NA    NA  NA  NA
# Chintang 4985  7379  NA  NA    NA    NA  NA  NA
# Dutch    3863  6301  NA  NA    NA    NA  NA  NA
# English  7542 10773  NA  NA    NA    NA  NA  NA
# Even     7980  9235  NA  NA    NA    NA  NA  NA
# Hoocąk   3091  6058  NA  NA    NA    NA  NA  NA
# Nǁng     3336  6388  NA  NA    NA    NA  NA  NA
# Texistepec 2393  5210  NA  NA    NA    NA  NA  NA

# Word classes overall
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 41210 63274     0     0     0     0     0     0 

# Eliminate words with missing word frequency information
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6474    13476    12364    10164    18315    17215     9149     9722     7603

# Only happens in Nǁng. Only occurs with (acoustically) doubtful words or false starts (count as disfluencies for paper!)

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 104482

# Word classes by language
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V AUX PRO OTHER FLDPS BPN BPP
# Baure    2454  4020  NA  NA    NA    NA  NA  NA
# Bora     5566  7910  NA  NA    NA    NA  NA  NA
# Chintang 4985  7379  NA  NA    NA    NA  NA  NA
# Dutch    3863  6301  NA  NA    NA    NA  NA  NA
# English  7542 10773  NA  NA    NA    NA  NA  NA
# Even     7980  9235  NA  NA    NA    NA  NA  NA
# Hoocąk   3091  6058  NA  NA    NA    NA  NA  NA
# Nǁng     3336  6386  NA  NA    NA    NA  NA  NA
# Texistepec 2393  5210  NA  NA    NA    NA  NA  NA

# Word classes overall
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 41210 63272     0     0     0     0     0     0 

# Throw out pre-word windows before filled pauses and false starts
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6474    13472    12347    10164    18294    17129     9149     9630     7595

sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 104254

# Word classes by language
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V AUX PRO OTHER FLDPS BPN BPP
# Baure    2454  4020  NA  NA    NA    NA  NA  NA
# Bora     5566  7906  NA  NA    NA    NA  NA  NA
# Chintang 4969  7378  NA  NA    NA    NA  NA  NA
# Dutch    3863  6301  NA  NA    NA    NA  NA  NA
# English  7521 10773  NA  NA    NA    NA  NA  NA
# Even     7948  9181  NA  NA    NA    NA  NA  NA
# Hoocąk   3091  6058  NA  NA    NA    NA  NA  NA
# Nǁng     3296  6334  NA  NA    NA    NA  NA  NA
# Texistepec 2386  5209  NA  NA    NA    NA  NA  NA

# Word classes overall
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 41094 63160     0     0     0     0     0     0 

# Eliminate words with a pre-word window of length 0 seconds
# (which can happen if the word before the target word is longer than one second and its midpoint thus occurs before the target
# pre-word window length of 0.5 seconds)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6364    13316    12283    10147    18282    17017     8825     9619     7586

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 103439

# Word classes by language
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V AUX PRO OTHER FLDPS BPN BPP
# Baure    2427  3937  NA  NA    NA    NA  NA  NA
# Bora     5507  7809  NA  NA    NA    NA  NA  NA
# Chintang 4942  7341  NA  NA    NA    NA  NA  NA
# Dutch    3853  6294  NA  NA    NA    NA  NA  NA
# English  7516 10766  NA  NA    NA    NA  NA  NA
# Even     7892  9125  NA  NA    NA    NA  NA  NA
# Hoocąk   2968  5857  NA  NA    NA    NA  NA  NA
# Nǁng     3290  6329  NA  NA    NA    NA  NA  NA
# Texistepec 2382  5204  NA  NA    NA    NA  NA  NA

# Word classes overall
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V") & !grepl("AUX", whole_word_word_class_all) & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 40777 62662     0     0     0     0     0     0 

# Check reduced data set (only one root per word)
with(combined.wordtimes.prewindows.publish.pause_probability.no_aux,by(word_id,language,length))[]
# language
#    Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
#     6364    13316    12283    10147    18282    17017     8825     9619     7586

# Word classes by language
with(combined.wordtimes.prewindows.publish.pause_probability.no_aux,by(word_id,list(language,word_class_relevant),length))[]
#             N     V
# Baure    2427  3937
# Bora     5507  7809
# Chintang 4942  7341
# Dutch    3853  6294
# English  7516 10766
# Even     7892  9125
# Hoocąk   2968  5857
# Nǁng     3290  6329
# Texistepec 2382  5204

# Reduction
100 - (with(combined.wordtimes.prewindows.publish.pause_probability.no_aux,by(word_id,language,function(x) length(unique(x))))[] * 100 / with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_no_aux %in% c("N","V") & !grepl("AUX", whole_word_word_class_all)),by(word_id,language,function (x) length(unique(x))))[])
# language
#     Baure      Bora  Chintang     Dutch   English      Even    Hoocąk      Nǁng  Texistepec
# 19.616016  6.099711 19.524340  4.812383  2.114901  7.405594 11.342174 19.038801 14.437176

# All languages
100 - (sum(with(combined.wordtimes.prewindows.publish.pause_probability.no_aux,by(word_id,language,function(x) length(unique(x))))) * 100 / sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_no_aux %in% c("N","V") & !grepl("AUX", whole_word_word_class_all)),by(word_id,language,function (x) length(unique(x))))))
# [1] 10.65669

# Word classes by language
100 - (with(combined.wordtimes.prewindows.publish.pause_probability.no_aux,by(word_id,list(language,word_class_relevant),function(x) length(unique(x))))[] * 100 / with(droplevels(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_no_aux %in% c("N","V") & !grepl("AUX", whole_word_word_class_all))),by(word_id,list(language,word_class_relevant),function (x) length(unique(x))))[])
#                  N         V
# Baure    12.634989 24.477268
# Bora      6.866227  5.562946
# Chintang 25.200545 15.221157
# Dutch     3.020388  5.877075
# English   3.356050  1.256535
# Even     10.673458  4.380174
# Hoocąk   19.128065  8.726819
# Nǁng     25.481314 15.229038
# Texistepec 13.002191 17.014830

# Word classes overall
100 - (colSums(with(combined.wordtimes.prewindows.publish.pause_probability.no_aux,by(word_id,list(language,word_class_relevant),function(x) length(unique(x)))),na.rm=T) * 100 / colSums(with(droplevels(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_no_aux %in% c("N","V") & !grepl("AUX", whole_word_word_class_all))),by(word_id,list(language,word_class_relevant),function (x) length(unique(x)))),na.rm=T))
#         N         V 
# 12.694301  9.745348 


## --- Relevant data set for alternative study including auxiliaries (AUX)

# Only keep N, V and AUX
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  7917    14181    15263    10660    20551    19003    11504    11881    10916

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 121876

# Word classes by language (not distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V PRO OTHER FLDPS BPN BPP
# Baure    2778  5213  NA    NA    NA  NA  NA
# Bora     5913  8269  NA    NA    NA  NA  NA
# Chintang 6607  8659  NA    NA    NA  NA  NA
# Dutch    3973  6687  NA    NA    NA  NA  NA
# English  7777 12777  NA    NA    NA  NA  NA
# Even     8835 10168  NA    NA    NA  NA  NA
# Hoocąk   3683  7967  NA    NA    NA  NA  NA
# Nǁng     4415  7466  NA    NA    NA  NA  NA
# Texistepec 2738  8321  NA    NA    NA  NA  NA

# Word classes overall (not distinguishing auxiliaries, AUX)
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   PRO OTHER FLDPS   BPN   BPP 
# 46719 75527     0     0     0     0     0 

# Word classes by language (distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX PRO OTHER FLDPS BPN BPP
# Baure    2778  5213   NA  NA    NA    NA  NA  NA
# Bora     5913  8269   NA  NA    NA    NA  NA  NA
# Chintang 6607  8659   NA  NA    NA    NA  NA  NA
# Dutch    3973  6687   NA  NA    NA    NA  NA  NA
# English  7777 10903 1874  NA    NA    NA  NA  NA
# Even     8835  9543  625  NA    NA    NA  NA  NA
# Hoocąk   3683  6903 1550  NA    NA    NA  NA  NA
# Nǁng     4415  7466   NA  NA    NA    NA  NA  NA
# Texistepec 2738  6272 2050  NA    NA    NA  NA  NA

# Word classes overall (distinguishing auxiliaries, AUX)
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 46719 69915  6099     0     0     0     0     0 

# Exclude pre-word windows that include multiple different roots at the same time
ambiguous.words = with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),intersect(word_id[word_class_relevant_aux=="N"],word_id[word_class_relevant_aux=="V"]))

with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  7843    14180    15260    10660    20548    19003    11358    11881    10773

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 121506

# Word classes by language (not distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V PRO OTHER FLDPS BPN BPP
# Baure    2704  5139  NA    NA    NA  NA  NA
# Bora     5912  8268  NA    NA    NA  NA  NA
# Chintang 6604  8656  NA    NA    NA  NA  NA
# Dutch    3973  6687  NA    NA    NA  NA  NA
# English  7774 12774  NA    NA    NA  NA  NA
# Even     8835 10168  NA    NA    NA  NA  NA
# Hoocąk   3537  7821  NA    NA    NA  NA  NA
# Nǁng     4415  7466  NA    NA    NA  NA  NA
# Texistepec 2595  8178  NA    NA    NA  NA  NA

# Word classes overall (not distinguishing auxiliaries, AUX)
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   PRO OTHER FLDPS   BPN   BPP 
# 46349 75157     0     0     0     0     0 

# Word classes by language (distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX PRO OTHER FLDPS BPN BPP
# Baure    2704  5139   NA  NA    NA    NA  NA  NA
# Bora     5912  8268   NA  NA    NA    NA  NA  NA
# Chintang 6604  8656   NA  NA    NA    NA  NA  NA
# Dutch    3973  6687   NA  NA    NA    NA  NA  NA
# English  7774 10900 1874  NA    NA    NA  NA  NA
# Even     8835  9543  625  NA    NA    NA  NA  NA
# Hoocąk   3537  6770 1537  NA    NA    NA  NA  NA
# Nǁng     4415  7466   NA  NA    NA    NA  NA  NA
# Texistepec 2595  6129 2050  NA    NA    NA  NA  NA

# Word classes overall (distinguishing auxiliaries, AUX)
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 46349 69558  6086     0     0     0     0     0 

# Excluding words without a pre-word window (first words in annotation units)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6474    13476    12364    10164    20185    17788    10647     9724     8959

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 109781

# Word classes by language (not distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V PRO OTHER FLDPS BPN BPP
# Baure    2454  4020  NA    NA    NA  NA  NA
# Bora     5566  7910  NA    NA    NA  NA  NA
# Chintang 4985  7379  NA    NA    NA  NA  NA
# Dutch    3863  6301  NA    NA    NA  NA  NA
# English  7542 12643  NA    NA    NA  NA  NA
# Even     7980  9808  NA    NA    NA  NA  NA
# Hoocąk   3091  7556  NA    NA    NA  NA  NA
# Nǁng     3336  6388  NA    NA    NA  NA  NA
# Texistepec 2393  6566  NA    NA    NA  NA  NA

# Word classes overall (not distinguishing auxiliaries, AUX)
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   PRO OTHER FLDPS   BPN   BPP 
# 41210 68571     0     0     0     0     0 

# Word classes by language (distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX PRO OTHER FLDPS BPN BPP
# Baure    2454  4020   NA  NA    NA    NA  NA  NA
# Bora     5566  7910   NA  NA    NA    NA  NA  NA
# Chintang 4985  7379   NA  NA    NA    NA  NA  NA
# Dutch    3863  6301   NA  NA    NA    NA  NA  NA
# English  7542 10773 1870  NA    NA    NA  NA  NA
# Even     7980  9235  573  NA    NA    NA  NA  NA
# Hoocąk   3091  6531 1498  NA    NA    NA  NA  NA
# Nǁng     3336  6388   NA  NA    NA    NA  NA  NA
# Texistepec 2393  5211 1356  NA    NA    NA  NA  NA

# Word classes overall (distinguishing auxiliaries, AUX)
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 41210 63748  5297     0     0     0     0     0 

# Eliminate words with missing word frequency information
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
#   Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
#    6474    13476    12364    10164    20185    17788    10647     9722     8959

# Only happens in Nǁng. Only occurs with (acoustically) doubtful words or false starts (count as disfluencies for paper!)

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 109779

# Word classes by language (not distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V PRO OTHER FLDPS BPN BPP
# Baure    2454  4020  NA    NA    NA  NA  NA
# Bora     5566  7910  NA    NA    NA  NA  NA
# Chintang 4985  7379  NA    NA    NA  NA  NA
# Dutch    3863  6301  NA    NA    NA  NA  NA
# English  7542 12643  NA    NA    NA  NA  NA
# Even     7980  9808  NA    NA    NA  NA  NA
# Hoocąk   3091  7556  NA    NA    NA  NA  NA
# Nǁng     3336  6386  NA    NA    NA  NA  NA
# Texistepec 2393  6566  NA    NA    NA  NA  NA

# Word classes overall (not distinguishing auxiliaries, AUX)
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   PRO OTHER FLDPS   BPN   BPP 
# 41210 68569     0     0     0     0     0 

# Word classes by language (distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX PRO OTHER FLDPS BPN BPP
# Baure    2454  4020   NA  NA    NA    NA  NA  NA
# Bora     5566  7910   NA  NA    NA    NA  NA  NA
# Chintang 4985  7379   NA  NA    NA    NA  NA  NA
# Dutch    3863  6301   NA  NA    NA    NA  NA  NA
# English  7542 10773 1870  NA    NA    NA  NA  NA
# Even     7980  9235  573  NA    NA    NA  NA  NA
# Hoocąk   3091  6531 1498  NA    NA    NA  NA  NA
# Nǁng     3336  6386   NA  NA    NA    NA  NA  NA
# Texistepec 2393  5211 1356  NA    NA    NA  NA  NA

# Word classes overall (distinguishing auxiliaries, AUX)
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency)),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 41210 63746  5297     0     0     0     0     0 

# Throw out pre-word windows before filled pauses and false starts
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6474    13472    12347    10164    20161    17700    10647     9630     8948

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 109543

# Word classes by language (not distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V PRO OTHER FLDPS BPN BPP
# Baure    2454  4020  NA    NA    NA  NA  NA
# Bora     5566  7906  NA    NA    NA  NA  NA
# Chintang 4969  7378  NA    NA    NA  NA  NA
# Dutch    3863  6301  NA    NA    NA  NA  NA
# English  7521 12640  NA    NA    NA  NA  NA
# Even     7948  9752  NA    NA    NA  NA  NA
# Hoocąk   3091  7556  NA    NA    NA  NA  NA
# Nǁng     3296  6334  NA    NA    NA  NA  NA
# Texistepec 2386  6562  NA    NA    NA  NA  NA

# Word classes overall (not distinguishing auxiliaries, AUX)
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   PRO OTHER FLDPS   BPN   BPP 
# 41094 68449     0     0     0     0     0 

# Word classes by language (distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX PRO OTHER FLDPS BPN BPP
# Baure    2454  4020   NA  NA    NA    NA  NA  NA
# Bora     5566  7906   NA  NA    NA    NA  NA  NA
# Chintang 4969  7378   NA  NA    NA    NA  NA  NA
# Dutch    3863  6301   NA  NA    NA    NA  NA  NA
# English  7521 10773 1867  NA    NA    NA  NA  NA
# Even     7948  9181  571  NA    NA    NA  NA  NA
# Hoocąk   3091  6531 1498  NA    NA    NA  NA  NA
# Nǁng     3296  6334   NA  NA    NA    NA  NA  NA
# Texistepec 2386  5210 1353  NA    NA    NA  NA  NA

# Word classes overall (distinguishing auxiliaries, AUX)
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*"),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 41094 63634  5289     0     0     0     0     0 

# Eliminate words with a pre-word window of length 0 seconds
# (which can happen if the word before the target word is longer than one second and its midpoint thus occurs before the target
# pre-word window length of 0.5 seconds)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x))))[]
   # Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
   #  6364    13316    12283    10147    20149    17588    10263     9619     8939

# All languages
sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language),FUN=function(x) length(unique(x)))))
# [1] 108668

# Word classes by language (not distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x))))[]
#             N     V PRO OTHER FLDPS BPN BPP
# Baure    2427  3937  NA    NA    NA  NA  NA
# Bora     5507  7809  NA    NA    NA  NA  NA
# Chintang 4942  7341  NA    NA    NA  NA  NA
# Dutch    3853  6294  NA    NA    NA  NA  NA
# English  7516 12633  NA    NA    NA  NA  NA
# Even     7892  9696  NA    NA    NA  NA  NA
# Hoocąk   2968  7295  NA    NA    NA  NA  NA
# Nǁng     3290  6329  NA    NA    NA  NA  NA
# Texistepec 2382  6557  NA    NA    NA  NA  NA

# Word classes overall (not distinguishing auxiliaries, AUX)
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language,word_class_relevant_aux),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   PRO OTHER FLDPS   BPN   BPP 
# 40777 67891     0     0     0     0     0 

# Word classes by language (distinguishing auxiliaries, AUX)
with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x))))[]
#             N     V  AUX PRO OTHER FLDPS BPN BPP
# Baure    2427  3937   NA  NA    NA    NA  NA  NA
# Bora     5507  7809   NA  NA    NA    NA  NA  NA
# Chintang 4942  7341   NA  NA    NA    NA  NA  NA
# Dutch    3853  6294   NA  NA    NA    NA  NA  NA
# English  7516 10766 1867  NA    NA    NA  NA  NA
# Even     7892  9125  571  NA    NA    NA  NA  NA
# Hoocąk   2968  6314 1438  NA    NA    NA  NA  NA
# Nǁng     3290  6329   NA  NA    NA    NA  NA  NA
# Texistepec 2382  5205 1353  NA    NA    NA  NA  NA

# Word classes overall (distinguishing auxiliaries, AUX)
colSums(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX") & !word_id %in% ambiguous.words & !is.na(pre_word_window_begin) & !is.na(word_frequency) & disfluency=="*" & pre_word_window_length_seconds > 0),by(word_id,INDICES=list(language,word_class_relevant),FUN=function(x) length(unique(x)))),na.rm=T)
#     N     V   AUX   PRO OTHER FLDPS   BPN   BPP 
# 40777 63120  5229     0     0     0     0     0 

# Check reduced data set (only one root per word)
with(combined.wordtimes.prewindows.publish.pause_probability.aux,by(word_id,language,length))[]
# language
#    Baure     Bora Chintang    Dutch  English     Even   Hoocąk     Nǁng Texistepec
#     6364    13316    12283    10147    20149    17588    10263     9619     8939

# All languages
sum(with(combined.wordtimes.prewindows.publish.pause_probability.aux,by(word_id,language,length))[])
# [1] 108668

# Word classes by language (not distinguishing auxiliaries, AUX)
with(combined.wordtimes.prewindows.publish.pause_probability.aux,by(word_id,list(language,word_class_relevant_aux),length))[]
#             N     V
# Baure    2427  3937
# Bora     5507  7809
# Chintang 4942  7341
# Dutch    3853  6294
# English  7516 12633
# Even     7892  9696
# Hoocąk   2968  7295
# Nǁng     3290  6329
# Texistepec 2382  6557

# Word classes overall (not distinguishing auxiliaries, AUX)
colSums(with(combined.wordtimes.prewindows.publish.pause_probability.aux,by(word_id,list(language,word_class_relevant_aux),length))[],na.rm=T)
#     N     V 
# 40777 67891 

# Word classes by language (distinguishing auxiliaries, AUX)
with(combined.wordtimes.prewindows.publish.pause_probability.aux,by(word_id,list(language,word_class_relevant),length))[]
#             N     V  AUX
# Baure    2427  3937   NA
# Bora     5507  7809   NA
# Chintang 4942  7341   NA
# Dutch    3853  6294   NA
# English  7516 10766 1867
# Even     7892  9125  571
# Hoocąk   2968  6314  981
# Nǁng     3290  6329   NA
# Texistepec 2382  5205 1352

# Word classes overall (distinguishing auxiliaries, AUX)
colSums(with(combined.wordtimes.prewindows.publish.pause_probability.aux,by(word_id,list(language,word_class_relevant),length))[],na.rm=T)
#     N     V   AUX 
# 40777 63120  4771 

# Reduction
100 - (with(combined.wordtimes.prewindows.publish.pause_probability.aux,by(word_id,language,function(x) length(unique(x))))[] * 100 / with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_aux %in% c("N","V")),by(word_id,language,function (x) length(unique(x))))[])
# language
#     Baure      Bora  Chintang     Dutch   English      Even    Hoocąk      Nǁng  Texistepec
# 19.616016  6.099711 19.524340  4.812383  1.956109  7.446193 10.787552 19.038801 18.111030

# All languages
100 - (sum(with(combined.wordtimes.prewindows.publish.pause_probability.aux,by(word_id,language,function(x) length(unique(x))))) * 100 / sum(with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_aux %in% c("N","V")),by(word_id,language,function (x) length(unique(x))))))
# [1] 10.83724

# Word classes by language (not distinguishing auxiliaries, AUX)
100 - (with(combined.wordtimes.prewindows.publish.pause_probability.aux,by(word_id,list(language,word_class_relevant_aux),function(x) length(unique(x))))[] * 100 / with(droplevels(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_aux %in% c("N","V"))),by(word_id,list(language,word_class_relevant_aux),function (x) length(unique(x))))[])
#                  N         V
# Baure    12.634989 24.477268
# Bora      6.866227  5.562946
# Chintang 25.200545 15.221157
# Dutch     3.020388  5.877075
# English   3.356050  1.127025
# Even     10.673458  4.642014
# Hoocąk   19.413522  8.434794
# Nǁng     25.481314 15.229038
# Texistepec 13.002191 21.199375

# Word classes overall (not distinguishing auxiliaries, AUX)
100 - (colSums(with(combined.wordtimes.prewindows.publish.pause_probability.aux,by(word_id,list(language,word_class_relevant_aux),function(x) length(unique(x)))),na.rm=T) * 100 / colSums(with(droplevels(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_aux %in% c("N","V"))),by(word_id,list(language,word_class_relevant_aux),function (x) length(unique(x)))),na.rm=T))
#        N        V 
# 12.71859 10.11029 

# Word classes by language (distinguishing auxiliaries, AUX)
100 - (with(combined.wordtimes.prewindows.publish.pause_probability.aux,by(word_id,list(language,word_class_relevant),function(x) length(unique(x))))[] * 100 / with(droplevels(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_aux %in% c("N","V"))),by(word_id,list(language,word_class_relevant),function (x) length(unique(x))))[])
#                    N         V        AUX
# Baure      12.634989 24.477268         NA
# Bora        6.866227  5.562946         NA
# Chintang   25.200545 15.221157         NA
# Dutch       3.020388  5.877075         NA
# English     3.356050  1.256535  0.3735326
# Even       10.673458  4.380174  8.6400000
# Hoocąk     19.413522  8.532522 36.7096774   # AUX corrected to 7.800752
# Nǁng       25.481314 15.229038         NA
# Texistepec 13.002191 17.012117 34.0487805   # AUX corrected to 34.01659

# AUX percentages for Hoocąk and Texistepec needed to be corrected because of words containing AUX and V roots at the same time
# which were only included as V in the reduced data set (combined.wordtimes.prewindows.publish.pause_probability.aux) but are still included
# with both roots in the original data set (combined.wordtimes.prewindows.publish).
# The correct number of pre-word windows before auxiliaries (AUX) is equal to the number of all pre-word windows
# minus the number of pre-word windows before nouns (N) and minus the number of pre-word windows before verbs (V).

# Word classes overall (distinguishing auxiliaries, AUX)
100 - (colSums(with(combined.wordtimes.prewindows.publish.pause_probability.aux,by(word_id,list(language,word_class_relevant),function(x) length(unique(x)))),na.rm=T) * 100 / colSums(with(droplevels(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant_aux %in% c("N","V"))),by(word_id,list(language,word_class_relevant),function (x) length(unique(x)))),na.rm=T))
#         N         V       AUX 
# 12.718594  9.718944 21.774061 # AUX corrected to 14.98574

# The AUX percentage needed to be corrected because of words containing AUX and V roots at the same time
# which were only included as V in the reduced data set (combined.wordtimes.prewindows.publish.pause_probability.aux) but are still included
# with both roots in the original data set (combined.wordtimes.prewindows.publish).
# The correct number of pre-word windows before auxiliaries (AUX) is equal to the number of all pre-word windows
# minus the number of pre-word windows before nouns (N) and minus the number of pre-word windows before verbs (V).


## --- Statistics for main study excluding auxiliaries (AUX)

# Overall number of relevant pre-word windows examined (of categories N or V excluding AUX)
length(unique(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_id))
# [1] 103439

# Distribution of examined pre-word windows by language
as.table(by(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_id,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code,FUN=length))
# combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code
#   boa   brg   ctn   eng   eve   ngh   nld   poq   win 
# 13316  6364 12283 18282 17017  9619 10147  7586  8825 

# Distribution of examined pre-word windows by part-of-speech of target word
as.table(by(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_id,combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux,FUN=length))
# combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux
#     N     V 
# 40777 62662 

# Distribution of examined pre-word windows by part-of-speech of target word (percentages)
prop.table(as.table(by(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_id,combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux,FUN=length)))*100
# combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux
#       N       V 
# 39.4213 60.5787 

# Distribution of examined pre-word windows by language and part-of-speech of target word
as.table(by(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_id,list(combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code,combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux),FUN=length))
#         N     V
# boa  5507  7809
# brg  2427  3937
# ctn  4942  7341
# eng  7516 10766
# eve  7892  9125
# ngh  3290  6329
# nld  3853  6294
# poq  2382  5204
# win  2968  5857

# Distribution of examined pre-word windows by language and part-of-speech of target word (percentages)
prop.table(as.table(by(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_id,list(combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code,combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux),FUN=length)),1)*100
#            N        V
# boa 41.35626 58.64374
# brg 38.13639 61.86361
# ctn 40.23447 59.76553
# eng 41.11148 58.88852
# eve 46.37715 53.62285
# ngh 34.20314 65.79686
# nld 37.97181 62.02819
# poq 31.39995 68.60005
# win 33.63173 66.36827

# Probability of silent pauses (AUX excluded)
table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$silent_pause_in_pre_word_window_factor)
#    no   yes 
# 83873 19566 

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$silent_pause_in_pre_word_window_factor)) * 100
#      no     yes 
# 81.0845 18.9155 

# Confidence intervals, using exact binomial method (Mid P) from library proportion (AUX excluded)
ciEXx(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$silent_pause_in_pre_word_window_factor)["yes"],sum(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$silent_pause_in_pre_word_window_factor)),alp=0.05,e=0.5)[c("LEXx","UEXx")]*100
#        LEXx     UEXx
# yes 18.6786 19.15659

# Probability of filled pauses (AUX excluded)
table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$filled_pause_in_pre_word_window_factor)
#     no    yes 
# 101253   2186 

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$filled_pause_in_pre_word_window_factor)) * 100
#        no       yes 
# 97.886677  2.113323 

# Confidence intervals, using exact binomial method (Mid P) (AUX excluded)
ciEXx(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$filled_pause_in_pre_word_window_factor)["yes"],sum(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$filled_pause_in_pre_word_window_factor)),alp=0.05,e=0.5)[c("LEXx","UEXx")]*100
#         LEXx     UEXx
# yes 2.023804 2.205427

# Probability of all pauses (including filled pauses) (AUX excluded)
table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$pause_in_pre_word_window_factor)
#    no   yes 
# 82160 21279 

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$pause_in_pre_word_window_factor)) * 100
#       no      yes 
# 79.42846 20.57154 

# Confidence intervals, using exact binomial method (Mid P) (AUX excluded)
ciEXx(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$pause_in_pre_word_window_factor)["yes"],sum(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$silent_pause_in_pre_word_window_factor)),alp=0.05,e=0.5)[c("LEXx","UEXx")]*100
#         LEXx     UEXx
# yes 20.32456 20.81754


# Probability of silent pauses per language (AUX excluded)
table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code)
#       boa   brg   ctn   eng   eve   ngh   nld   poq   win
# no   9247  5430 10752 15414 12445  8756  9257  6699  5873
# yes  4069   934  1531  2868  4572   863   890   887  2952

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code),2)*100
#           boa       brg       ctn       eng       eve       ngh       nld       poq       win
# no  69.442776 85.323696 87.535618 84.312438 73.132750 91.028173 91.228935 88.307408 66.549575
# yes 30.557224 14.676304 12.464382 15.687562 26.867250  8.971827  8.771065 11.692592 33.450425

# Confidence intervals, using exact binomial method (Mid P) (AUX excluded)
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.no_aux$silent_pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.no_aux$language),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.no_aux$language),c("LEXx","UEXx")))*100
#               LEXx      UEXx
# Baure    13.822229 15.561558
# Bora     29.777989 31.345009
# Chintang 11.887155 13.057794
# Dutch     8.232540  9.332859
# English  15.163637 16.221419
# Even     26.206050 27.536573
# Hoocąk   32.470981 34.440061
# Nǁng      8.412121  9.556078
# Texistepec 10.986084 12.433165

# Probability of filled pauses per language (AUX excluded)
table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code)
#       boa   brg   ctn   eng   eve   ngh   nld   poq   win
# no  13259  6249 12086 17901 16220  9614  9688  7573  8663
# yes    57   115   197   381   797     5   459    13   162

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code),2)*100
#             boa         brg         ctn         eng         eve         ngh         nld         poq         win
# no  99.57194353 98.19296040 98.39615729 97.91598293 95.31644826 99.94801954 95.47649552 99.82863169 98.16430595
# yes  0.42805647  1.80703960  1.60384271  2.08401707  4.68355174  0.05198046  4.52350448  0.17136831  1.83569405

# Confidence intervals, using exact binomial method (Mid P) (AUX excluded)
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.no_aux$filled_pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.no_aux$language),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.no_aux$language),c("LEXx","UEXx")))*100
#                LEXx      UEXx
# Baure    1.50026624 2.1561038
# Bora     0.33146186 0.5532237
# Chintang 1.39499953 1.8394132
# Dutch    4.13476213 4.9417616
# English  1.88425722 2.2999910
# Even     4.37453405 5.0113045
# Hoocąk   1.57350574 2.1349579
# Nǁng     0.01220703 0.1175276
# Texistepec 0.09196428 0.2866912

# Probability of all pauses per language (including filled pauses) (AUX excluded)
table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code)
#       boa   brg   ctn   eng   eve   ngh   nld   poq   win
# no   9223  5342 10582 15117 11878  8752  8846  6690  5730
# yes  4093  1022  1701  3165  5139   867  1301   896  3095

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code),2)*100
#           boa       brg       ctn       eng       eve       ngh       nld       poq       win
# no  69.262541 83.940918 86.151592 82.687890 69.800787 90.986589 87.178476 88.188769 64.929178
# yes 30.737459 16.059082 13.848408 17.312110 30.199213  9.013411 12.821524 11.811231 35.070822

# Confidence intervals, using exact binomial method (Mid P) (AUX excluded)
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.no_aux$pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.no_aux$language),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.no_aux$language),c("LEXx","UEXx")))*100
#               LEXx      UEXx
# Baure    15.171036 16.976475
# Bora     29.959428 31.525099
# Chintang 13.247137 14.466819
# Dutch    12.182329 13.481844
# English  16.769259 17.864147
# Even     29.513366 30.891640
# Hoocąk   34.077948 36.069437
# Nǁng      8.455941  9.600279
# Texistepec 11.096409 12.550485


# Probability of silent pauses by part-of-speech (AUX excluded)
table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux)
#         N     V
# no  31206 52667
# yes  9571  9995

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux),2)*100
#            N        V
# no  76.52844 84.04934
# yes 23.47156 15.95066

# Confidence intervals, using exact binomial method (Mid P) (AUX excluded)
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.no_aux$silent_pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux),c("LEXx","UEXx")))*100
#       LEXx     UEXx
# N 23.06525 23.88384
# V 15.66835 16.24075


# Probability of filled pauses by part-of-speech (AUX excluded)
table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux)
#         N     V
# no  39582 61671
# yes  1195   991

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux),2)*100
#             N         V
# no  97.069426 98.418499
# yes  2.930574  1.581501

# Confidence intervals (AUX excluded)
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.no_aux$filled_pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux),c("LEXx","UEXx")))*100
#       LEXx     UEXx
# N 2.770793 3.094722
# V 1.482393 1.682563

# Probability of all pauses by part-of-speech (AUX excluded)
table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux)
#         N     V
# no  30285 51875
# yes 10492 10787

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux),2)*100
#            N        V
# no  74.26981 82.78542
# yes 25.73019 17.21458

# Confidence intervals (AUX excluded)
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.no_aux$pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux),c("LEXx","UEXx")))*100
#       LEXx     UEXx
# N 25.30566 26.15431
# V 16.92152 17.51088


# Probability of silent pauses by language and part-of-speech of target word (AUX excluded)
table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux,combined.wordtimes.prewindows.publish.pause_probability.no_aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code)
# , ,  = boa
# 
#    
#       no  yes
#   N 3479 2028
#   V 5768 2041
# 
# , ,  = brg
# 
#    
#       no  yes
#   N 2044  383
#   V 3386  551
# 
# , ,  = ctn
# 
#    
#       no  yes
#   N 4136  806
#   V 6616  725
# 
# , ,  = eng
# 
#    
#       no  yes
#   N 6525  991
#   V 8889 1877
# 
# , ,  = eve
# 
#    
#       no  yes
#   N 5136 2756
#   V 7309 1816
# 
# , ,  = ngh
# 
#    
#       no  yes
#   N 2846  444
#   V 5910  419
# 
# , ,  = nld
# 
#    
#       no  yes
#   N 3502  351
#   V 5755  539
# 
# , ,  = poq
# 
#    
#       no  yes
#   N 1970  412
#   V 4729  475
# 
# , ,  = win
# 
#    
#       no  yes
#   N 1568 1400
#   V 4305 1552

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux,combined.wordtimes.prewindows.publish.pause_probability.no_aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code),c(1,3))*100
# , ,  = boa
# 
#    
#            no       yes
#   N 63.174142 36.825858
#   V 73.863491 26.136509
# 
# , ,  = brg
# 
#    
#            no       yes
#   N 84.219201 15.780799
#   V 86.004572 13.995428
# 
# , ,  = ctn
# 
#    
#            no       yes
#   N 83.690813 16.309187
#   V 90.123961  9.876039
# 
# , ,  = eng
# 
#    
#            no       yes
#   N 86.814795 13.185205
#   V 82.565484 17.434516
# 
# , ,  = eve
# 
#    
#            no       yes
#   N 65.078561 34.921439
#   V 80.098630 19.901370
# 
# , ,  = ngh
# 
#    
#            no       yes
#   N 86.504559 13.495441
#   V 93.379681  6.620319
# 
# , ,  = nld
# 
#    
#            no       yes
#   N 90.890215  9.109785
#   V 91.436289  8.563711
# 
# , ,  = poq
# 
#    
#            no       yes
#   N 82.703610 17.296390
#   V 90.872406  9.127594
# 
# , ,  = win
# 
#    
#            no       yes
#   N 52.830189 47.169811
#   V 73.501793 26.498207

ci_per_language_per_pos(combined.wordtimes.prewindows.publish.pause_probability.no_aux,variable="silent_pause_in_pre_word_window_factor",language="language_iso_code",pos="word_class_relevant_no_aux")
#    language pos   percent  lower.ci  upper.ci
# 1       boa   N 36.825858 35.558231 38.105522
# 2       brg   N 15.780799 14.371502 17.271961
# 3       ctn   N 16.309187 15.299051 17.357766
# 4       eng   N 13.185205 12.437430 13.969470
# 5       eve   N 34.921439 33.873468 35.977955
# 6       ngh   N 13.495441 12.360421 14.697643
# 7       nld   N  9.109785  8.230880 10.050054
# 8       poq   N 17.296390 15.817252 18.854842
# 10      win   N 47.169811 45.378895 48.969491
# 11      boa   V 26.136509 25.173533 27.119691
# 12      brg   V 13.995428 12.940263 15.102769
# 13      ctn   V  9.876039  9.209550 10.573341
# 14      eng   V 17.434516 16.728825 18.161078
# 15      eve   V 19.901370 19.091955 20.729164
# 16      ngh   V  6.620319  6.026747  7.251619
# 17      nld   V  8.563711  7.888193  9.273441
# 18      poq   V  9.127594  8.367901  9.934725
# 20      win   V 26.498207 25.378574 27.641492


# Probability of filled pauses by language and part-of-speech of target word (AUX excluded)
table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux,combined.wordtimes.prewindows.publish.pause_probability.no_aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code)
# , ,  = boa
# 
#    
#        no   yes
#   N  5475    32
#   V  7784    25
# 
# , ,  = brg
# 
#    
#        no   yes
#   N  2370    57
#   V  3879    58
# 
# , ,  = ctn
# 
#    
#        no   yes
#   N  4841   101
#   V  7245    96
# 
# , ,  = eng
# 
#    
#        no   yes
#   N  7340   176
#   V 10561   205
# 
# , ,  = eve
# 
#    
#        no   yes
#   N  7379   513
#   V  8841   284
# 
# , ,  = ngh
# 
#    
#        no   yes
#   N  3287     3
#   V  6327     2
# 
# , ,  = nld
# 
#    
#        no   yes
#   N  3636   217
#   V  6052   242
# 
# , ,  = poq
# 
#    
#        no   yes
#   N  2377     5
#   V  5196     8
# 
# , ,  = win
# 
#    
#        no   yes
#   N  2877    91
#   V  5786    71

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux,combined.wordtimes.prewindows.publish.pause_probability.no_aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code),c(1,3))*100
# , ,  = boa
# 
#    
#              no         yes
#   N 99.41892137  0.58107863
#   V 99.67985658  0.32014342
# 
# , ,  = brg
# 
#    
#              no         yes
#   N 97.65142151  2.34857849
#   V 98.52679705  1.47320295
# 
# , ,  = ctn
# 
#    
#              no         yes
#   N 97.95629300  2.04370700
#   V 98.69227626  1.30772374
# 
# , ,  = eng
# 
#    
#              no         yes
#   N 97.65832890  2.34167110
#   V 98.09585733  1.90414267
# 
# , ,  = eve
# 
#    
#              no         yes
#   N 93.49974658  6.50025342
#   V 96.88767123  3.11232877
# 
# , ,  = ngh
# 
#    
#              no         yes
#   N 99.90881459  0.09118541
#   V 99.96839943  0.03160057
# 
# , ,  = nld
# 
#    
#              no         yes
#   N 94.36802492  5.63197508
#   V 96.15506832  3.84493168
# 
# , ,  = poq
# 
#    
#              no         yes
#   N 99.79009236  0.20990764
#   V 99.84627210  0.15372790
# 
# , ,  = win,
# 
#    
#              no         yes
#   N 96.93396226  3.06603774
#   V 98.78777531  1.21222469

ci_per_language_per_pos(combined.wordtimes.prewindows.publish.pause_probability.no_aux,variable="filled_pause_in_pre_word_window_factor",language="language_iso_code",pos="word_class_relevant_no_aux")
#    language pos    percent    lower.ci  upper.ci
# 1       boa   N 0.58107863 0.405108495 0.8078710
# 2       brg   N 2.34857849 1.802421700 3.0118783
# 3       ctn   N 2.04370700 1.679258753 2.4659441
# 4       eng   N 2.34167110 2.016062261 2.7046308
# 5       eve   N 6.50025342 5.973360989 7.0587112
# 6       ngh   N 0.09118541 0.025522185 0.2492812
# 7       nld   N 5.63197508 4.937162625 6.3915639
# 8       poq   N 0.20990764 0.079570462 0.4648336
# 10      win   N 3.06603774 2.489656652 3.7365802
# 11      boa   V 0.32014342 0.214463579 0.4638497
# 12      brg   V 1.47320295 1.128427902 1.8873711
# 13      ctn   V 1.30772374 1.066842880 1.5900746
# 14      eng   V 1.90414267 1.659198669 2.1746318
# 15      eve   V 3.11232877 2.769733667 3.4860321
# 16      ngh   V 0.03160057 0.006103516 0.1040430
# 17      nld   V 3.84493168 3.391918288 4.3388234
# 18      poq   V 0.15372790 0.069867746 0.2946352
# 20      win   V 1.21222469 0.955648715 1.5173340


# Probability of all pauses (including filled pauses) by language and part-of-speech of target word (AUX excluded)
table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux,combined.wordtimes.prewindows.publish.pause_probability.no_aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code)
# , ,  = boa
# 
#    
#       no  yes
#   N 3468 2039
#   V 5755 2054
# 
# , ,  = brg
# 
#    
#       no  yes
#   N 2000  427
#   V 3342  595
# 
# , ,  = ctn
# 
#    
#       no  yes
#   N 4053  889
#   V 6529  812
# 
# , ,  = eng
# 
#    
#       no  yes
#   N 6388 1128
#   V 8729 2037
# 
# , ,  = eve
# 
#    
#       no  yes
#   N 4767 3125
#   V 7111 2014
# 
# , ,  = ngh
# 
#    
#       no  yes
#   N 2844  446
#   V 5908  421
# 
# , ,  = nld
# 
#    
#       no  yes
#   N 3309  544
#   V 5537  757
# 
# , ,  = poq
# 
#    
#       no  yes
#   N 1967  415
#   V 4723  481
# 
# , ,  = win
# 
#    
#       no  yes
#   N 1489 1479
#   V 4241 1616

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux,combined.wordtimes.prewindows.publish.pause_probability.no_aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language_iso_code),c(1,3))*100
# , ,  = boa
# 
#    
#           no      yes
#   N 62.97440 37.02560
#   V 73.69702 26.30298
# 
# , ,  = brg
# 
#    
#           no      yes
#   N 82.40626 17.59374
#   V 84.88697 15.11303
# 
# , ,  = ctn
# 
#    
#           no      yes
#   N 82.01133 17.98867
#   V 88.93884 11.06116
# 
# , ,  = eng
# 
#    
#           no      yes
#   N 84.99202 15.00798
#   V 81.07932 18.92068
# 
# , ,  = eve
# 
#    
#           no      yes
#   N 60.40294 39.59706
#   V 77.92877 22.07123
# 
# , ,  = ngh
# 
#    
#           no      yes
#   N 86.44377 13.55623
#   V 93.34808  6.65192
# 
# , ,  = nld
# 
#    
#           no      yes
#   N 85.88113 14.11887
#   V 87.97267 12.02733
# 
# , ,  = poq
# 
#    
#           no      yes
#   N 82.57767 17.42233
#   V 90.75711  9.24289
# 
# , ,  = win
# 
#    
#           no      yes
#   N 50.16846 49.83154
#   V 72.40908 27.59092

ci_per_language_per_pos(combined.wordtimes.prewindows.publish.pause_probability.no_aux,variable="pause_in_pre_word_window_factor",language="language_iso_code",pos="word_class_relevant_no_aux")
#    language pos  percent  lower.ci  upper.ci
# 1       boa   N 37.02560 35.757520 38.305292
# 2       brg   N 17.59374 16.117823 19.146738
# 3       ctn   N 17.98867 16.938803 19.078797
# 4       eng   N 15.00798 14.213843 15.831521
# 5       eve   N 39.59706 38.521322 40.678246
# 6       ngh   N 13.55623 12.421174 14.756649
# 7       nld   N 14.11887 13.045184 15.242875
# 8       poq   N 17.42233 15.938127 18.983931
# 10      win   N 49.83154 48.031140 51.629933
# 11      boa   V 26.30298 25.335732 27.288090
# 12      brg   V 15.11303 14.022250 16.254770
# 13      ctn   V 11.06116 10.359135 11.793602
# 14      eng   V 18.92068 18.187958 19.669606
# 15      eve   V 22.07123 21.229424 22.930845
# 16      ngh   V  6.65192  6.054490  7.283522
# 17      nld   V 12.02733 11.241235 12.847821
# 18      poq   V  9.24289  8.476581 10.056949
# 20      win   V 27.59092 26.454592 28.746371


## --- Statistics for alternative study including auxiliaries (AUX)

# Overall number of relevant pre-word windows examined (of categories N or V including AUX)
length(unique(combined.wordtimes.prewindows.publish.pause_probability.aux$word_id))
# [1] 108668

# Distribution of examined pre-word windows by language
as.table(by(combined.wordtimes.prewindows.publish.pause_probability.aux$word_id,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code,FUN=length))
# combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code
#   boa   brg   ctn   eng   eve   ngh   nld   poq   win 
# 13316  6364 12283 20149 17588  9619 10147  8939 10263 

# Distribution of examined pre-word windows by part-of-speech of target word
as.table(by(combined.wordtimes.prewindows.publish.pause_probability.aux$word_id,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux,FUN=length))
# combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux
#     N     V 
# 40777 67891 

# Distribution of examined pre-word windows by part-of-speech of target word (percentages)
prop.table(as.table(by(combined.wordtimes.prewindows.publish.pause_probability.aux$word_id,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux,FUN=length)))*100
# combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux
#        N        V 
# 37.52439 62.47561 

# Distribution of examined pre-word windows by part-of-speech of target word (AUX separately)
as.table(by(combined.wordtimes.prewindows.publish.pause_probability.aux$word_id,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant,FUN=length))
# combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant
#     N     V   AUX 
# 40777 63120  4771 

# Distribution of examined pre-word windows by part-of-speech of target word (AUX separately) (percentages)
prop.table(as.table(by(combined.wordtimes.prewindows.publish.pause_probability.aux$word_id,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant,FUN=length)))*100
# combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant
#         N         V       AUX 
# 37.524386 58.085177  4.390437 

# Distribution of examined pre-word windows by language and part-of-speech of target word
as.table(by(combined.wordtimes.prewindows.publish.pause_probability.aux$word_id,list(combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux),FUN=length))
#         N     V
# boa  5507  7809
# brg  2427  3937
# ctn  4942  7341
# eng  7516 12633
# eve  7892  9696
# ngh  3290  6329
# nld  3853  6294
# poq  2382  6557
# win  2968  7295

# Distribution of examined pre-word windows by language and part-of-speech of target word (percentages)
prop.table(as.table(by(combined.wordtimes.prewindows.publish.pause_probability.aux$word_id,list(combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux),FUN=length)),1)*100
#            N        V
# boa 41.35626 58.64374
# brg 38.13639 61.86361
# ctn 40.23447 59.76553
# eng 37.30210 62.69790
# eve 44.87150 55.12850
# ngh 34.20314 65.79686
# nld 37.97181 62.02819
# poq 26.64728 73.35272
# win 28.91942 71.08058

# Distribution of examined pre-word windows by language and part-of-speech of target word (AUX separately)
as.table(by(combined.wordtimes.prewindows.publish.pause_probability.aux$word_id,list(combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant),FUN=length))
#         N     V   AUX
# boa  5507  7809      
# brg  2427  3937      
# ctn  4942  7341      
# eng  7516 10766  1867
# eve  7892  9125   571
# ngh  3290  6329      
# nld  3853  6294      
# poq  2382  5205  1352
# win  2968  6314   981

# Distribution of examined pre-word windows by language and part-of-speech of target word (AUX separately) (percentages)
prop.table(as.table(by(combined.wordtimes.prewindows.publish.pause_probability.aux$word_id,list(combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant),FUN=length)),1)*100
#             N         V       AUX
# boa                              
# brg                              
# ctn                              
# eng 37.302099 53.431932  9.265969
# eve 44.871503 51.881965  3.246532
# ngh                              
# nld                              
# poq 26.647276 58.227990 15.124734
# win 28.919419 61.521972  9.558609

# Probability of silent pauses (assuming a threshold of 150 ms)
table(combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor)
#    no   yes 
# 88331 20337 

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor)) * 100
#      no     yes 
# 81.2852 18.7148 

# Confidence intervals, using exact binomial method (Mid P)
ciEXx(table(combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor)["yes"],sum(table(combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor)),alp=0.05,e=0.5)[c("LEXx","UEXx")]*100
#         LEXx     UEXx
# yes 18.48496 18.94927

# Probability of filled pauses
table(combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor)
#     no    yes 
# 106426   2242 

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor)) * 100
#        no       yes 
# 97.936835  2.063165 

# Confidence intervals, using exact binomial method (Mid P)
ciEXx(table(combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor)["yes"],sum(table(combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor)),alp=0.05,e=0.5)[c("LEXx","UEXx")]*100
#         LEXx     UEXx
# yes 1.977804 2.148253

# Probability of all pauses (including filled pauses)
table(combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor)
#    no   yes 
# 86568 22100 

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor)) * 100
#       no      yes 
# 79.66283 20.33717 

# Confidence intervals, using exact binomial method (Mid P)
ciEXx(table(combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor)["yes"],sum(table(combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor)),alp=0.05,e=0.5)[c("LEXx","UEXx")]*100
#         LEXx     UEXx
# yes 20.10022 20.57872

# Probability of silent pauses per language
table(combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code)
#       boa   brg   ctn   eng   eve   ngh   nld   poq   win
# no   9247  5430 10752 17035 12915  8756  9257  7882  7057
# yes  4069   934  1531  3114  4673   863   890  1057  3206

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code),2)*100
#           boa       brg       ctn       eng       eve       ngh       nld       poq       win
# no  69.442776 85.323696 87.535618 84.545139 73.430748 91.028173 91.228935 88.175411 68.761571
# yes 30.557224 14.676304 12.464382 15.454861 26.569252  8.971827  8.771065 11.824589 31.238429

# Confidence intervals, using exact binomial method (Mid P)
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.aux$language),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.aux$language),c("LEXx","UEXx")))*100
#               LEXx      UEXx
# Baure    13.822229 15.561558
# Bora     29.777989 31.345009
# Chintang 11.887155 13.057794
# Dutch     8.232540  9.332859
# English  14.962923 15.957159
# Even     25.921684 27.225109
# Hoocąk   30.346366 32.140177
# Nǁng      8.412121  9.556078
# Texistepec 11.168138 12.503612

# Probability of filled pauses per language
table(combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code)
#       boa   brg   ctn   eng   eve   ngh   nld   poq   win
# no  13259  6249 12086 19744 16772  9614  9688  8921 10093
# yes    57   115   197   405   816     5   459    18   170

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code),2)*100
#             boa         brg         ctn         eng         eve         ngh         nld         poq         win
# no  99.57194353 98.19296040 98.39615729 97.98997469 95.36047305 99.94801954 95.47649552 99.79863519 98.34356426
# yes  0.42805647  1.80703960  1.60384271  2.01002531  4.63952695  0.05198046  4.52350448  0.20136481  1.65643574

# Confidence intervals, using exact binomial method (Mid P)
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.aux$language),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.aux$language),c("LEXx","UEXx")))*100
#                LEXx      UEXx
# Baure    1.50026624 2.1561038
# Bora     0.33146186 0.5532237
# Chintang 1.39499953 1.8394132
# Dutch    4.13476213 4.9417616
# English  1.82348619 2.2131761
# Even     4.33365833 4.9552911
# Hoocąk   1.42267203 1.9146993
# Nǁng     0.01220703 0.1175276
# Texistepec 0.12514016 0.3123668

# Probability of all pauses per language (including filled pauses)
table(combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code)
#       boa   brg   ctn   eng   eve   ngh   nld   poq   win
# no   9223  5342 10582 16716 12333  8752  8846  7868  6906
# yes  4093  1022  1701  3433  5255   867  1301  1071  3357

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code),2)*100
#           boa       brg       ctn       eng       eve       ngh       nld       poq       win
# no  69.262541 83.940918 86.151592 82.961934 70.121674 90.986589 87.178476 88.018794 67.290266
# yes 30.737459 16.059082 13.848408 17.038066 29.878326  9.013411 12.821524 11.981206 32.709734

# Confidence intervals, using exact binomial method (Mid P)
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.aux$language),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.aux$language),c("LEXx","UEXx")))*100
#               LEXx      UEXx
# Baure    15.171036 16.976475
# Bora     29.959428 31.525099
# Chintang 13.247137 14.466819
# Dutch    12.182329 13.481844
# English  16.525488 17.561048
# Even     29.204926 30.556467
# Hoocąk   31.807269 33.622948
# Nǁng      8.455941  9.600279
# Texistepec 11.320941 12.666958

# Probability of silent pauses by part-of-speech
table(combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux)
#         N     V
# no  31206 57125
# yes  9571 10766

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux),2)*100
#            N        V
# no  76.52844 84.14223
# yes 23.47156 15.85777

# Confidence intervals, using exact binomial method (Mid P)
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux),c("LEXx","UEXx")))*100
#       LEXx     UEXx
# N 23.06525 23.88384
# V 15.58317 16.13398

# Probability of filled pauses by part-of-speech
table(combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux)
#         N     V
# no  39582 66844
# yes  1195  1047

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux),2)*100
#             N         V
# no  97.069426 98.457822
# yes  2.930574  1.542178

# Confidence intervals
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux),c("LEXx","UEXx")))*100
#       LEXx     UEXx
# N 2.770793 3.094722
# V 1.449349 1.633264

# Probability of all pauses by part-of-speech
table(combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux)
#         N     V
# no  30285 56283
# yes 10492 11608

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux),2)*100
#            N        V
# no  74.26981 82.90200
# yes 25.73019 17.09800

# Confidence intervals
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux),c("LEXx","UEXx")))*100
#       LEXx     UEXx
# N 25.30566 26.15431
# V 16.81358 17.38079

# Probability of silent pauses by part-of-speech (AUX separately)
table(combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant)
#         N     V   AUX
# no  31206 53044  4081
# yes  9571 10076   690

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant),2)*100
#            N        V      AUX
# no  76.52844 84.03676 85.53762
# yes 23.47156 15.96324 14.46238

# Confidence intervals
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant),c("LEXx","UEXx")))*100
#         LEXx     UEXx
# N   23.06525 23.88384
# V   15.67711 16.25177
# AUX 13.48842 15.48461

# Probability of filled pauses by part-of-speech (AUX separately)
table(combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant)
#         N     V   AUX
# no  39582 62124  4720
# yes  1195   996    51

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant),2)*100
#             N         V       AUX
# no  97.069426 98.422053 98.931042
# yes  2.930574  1.577947  1.068958

# Confidence intervals
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant),c("LEXx","UEXx")))*100
#          LEXx     UEXx
# N   2.7707933 3.094722
# V   1.4848069 1.678308
# AUX 0.8037432 1.391014

# Probability of all pauses by part-of-speech (AUX separately)
table(combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant)
#         N     V   AUX
# no  30285 52247  4036
# yes 10492 10873   735

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant),2)*100
#            N        V      AUX
# no  74.26981 82.77408 84.59442
# yes 25.73019 17.22592 15.40558

# Confidence intervals
matrix(unlist(by(combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor,list(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant),FUN=function (x) ciEXx(table(x)["yes"],sum(table(x)),alp=0.05,e=0.5)[c("LEXx","UEXx")])),ncol=2,byrow=T,dimnames = list(levels(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant),c("LEXx","UEXx")))*100
#         LEXx     UEXx
# N   25.30566 26.15431
# V   16.93513 17.52338
# AUX 14.40275 16.45089

# Probability of silent pauses by language and part-of-speech of target word
table(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux,combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code)
# , ,  = boa
# 
#    
#        no   yes
#   N  3479  2028
#   V  5768  2041
# 
# , ,  = brg
# 
#    
#        no   yes
#   N  2044   383
#   V  3386   551
# 
# , ,  = ctn
# 
#    
#        no   yes
#   N  4136   806
#   V  6616   725
# 
# , ,  = eng
# 
#    
#        no   yes
#   N  6525   991
#   V 10510  2123
# 
# , ,  = eve
# 
#    
#        no   yes
#   N  5136  2756
#   V  7779  1917
# 
# , ,  = ngh
# 
#    
#        no   yes
#   N  2846   444
#   V  5910   419
# 
# , ,  = nld
# 
#    
#        no   yes
#   N  3502   351
#   V  5755   539
# 
# , ,  = poq
# 
#    
#        no   yes
#   N  1970   412
#   V  5912   645
# 
# , ,  = win
# 
#    
#        no   yes
#   N  1568  1400
#   V  5489  1806

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux,combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code),c(1,3))*100
# , ,  = boa
# 
#    
#            no       yes
#   N 63.174142 36.825858
#   V 73.863491 26.136509
# 
# , ,  = brg
# 
#    
#            no       yes
#   N 84.219201 15.780799
#   V 86.004572 13.995428
# 
# , ,  = ctn
# 
#    
#            no       yes
#   N 83.690813 16.309187
#   V 90.123961  9.876039
# 
# , ,  = eng
# 
#    
#            no       yes
#   N 86.814795 13.185205
#   V 83.194807 16.805193
# 
# , ,  = eve
# 
#    
#            no       yes
#   N 65.078561 34.921439
#   V 80.228960 19.771040
# 
# , ,  = ngh
# 
#    
#            no       yes
#   N 86.504559 13.495441
#   V 93.379681  6.620319
# 
# , ,  = nld
# 
#    
#            no       yes
#   N 90.890215  9.109785
#   V 91.436289  8.563711
# 
# , ,  = poq
# 
#    
#            no       yes
#   N 82.703610 17.296390
#   V 90.163184  9.836816
# 
# , ,  = win
# 
#    
#            no       yes
#   N 52.830189 47.169811
#   V 75.243317 24.756683

ci_per_language_per_pos(combined.wordtimes.prewindows.publish.pause_probability.aux,variable="silent_pause_in_pre_word_window_factor",language="language_iso_code",pos="word_class_relevant_aux")
#    language pos   percent  lower.ci  upper.ci
# 1       boa   N 36.825858 35.558231 38.105522
# 2       brg   N 15.780799 14.371502 17.271961
# 3       ctn   N 16.309187 15.299051 17.357766
# 4       eng   N 13.185205 12.437430 13.969470
# 5       eve   N 34.921439 33.873468 35.977955
# 6       ngh   N 13.495441 12.360421 14.697643
# 7       nld   N  9.109785  8.230880 10.050054
# 8       poq   N 17.296390 15.817252 18.854842
# 10      win   N 47.169811 45.378895 48.969491
# 11      boa   V 26.136509 25.173533 27.119691
# 12      brg   V 13.995428 12.940263 15.102769
# 13      ctn   V  9.876039  9.209550 10.573341
# 14      eng   V 16.805193 16.161191 17.464479
# 15      eve   V 19.771040 18.987610 20.573829
# 16      ngh   V  6.620319  6.026747  7.251619
# 17      nld   V  8.563711  7.888193  9.273441
# 18      poq   V  9.836816  9.134360 10.574743
# 20      win   V 24.756683 23.775565 25.756955

# Probability of silent pauses by language and part-of-speech of target word (AUX separately)
table(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant,combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code)
# , ,  = boa
# 
#      
#         no  yes
#   N   3479 2028
#   V   5768 2041
#   AUX    0    0
# 
# , ,  = brg
# 
#      
#         no  yes
#   N   2044  383
#   V   3386  551
#   AUX    0    0
# 
# , ,  = ctn
# 
#      
#         no  yes
#   N   4136  806
#   V   6616  725
#   AUX    0    0
# 
# , ,  = eng
# 
#      
#         no  yes
#   N   6525  991
#   V   8889 1877
#   AUX 1621  246
# 
# , ,  = eve
# 
#      
#         no  yes
#   N   5136 2756
#   V   7309 1816
#   AUX  470  101
# 
# , ,  = ngh
# 
#      
#         no  yes
#   N   2846  444
#   V   5910  419
#   AUX    0    0
# 
# , ,  = nld
# 
#      
#         no  yes
#   N   3502  351
#   V   5755  539
#   AUX    0    0
# 
# , ,  = poq
# 
#      
#         no  yes
#   N   1970  412
#   V   4730  475
#   AUX 1182  170
# 
# , ,  = win
# 
#      
#         no  yes
#   N   1568 1400
#   V   4681 1633
#   AUX  808  173

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant,combined.wordtimes.prewindows.publish.pause_probability.aux$silent_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code),c(1,3))*100
# , ,  = boa
# 
#      
#              no       yes
#   N   63.174142 36.825858
#   V   73.863491 26.136509
#   AUX                    
# 
# , ,  = brg
# 
#      
#              no       yes
#   N   84.219201 15.780799
#   V   86.004572 13.995428
#   AUX                    
# 
# , ,  = ctn
# 
#      
#              no       yes
#   N   83.690813 16.309187
#   V   90.123961  9.876039
#   AUX                    
# 
# , ,  = eng
# 
#      
#              no       yes
#   N   86.814795 13.185205
#   V   82.565484 17.434516
#   AUX 86.823781 13.176219
# 
# , ,  = eve
# 
#      
#              no       yes
#   N   65.078561 34.921439
#   V   80.098630 19.901370
#   AUX 82.311734 17.688266
# 
# , ,  = ngh
# 
#      
#              no       yes
#   N   86.504559 13.495441
#   V   93.379681  6.620319
#   AUX                    
# 
# , ,  = nld
# 
#      
#              no       yes
#   N   90.890215  9.109785
#   V   91.436289  8.563711
#   AUX                    
# 
# , ,  = poq
# 
#      
#              no       yes
#   N   82.703610 17.296390
#   V   90.874159  9.125841
#   AUX 87.426036 12.573964
# 
# , ,  = win
# 
#      
#              no       yes
#   N   52.830189 47.169811
#   V   74.136839 25.863161
#   AUX 82.364934 17.635066

ci_per_language_per_pos(combined.wordtimes.prewindows.publish.pause_probability.aux,variable="silent_pause_in_pre_word_window_factor",language="language_iso_code",pos="word_class_relevant")
#    language pos   percent  lower.ci  upper.ci
# 1       boa   N 36.825858 35.558231 38.105522
# 2       brg   N 15.780799 14.371502 17.271961
# 3       ctn   N 16.309187 15.299051 17.357766
# 4       eng   N 13.185205 12.437430 13.969470
# 5       eve   N 34.921439 33.873468 35.977955
# 6       ngh   N 13.495441 12.360421 14.697643
# 7       nld   N  9.109785  8.230880 10.050054
# 8       poq   N 17.296390 15.817252 18.854842
# 10      win   N 47.169811 45.378895 48.969491
# 11      boa   V 26.136509 25.173533 27.119691
# 12      brg   V 13.995428 12.940263 15.102769
# 13      ctn   V  9.876039  9.209550 10.573341
# 14      eng   V 17.434516 16.728825 18.161078
# 15      eve   V 19.901370 19.091955 20.729164
# 16      ngh   V  6.620319  6.026747  7.251619
# 17      nld   V  8.563711  7.888193  9.273441
# 18      poq   V  9.125841  8.366289  9.932838
# 20      win   V 25.863161 24.794755 26.953660
# 21      boa AUX       NaN        NA        NA
# 22      brg AUX       NaN        NA        NA
# 23      ctn AUX       NaN        NA        NA
# 24      eng AUX 13.176219 11.698078 14.767296
# 25      eve AUX 17.688266 14.720975 20.982287
# 26      ngh AUX       NaN        NA        NA
# 27      nld AUX       NaN        NA        NA
# 28      poq AUX 12.573964 10.883269 14.422060
# 30      win AUX 17.635066 15.342957 20.113204


# Probability of filled pauses by language and part-of-speech of target word
table(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux,combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code)
# , ,  = boa
# 
#    
#        no   yes
#   N  5475    32
#   V  7784    25
# 
# , ,  = brg
# 
#    
#        no   yes
#   N  2370    57
#   V  3879    58
# 
# , ,  = ctn
# 
#    
#        no   yes
#   N  4841   101
#   V  7245    96
# 
# , ,  = eng
# 
#    
#        no   yes
#   N  7340   176
#   V 12404   229
# 
# , ,  = eve
# 
#    
#        no   yes
#   N  7379   513
#   V  9393   303
# 
# , ,  = ngh
# 
#    
#        no   yes
#   N  3287     3
#   V  6327     2
# 
# , ,  = nld
# 
#    
#        no   yes
#   N  3636   217
#   V  6052   242
# 
# , ,  = poq
# 
#    
#        no   yes
#   N  2377     5
#   V  6544    13
# 
# , ,  = win
# 
#    
#        no   yes
#   N  2877    91
#   V  7216    79

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux,combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code),c(1,3))*100
# , ,  = boa
# 
#    
#              no         yes
#   N 99.41892137  0.58107863
#   V 99.67985658  0.32014342
# 
# , ,  = brg
# 
#    
#              no         yes
#   N 97.65142151  2.34857849
#   V 98.52679705  1.47320295
# 
# , ,  = ctn
# 
#    
#              no         yes
#   N 97.95629300  2.04370700
#   V 98.69227626  1.30772374
# 
# , ,  = eng
# 
#    
#              no         yes
#   N 97.65832890  2.34167110
#   V 98.18728726  1.81271274
# 
# , ,  = eve
# 
#    
#              no         yes
#   N 93.49974658  6.50025342
#   V 96.87500000  3.12500000
# 
# , ,  = ngh
# 
#    
#              no         yes
#   N 99.90881459  0.09118541
#   V 99.96839943  0.03160057
# 
# , ,  = nld
# 
#    
#              no         yes
#   N 94.36802492  5.63197508
#   V 96.15506832  3.84493168
# 
# , ,  = poq
# 
#    
#              no         yes
#   N 99.79009236  0.20990764
#   V 99.80173860  0.19826140
# 
# , ,  = win
# 
#    
#              no         yes
#   N 96.93396226  3.06603774
#   V 98.91706648  1.08293352

ci_per_language_per_pos(combined.wordtimes.prewindows.publish.pause_probability.aux,variable="filled_pause_in_pre_word_window_factor",language="language_iso_code",pos="word_class_relevant_aux")
#    language pos    percent    lower.ci  upper.ci
# 1       boa   N 0.58107863 0.405108495 0.8078710
# 2       brg   N 2.34857849 1.802421700 3.0118783
# 3       ctn   N 2.04370700 1.679258753 2.4659441
# 4       eng   N 2.34167110 2.016062261 2.7046308
# 5       eve   N 6.50025342 5.973360989 7.0587112
# 6       ngh   N 0.09118541 0.025522185 0.2492812
# 7       nld   N 5.63197508 4.937162625 6.3915639
# 8       poq   N 0.20990764 0.079570462 0.4648336
# 10      win   N 3.06603774 2.489656652 3.7365802
# 11      boa   V 0.32014342 0.214463579 0.4638497
# 12      brg   V 1.47320295 1.128427902 1.8873711
# 13      ctn   V 1.30772374 1.066842880 1.5900746
# 14      eng   V 1.81271274 1.589465159 2.0559462
# 15      eve   V 3.12500000 2.790563277 3.4885497
# 16      ngh   V 0.03160057 0.006103516 0.1040430
# 17      nld   V 3.84493168 3.391918288 4.3388234
# 18      poq   V 0.19826140 0.109655085 0.3283414
# 20      win   V 1.08293352 0.862721015 1.3393742


# Probability of filled pauses by language and part-of-speech of target word (AUX separately)
table(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant,combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code)
# , ,  = boa
# 
#      
#          no   yes
#   N    5475    32
#   V    7784    25
#   AUX     0     0
# 
# , ,  = brg
# 
#      
#          no   yes
#   N    2370    57
#   V    3879    58
#   AUX     0     0
# 
# , ,  = ctn
# 
#      
#          no   yes
#   N    4841   101
#   V    7245    96
#   AUX     0     0
# 
# , ,  = eng
# 
#      
#          no   yes
#   N    7340   176
#   V   10561   205
#   AUX  1843    24
# 
# , ,  = eve
# 
#      
#          no   yes
#   N    7379   513
#   V    8841   284
#   AUX   552    19
# 
# , ,  = ngh
# 
#      
#          no   yes
#   N    3287     3
#   V    6327     2
#   AUX     0     0
# 
# , ,  = nld
# 
#      
#          no   yes
#   N    3636   217
#   V    6052   242
#   AUX     0     0
# 
# , ,  = poq
# 
#      
#          no   yes
#   N    2377     5
#   V    5197     8
#   AUX  1347     5
# 
# , ,  = win
# 
#      
#          no   yes
#   N    2877    91
#   V    6238    76
#   AUX   978     3

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant,combined.wordtimes.prewindows.publish.pause_probability.aux$filled_pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code),c(1,3))*100
# , ,  = boa
# 
#      
#                 no          yes
#   N    99.41892137   0.58107863
#   V    99.67985658   0.32014342
#   AUX                          
# 
# , ,  = brg
# 
#      
#                 no          yes
#   N    97.65142151   2.34857849
#   V    98.52679705   1.47320295
#   AUX                          
# 
# , ,  = ctn
# 
#      
#                 no          yes
#   N    97.95629300   2.04370700
#   V    98.69227626   1.30772374
#   AUX                          
# 
# , ,  = eng
# 
#      
#                 no          yes
#   N    97.65832890   2.34167110
#   V    98.09585733   1.90414267
#   AUX  98.71451527   1.28548473
# 
# , ,  = eve
# 
#      
#                 no          yes
#   N    93.49974658   6.50025342
#   V    96.88767123   3.11232877
#   AUX  96.67250438   3.32749562
# 
# , ,  = ngh
# 
#      
#                 no          yes
#   N    99.90881459   0.09118541
#   V    99.96839943   0.03160057
#   AUX                          
# 
# , ,  = nld
# 
#      
#                 no          yes
#   N    94.36802492   5.63197508
#   V    96.15506832   3.84493168
#   AUX                          
# 
# , ,  = poq
# 
#      
#                 no          yes
#   N    99.79009236   0.20990764
#   V    99.84630163   0.15369837
#   AUX  99.63017751   0.36982249
# 
# , ,  = win
# 
#      
#                 no          yes
#   N    96.93396226   3.06603774
#   V    98.79632563   1.20367437
#   AUX  99.69418960   0.30581040

ci_per_language_per_pos(combined.wordtimes.prewindows.publish.pause_probability.aux,variable="filled_pause_in_pre_word_window_factor",language="language_iso_code",pos="word_class_relevant")
#    language pos    percent    lower.ci  upper.ci
# 1       boa   N 0.58107863 0.405108495 0.8078710
# 2       brg   N 2.34857849 1.802421700 3.0118783
# 3       ctn   N 2.04370700 1.679258753 2.4659441
# 4       eng   N 2.34167110 2.016062261 2.7046308
# 5       eve   N 6.50025342 5.973360989 7.0587112
# 6       ngh   N 0.09118541 0.025522185 0.2492812
# 7       nld   N 5.63197508 4.937162625 6.3915639
# 8       poq   N 0.20990764 0.079570462 0.4648336
# 10      win   N 3.06603774 2.489656652 3.7365802
# 11      boa   V 0.32014342 0.214463579 0.4638497
# 12      brg   V 1.47320295 1.128427902 1.8873711
# 13      ctn   V 1.30772374 1.066842880 1.5900746
# 14      eng   V 1.90414267 1.659198669 2.1746318
# 15      eve   V 3.11232877 2.769733667 3.4860321
# 16      ngh   V 0.03160057 0.006103516 0.1040430
# 17      nld   V 3.84493168 3.391918288 4.3388234
# 18      poq   V 0.15369837 0.069856852 0.2945634
# 20      win   V 1.20367437 0.956770078 1.4985300
# 21      boa AUX        NaN          NA        NA
# 22      brg AUX        NaN          NA        NA
# 23      ctn AUX        NaN          NA        NA
# 24      eng AUX 1.28548473 0.842441192 1.8793514
# 25      eve AUX 3.32749562 2.075736859 5.0530841
# 26      ngh AUX        NaN          NA        NA
# 27      nld AUX        NaN          NA        NA
# 28      poq AUX 0.36982249 0.137139240 0.8168364
# 30      win AUX 0.30581040 0.076110647 0.8293046


# Probability of all pauses (including filled pauses) by language and part-of-speech of target word
table(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux,combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code)
# , ,  = boa
# 
#    
#        no   yes
#   N  3468  2039
#   V  5755  2054
# 
# , ,  = brg
# 
#    
#        no   yes
#   N  2000   427
#   V  3342   595
# 
# , ,  = ctn
# 
#    
#        no   yes
#   N  4053   889
#   V  6529   812
# 
# , ,  = eng
# 
#    
#        no   yes
#   N  6388  1128
#   V 10328  2305
# 
# , ,  = eve
# 
#    
#        no   yes
#   N  4767  3125
#   V  7566  2130
# 
# , ,  = ngh
# 
#    
#        no   yes
#   N  2844   446
#   V  5908   421
# 
# , ,  = nld
# 
#    
#        no   yes
#   N  3309   544
#   V  5537   757
# 
# , ,  = poq
# 
#    
#        no   yes
#   N  1967   415
#   V  5901   656
# 
# , ,  = win
# 
#    
#        no   yes
#   N  1489  1479
#   V  5417  1878

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux,combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code),c(1,3))*100
# , ,  = boa
# 
#    
#           no      yes
#   N 62.97440 37.02560
#   V 73.69702 26.30298
# 
# , ,  = brg
# 
#    
#           no      yes
#   N 82.40626 17.59374
#   V 84.88697 15.11303
# 
# , ,  = ctn
# 
#    
#           no      yes
#   N 82.01133 17.98867
#   V 88.93884 11.06116
# 
# , ,  = eng
# 
#    
#           no      yes
#   N 84.99202 15.00798
#   V 81.75414 18.24586
# 
# , ,  = eve
# 
#    
#           no      yes
#   N 60.40294 39.59706
#   V 78.03218 21.96782
# 
# , ,  = ngh
# 
#    
#           no      yes
#   N 86.44377 13.55623
#   V 93.34808  6.65192
# 
# , ,  = nld
# 
#    
#           no      yes
#   N 85.88113 14.11887
#   V 87.97267 12.02733
# 
# , ,  = poq
# 
#    
#           no      yes
#   N 82.57767 17.42233
#   V 89.99542 10.00458
# 
# , ,  = win
# 
#    
#           no      yes
#   N 50.16846 49.83154
#   V 74.25634 25.74366

ci_per_language_per_pos(combined.wordtimes.prewindows.publish.pause_probability.aux,variable="pause_in_pre_word_window_factor",language="language_iso_code",pos="word_class_relevant_aux")
#    language pos  percent  lower.ci  upper.ci
# 1       boa   N 37.02560 35.757520 38.305292
# 2       brg   N 17.59374 16.117823 19.146738
# 3       ctn   N 17.98867 16.938803 19.078797
# 4       eng   N 15.00798 14.213843 15.831521
# 5       eve   N 39.59706 38.521322 40.678246
# 6       ngh   N 13.55623 12.421174 14.756649
# 7       nld   N 14.11887 13.045184 15.242875
# 8       poq   N 17.42233 15.938127 18.983931
# 10      win   N 49.83154 48.031140 51.629933
# 11      boa   V 26.30298 25.335732 27.288090
# 12      brg   V 15.11303 14.022250 16.254770
# 13      ctn   V 11.06116 10.359135 11.793602
# 14      eng   V 18.24586 17.580142 18.925948
# 15      eve   V 21.96782 21.152384 22.800113
# 16      ngh   V  6.65192  6.054490  7.283522
# 17      nld   V 12.02733 11.241235 12.847821
# 18      poq   V 10.00458  9.292498 10.749714
# 20      win   V 25.74366 24.750141 26.755406

# Probability of all pauses (including filled pauses) by language and part-of-speech of target word (AUX separately)
table(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant,combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code)
# , ,  = boa
# 
#      
#         no  yes
#   N   3468 2039
#   V   5755 2054
#   AUX    0    0
# 
# , ,  = brg
# 
#      
#         no  yes
#   N   2000  427
#   V   3342  595
#   AUX    0    0
# 
# , ,  = ctn
# 
#      
#         no  yes
#   N   4053  889
#   V   6529  812
#   AUX    0    0
# 
# , ,  = eng
# 
#      
#         no  yes
#   N   6388 1128
#   V   8729 2037
#   AUX 1599  268
# 
# , ,  = eve
# 
#      
#         no  yes
#   N   4767 3125
#   V   7111 2014
#   AUX  455  116
# 
# , ,  = ngh
# 
#      
#         no  yes
#   N   2844  446
#   V   5908  421
#   AUX    0    0
# 
# , ,  = nld
# 
#      
#         no  yes
#   N   3309  544
#   V   5537  757
#   AUX    0    0
# 
# , ,  = poq
# 
#      
#         no  yes
#   N   1967  415
#   V   4724  481
#   AUX 1177  175
# 
# , ,  = win
# 
#      
#         no  yes
#   N   1489 1479
#   V   4612 1702
#   AUX  805  176

prop.table(table(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant,combined.wordtimes.prewindows.publish.pause_probability.aux$pause_in_pre_word_window_factor,combined.wordtimes.prewindows.publish.pause_probability.aux$language_iso_code),c(1,3))*100
# , ,  = boa
# 
#      
#              no       yes
#   N   62.974396 37.025604
#   V   73.697016 26.302984
#   AUX                    
# 
# , ,  = brg
# 
#      
#              no       yes
#   N   82.406263 17.593737
#   V   84.886970 15.113030
#   AUX                    
# 
# , ,  = ctn
# 
#      
#              no       yes
#   N   82.011331 17.988669
#   V   88.938837 11.061163
#   AUX                    
# 
# , ,  = eng
# 
#      
#              no       yes
#   N   84.992017 15.007983
#   V   81.079324 18.920676
#   AUX 85.645420 14.354580
# 
# , ,  = eve
# 
#      
#              no       yes
#   N   60.402940 39.597060
#   V   77.928767 22.071233
#   AUX 79.684764 20.315236
# 
# , ,  = ngh
# 
#      
#              no       yes
#   N   86.443769 13.556231
#   V   93.348080  6.651920
#   AUX                    
# 
# , ,  = nld
# 
#      
#              no       yes
#   N   85.881132 14.118868
#   V   87.972672 12.027328
#   AUX                    
# 
# , ,  = poq
# 
#      
#              no       yes
#   N   82.577666 17.422334
#   V   90.758886  9.241114
#   AUX 87.056213 12.943787
# 
# , ,  = win
# 
#      
#              no       yes
#   N   50.168464 49.831536
#   V   73.044029 26.955971
#   AUX 82.059123 17.940877

ci_per_language_per_pos(combined.wordtimes.prewindows.publish.pause_probability.aux,variable="pause_in_pre_word_window_factor",language="language_iso_code",pos="word_class_relevant")
#    language pos   percent  lower.ci  upper.ci
# 1       boa   N 37.025604 35.757520 38.305292
# 2       brg   N 17.593737 16.117823 19.146738
# 3       ctn   N 17.988669 16.938803 19.078797
# 4       eng   N 15.007983 14.213843 15.831521
# 5       eve   N 39.597060 38.521322 40.678246
# 6       ngh   N 13.556231 12.421174 14.756649
# 7       nld   N 14.118868 13.045184 15.242875
# 8       poq   N 17.422334 15.938127 18.983931
# 10      win   N 49.831536 48.031140 51.629933
# 11      boa   V 26.302984 25.335732 27.288090
# 12      brg   V 15.113030 14.022250 16.254770
# 13      ctn   V 11.061163 10.359135 11.793602
# 14      eng   V 18.920676 18.187958 19.669606
# 15      eve   V 22.071233 21.229424 22.930845
# 16      ngh   V  6.651920  6.054490  7.283522
# 17      nld   V 12.027328 11.241235 12.847821
# 18      poq   V  9.241114  8.474919 10.054173
# 20      win   V 26.955971 25.874111 28.061343
# 21      boa AUX       NaN        NA        NA
# 22      brg AUX       NaN        NA        NA
# 23      ctn AUX       NaN        NA        NA
# 24      eng AUX 14.354580 12.818743 15.997778
# 25      eve AUX 20.315236 17.164563 23.764121
# 26      ngh AUX       NaN        NA        NA
# 27      nld AUX       NaN        NA        NA
# 28      poq AUX 12.943787 11.232708 14.812893
# 30      win AUX 17.940877 15.634878 20.438116


### Multivariate modeling

## Upward selection process ##

## Main study excluding auxiliaries (AUX)

# Initial model including word class, language, and their interaction
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + language_iso_code + word_class_relevant_no_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.no_aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

# Try adding word length
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2 = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.no_aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

# Try adding word position
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3 = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_position_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.no_aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward,prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.no_aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2:     word_length_characters_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                       Df   AIC   BIC logLik deviance Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward  21 94736 94937 -47347    94694             
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2 22 94614 94824 -47285    94570 124.2      1
#                                                                       Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward                
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward,prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.no_aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3:     word_position_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                       Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward  21 94736 94937 -47347    94694              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3 22 94724 94934 -47340    94680 14.306      1
#                                                                       Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward                
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3  0.0001554 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Thus add word_length_characters_normalized
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward = prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2

# Try word position
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2 = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.no_aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))
# Warning message:
# In checkConv(attr(opt, "derivs"), opt$par, ctrl = control$checkConv,  :
#   Model failed to converge with max|grad| = 0.00137349 (tol = 0.001, component 1)

# Check with converge_ok function from library sjstats
# https://www.rdocumentation.org/packages/sjstats/versions/0.14.3/topics/converge_ok
converge_ok(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2)
# 0.00024081274875885 
#                TRUE 

# Try adding interaction of word class and word length
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3 = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux * word_length_characters_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.no_aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward,prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.no_aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                       Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward  22 94614 94824 -47285    94570              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2 23 94607 94826 -47280    94561 9.5696      1
#                                                                       Pr(>Chisq)   
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward               
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2   0.001978 **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward,prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.no_aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux * 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3:     word_length_characters_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                       Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward  22 94614 94824 -47285    94570              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3 23 94616 94835 -47285    94570 0.6384      1
#                                                                       Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward            
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3     0.4243

# Thus add word position
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward = prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2

# Try adding interaction of word class and word length
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2 = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_no_aux:word_length_characters_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.no_aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))
# Warning message:
# In checkConv(attr(opt, "derivs"), opt$par, ctrl = control$checkConv,  :
#   Model failed to converge with max|grad| = 0.0026961 (tol = 0.001, component 1)

# Check with converge_ok function from library sjstats
# https://www.rdocumentation.org/packages/sjstats/versions/0.14.3/topics/converge_ok
converge_ok(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2)
# 0.000860106004314661 
#                 TRUE

# Try adding interaction of word class and word position
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3 = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_no_aux:word_position_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.no_aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

# Try adding interaction of word length and word position
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward4 = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + word_length_characters_normalized:word_position_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.no_aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))
# Warning message:
# In checkConv(attr(opt, "derivs"), opt$par, ctrl = control$checkConv,  :
#   Model failed to converge with max|grad| = 0.00131072 (tol = 0.001, component 1)

# Check with converge_ok function from library sjstats
# https://www.rdocumentation.org/packages/sjstats/versions/0.14.3/topics/converge_ok
converge_ok(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward4)
# 0.00024458740610011 
#                TRUE 

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward,prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.no_aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2:     word_class_relevant_no_aux:word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                       Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward  23 94607 94826 -47280    94561              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2 24 94608 94837 -47280    94560 0.5358      1
#                                                                       Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward            
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward2     0.4642

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward,prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.no_aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3:     word_class_relevant_no_aux:word_position_normalized + language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3:     word_class_relevant_no_aux:language_iso_code + (1 | speaker) + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3:     (1 | text) + (1 | word_type)
#                                                                       Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward  23 94607 94826 -47280    94561              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3 24 94607 94836 -47280    94559 1.4302      1
#                                                                       Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward            
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward3     0.2317

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward,prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward4,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.no_aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward4: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward4:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward4:     word_length_characters_normalized:word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward4:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward4:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                       Df   AIC   BIC logLik deviance Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward  23 94607 94826 -47280    94561             
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward4 24 94609 94838 -47280    94561 1e-04      1
#                                                                       Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward            
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward4     0.9933

# No further interactions required in model


## Alternative study including auxiliaries (AUX)

# Initial model including word class, language, and their interaction
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + language_iso_code + word_class_relevant_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))
# Warning message:
# In checkConv(attr(opt, "derivs"), opt$par, ctrl = control$checkConv,  :
#   Model failed to converge with max|grad| = 0.00229932 (tol = 0.001, component 1)

# Check with converge_ok function from library sjstats
# https://www.rdocumentation.org/packages/sjstats/versions/0.14.3/topics/converge_ok
converge_ok(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward)
# 0.000697702009636079 
#                 TRUE 

# Try adding word length
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2 = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))
# Warning message:
# In checkConv(attr(opt, "derivs"), opt$par, ctrl = control$checkConv,  :
#   Model failed to converge with max|grad| = 0.00165653 (tol = 0.001, component 1)

# Check with converge_ok function from library sjstats
# https://www.rdocumentation.org/packages/sjstats/versions/0.14.3/topics/converge_ok
converge_ok(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2)
# 0.000544329236375118 
#                 TRUE 

# Try adding word position
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3 = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward,prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_aux + language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux:language_iso_code + (1 | speaker) + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2:     language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                   Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward  21 99209 99411 -49584    99167                         
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2 22 99084 99295 -49520    99040 126.92      1  < 2.2e-16
#                                                                      
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward     
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward,prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_aux + language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     word_class_relevant_aux:language_iso_code + (1 | speaker) + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3:     language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                   Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward  21 99209 99411 -49584    99167                         
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3 22 99194 99405 -49575    99150 16.884      1  3.973e-05
#                                                                      
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward     
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Thus add word length
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward = prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2

# Try adding word position
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2 = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))
# Warning message:
# In checkConv(attr(opt, "derivs"), opt$par, ctrl = control$checkConv,  :
#   Model failed to converge with max|grad| = 0.00225499 (tol = 0.001, component 1)

# Check with converge_ok function from library sjstats
# https://www.rdocumentation.org/packages/sjstats/versions/0.14.3/topics/converge_ok
converge_ok(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2)
# 0.00062694269949454 
#                TRUE 

# Try adding interaction of word class and word length
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3 = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux * word_length_characters_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward,prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2:     word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                   Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward  22 99084 99295 -49520    99040                         
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2 23 99075 99296 -49514    99029 11.382      1  0.0007417
#                                                                      
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward     
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward,prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3: pause_in_pre_word_window_factor ~ word_class_relevant_aux * word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3:     language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                   Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward  22 99084 99295 -49520    99040                         
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3 23 99086 99307 -49520    99040 0.4417      1     0.5063

# Thus add word position
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward = prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2

# Try adding interaction of word class and word length
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2 = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_aux:word_length_characters_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

# Try adding interaction of word class and word position
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3 = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + word_class_relevant_aux:word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

# Try adding interaction of word length and word position
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward4 = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + word_length_characters_normalized:word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))
# Warning message:
# In checkConv(attr(opt, "derivs"), opt$par, ctrl = control$checkConv,  :
#   Model failed to converge with max|grad| = 0.00154623 (tol = 0.001, component 1)

# Check with converge_ok function from library sjstats
# https://www.rdocumentation.org/packages/sjstats/versions/0.14.3/topics/converge_ok
converge_ok(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward4)
# 0.000631991260917783 
#                 TRUE

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward,prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2:     word_position_normalized + word_class_relevant_aux:word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2:     language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                   Df   AIC   BIC logLik deviance Chisq Chi Df Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward  23 99075 99296 -49514    99029                        
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward2 24 99077 99307 -49514    99029  0.34      1     0.5598

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward,prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3:     word_position_normalized + word_class_relevant_aux:word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3:     language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                   Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward  23 99075 99296 -49514    99029                         
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward3 24 99076 99306 -49514    99028 1.0384      1     0.3082

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward,prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward4,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward4: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward4:     word_position_normalized + word_length_characters_normalized:word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward4:     language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward4:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                   Df   AIC   BIC logLik deviance  Chisq Chi Df Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward  23 99075 99296 -49514    99029                         
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward4 24 99076 99307 -49514    99028 0.5011      1      0.479


## Final models ##

## Main study excluding auxiliaries (AUX)

summary(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized + word_position_normalized +  
#     language_iso_code + word_class_relevant_no_aux:language_iso_code +      (1 | speaker) + (1 | text) + (1 | word_type)
#    Data: combined.wordtimes.prewindows.publish.pause_probability.no_aux
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#  94606.7  94826.2 -47280.3  94560.7   103416 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.1322 -0.5073 -0.3638 -0.1972 10.2815 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept) 0.2949   0.5430  
#  text      (Intercept) 0.1326   0.3641  
#  speaker   (Intercept) 0.2080   0.4560  
# Number of obs: 103439, groups:  word_type, 34972; text, 346; speaker, 311
# 
# Fixed effects:
#                                                  Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                                      -1.16834    0.13679  -8.541  < 2e-16 ***
# word_class_relevant_no_auxV                      -0.54479    0.04606 -11.827  < 2e-16 ***
# word_length_characters_normalized                 0.11264    0.01005  11.211  < 2e-16 ***
# word_position_normalized                          0.09480    0.03024   3.134 0.001722 ** 
# language_iso_codebrg                             -0.34445    0.24054  -1.432 0.152148    
# language_iso_codectn                             -0.56912    0.17022  -3.343 0.000828 ***
# language_iso_codeeng                             -0.82202    0.16009  -5.135 2.83e-07 ***
# language_iso_codeeve                              0.73793    0.17286   4.269 1.96e-05 ***
# language_iso_codengh                             -0.76132    0.24115  -3.157 0.001594 ** 
# language_iso_codenld                             -1.03755    0.18656  -5.562 2.67e-08 ***
# language_iso_codepoq                             -0.56091    0.50722  -1.106 0.268789    
# language_iso_codewin                              1.18136    0.18241   6.476 9.39e-11 ***
# word_class_relevant_no_auxV:language_iso_codebrg  0.33488    0.09210   3.636 0.000277 ***
# word_class_relevant_no_auxV:language_iso_codectn -0.10861    0.07632  -1.423 0.154746    
# word_class_relevant_no_auxV:language_iso_codeeng  0.80919    0.07620  10.620  < 2e-16 ***
# word_class_relevant_no_auxV:language_iso_codeeve -0.34752    0.06197  -5.608 2.05e-08 ***
# word_class_relevant_no_auxV:language_iso_codengh -0.22415    0.10197  -2.198 0.027943 *  
# word_class_relevant_no_auxV:language_iso_codenld  0.41764    0.08961   4.661 3.15e-06 ***
# word_class_relevant_no_auxV:language_iso_codepoq -0.20034    0.09661  -2.074 0.038101 *  
# word_class_relevant_no_auxV:language_iso_codewin -0.65693    0.07577  -8.670  < 2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation matrix not shown by default, as p = 20 > 12.
# Use print(x, correlation=TRUE)  or
# 	 vcov(x)	 if you need it
# 
# convergence code: 0
# Model failed to converge with max|grad| = 0.00137349 (tol = 0.001, component 1)

# Check with converge_ok function from library sjstats
# https://www.rdocumentation.org/packages/sjstats/versions/0.14.3/topics/converge_ok
converge_ok(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward)
# 0.00024081274875885 
#                TRUE 

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward)
#                      word_class_relevant_no_auxV                word_length_characters_normalized 
#                                      -0.65862178                                       0.27907032 
#                         word_position_normalized                             language_iso_codebrg 
#                                       0.06957084                                      -0.20475630 
#                             language_iso_codectn                             language_iso_codeeng 
#                                      -0.45545379                                      -0.77570628 
#                             language_iso_codeeve                             language_iso_codengh 
#                                       0.67680827                                      -0.54698361 
#                             language_iso_codenld                             language_iso_codepoq 
#                                      -0.76347682                                      -0.36174266 
#                             language_iso_codewin word_class_relevant_no_auxV:language_iso_codebrg 
#                                       0.81641860                                       0.15851717 
# word_class_relevant_no_auxV:language_iso_codectn word_class_relevant_no_auxV:language_iso_codeeng 
#                                      -0.06898910                                       0.61129338 
# word_class_relevant_no_auxV:language_iso_codeeve word_class_relevant_no_auxV:language_iso_codengh 
#                                      -0.24382272                                      -0.13290213 
# word_class_relevant_no_auxV:language_iso_codenld word_class_relevant_no_auxV:language_iso_codepoq 
#                                       0.24698657                                      -0.10833310 
# word_class_relevant_no_auxV:language_iso_codewin 
#                                      -0.37561136 

# Comparison model to gauge the overall effect of word class (including language as a random effect and not in an interaction of fixed effects)
summary(glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1 + word_class_relevant_no_aux|language_iso_code) + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.no_aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa")))
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized + word_position_normalized +  
#     (1 + word_class_relevant_no_aux | language_iso_code) + (1 |      speaker) + (1 | text) + (1 | word_type)
#    Data: combined.wordtimes.prewindows.publish.pause_probability.no_aux
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#  94661.1  94756.5 -47320.5  94641.1   103429 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.0844 -0.5095 -0.3653 -0.1988 10.2030 
# 
# Random effects:
#  Groups            Name                        Variance Std.Dev. Corr 
#  word_type         (Intercept)                 0.2904   0.5389        
#  text              (Intercept)                 0.1348   0.3671        
#  speaker           (Intercept)                 0.2217   0.4708        
#  language_iso_code (Intercept)                 0.4740   0.6885        
#                    word_class_relevant_no_auxV 0.1706   0.4131   -0.77
# Number of obs: 103439, groups:  word_type, 34972; text, 346; speaker, 311; language_iso_code, 9
# 
# Fixed effects:
#                                   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                       -1.36757    0.23747  -5.759 8.46e-09 ***
# word_class_relevant_no_auxV       -0.53924    0.13896  -3.880 0.000104 ***
# word_length_characters_normalized  0.11250    0.01001  11.239  < 2e-16 ***
# word_position_normalized           0.09249    0.03018   3.065 0.002180 ** 
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) w____V wrd___
# wrd_cls___V -0.734              
# wrd_lngth__ -0.024 -0.009       
# wrd_pstn_nr -0.082 -0.003 -0.061


## Alternative study including auxiliaries (AUX)

summary(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized +  
#     word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code +  
#     (1 | speaker) + (1 | text) + (1 | word_type)
#    Data: combined.wordtimes.prewindows.publish.pause_probability.aux
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#  99074.9  99295.6 -49514.4  99028.9   108645 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.0601 -0.5025 -0.3655 -0.2034 10.2905 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept) 0.2997   0.5474  
#  text      (Intercept) 0.1346   0.3669  
#  speaker   (Intercept) 0.2035   0.4511  
# Number of obs: 108668, groups:  word_type, 35821; text, 346; speaker, 311
# 
# Fixed effects:
#                                                Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                                   -1.169552   0.136443  -8.572  < 2e-16 ***
# word_class_relevant_auxV                      -0.545365   0.046143 -11.819  < 2e-16 ***
# word_length_characters_normalized              0.111697   0.009884  11.301  < 2e-16 ***
# word_position_normalized                       0.101475   0.029689   3.418 0.000631 ***
# language_iso_codebrg                          -0.348087   0.239504  -1.453 0.146122    
# language_iso_codectn                          -0.571231   0.169906  -3.362 0.000774 ***
# language_iso_codeeng                          -0.826829   0.159709  -5.177 2.25e-07 ***
# language_iso_codeeve                           0.740143   0.172348   4.294 1.75e-05 ***
# language_iso_codengh                          -0.765897   0.241296  -3.174 0.001503 ** 
# language_iso_codenld                          -1.039986   0.186362  -5.580 2.40e-08 ***
# language_iso_codepoq                          -0.547507   0.498368  -1.099 0.271943    
# language_iso_codewin                           1.179130   0.181276   6.505 7.79e-11 ***
# word_class_relevant_auxV:language_iso_codebrg  0.336207   0.092232   3.645 0.000267 ***
# word_class_relevant_auxV:language_iso_codectn -0.109396   0.076430  -1.431 0.152340    
# word_class_relevant_auxV:language_iso_codeeng  0.807624   0.075623  10.680  < 2e-16 ***
# word_class_relevant_auxV:language_iso_codeeve -0.346320   0.061822  -5.602 2.12e-08 ***
# word_class_relevant_auxV:language_iso_codengh -0.223524   0.102281  -2.185 0.028861 *  
# word_class_relevant_auxV:language_iso_codenld  0.417723   0.089739   4.655 3.24e-06 ***
# word_class_relevant_auxV:language_iso_codepoq -0.135116   0.095385  -1.417 0.156620    
# word_class_relevant_auxV:language_iso_codewin -0.766518   0.074278 -10.320  < 2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation matrix not shown by default, as p = 20 > 12.
# Use print(x, correlation=TRUE)  or
# 	 vcov(x)	 if you need it
# 
# convergence code: 0
# Model failed to converge with max|grad| = 0.00225499 (tol = 0.001, component 1)

# Check with converge_ok function from library sjstats
# https://www.rdocumentation.org/packages/sjstats/versions/0.14.3/topics/converge_ok
converge_ok(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward)
# 0.00062694269949454 
#                TRUE 

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward)
#                      word_class_relevant_auxV             word_length_characters_normalized 
#                                   -0.65603316                                    0.28301519 
#                      word_position_normalized                          language_iso_codebrg 
#                                    0.07473512                                   -0.20306019 
#                          language_iso_codectn                          language_iso_codeeng 
#                                   -0.44935928                                   -0.79833620 
#                          language_iso_codeeve                          language_iso_codengh 
#                                    0.67726834                                   -0.54048725 
#                          language_iso_codenld                          language_iso_codepoq 
#                                   -0.75177191                                   -0.37374050 
#                          language_iso_codewin word_class_relevant_auxV:language_iso_codebrg 
#                                    0.85670735                                    0.15608169 
# word_class_relevant_auxV:language_iso_codectn word_class_relevant_auxV:language_iso_codeeng 
#                                   -0.06821283                                    0.64313536 
# word_class_relevant_auxV:language_iso_codeeve word_class_relevant_auxV:language_iso_codengh 
#                                   -0.24527623                                   -0.13005804 
# word_class_relevant_auxV:language_iso_codenld word_class_relevant_auxV:language_iso_codepoq 
#                                    0.24242171                                   -0.07993177 
# word_class_relevant_auxV:language_iso_codewin 
#                                   -0.47656432 

# Comparison model to gauge the overall effect of word class (including language as a random effect and not in an interaction of fixed effects)
summary(glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1 + word_class_relevant_aux|language_iso_code) + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa")))
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized +  
#     word_position_normalized + (1 + word_class_relevant_aux |  
#     language_iso_code) + (1 | speaker) + (1 | text) + (1 | word_type)
#    Data: combined.wordtimes.prewindows.publish.pause_probability.aux
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#  99129.8  99225.7 -49554.9  99109.8   108658 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.0083 -0.5046 -0.3668 -0.2050 10.2086 
# 
# Random effects:
#  Groups            Name                     Variance Std.Dev. Corr 
#  word_type         (Intercept)              0.2949   0.5430        
#  text              (Intercept)              0.1368   0.3699        
#  speaker           (Intercept)              0.2169   0.4657        
#  language_iso_code (Intercept)              0.4746   0.6889        
#                    word_class_relevant_auxV 0.1854   0.4305   -0.79
# Number of obs: 108668, groups:  word_type, 35821; text, 346; speaker, 311; language_iso_code, 9
# 
# Fixed effects:
#                                    Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                       -1.373900   0.237776  -5.778 7.55e-09 ***
# word_class_relevant_auxV          -0.544654   0.144924  -3.758 0.000171 ***
# word_length_characters_normalized  0.111558   0.009846  11.330  < 2e-16 ***
# word_position_normalized           0.099086   0.029624   3.345 0.000823 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___
# wrd_clss__V -0.761              
# wrd_lngth__ -0.024 -0.007       
# wrd_pstn_nr -0.081 -0.003 -0.064


## Tests of fixed effects in final model ##

## Main study excluding auxiliaries (AUX)

drop1(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
#     (1 | speaker) + (1 | text) + (1 | word_type)
#                                              Df   AIC    LRT   Pr(Chi)    
# <none>                                          94607                     
# word_length_characters_normalized             1 94724 119.46 < 2.2e-16 ***
# word_position_normalized                      1 94614   9.57  0.001978 ** 
# word_class_relevant_no_aux:language_iso_code  8 94992 401.26 < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p values for multiple testing adjustment
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="word length"] = pchisq(119.46,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="position"] = pchisq(9.57,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="word class:language"] = pchisq(401.26,8,lower.tail=FALSE)

# Test the factor language
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_language = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.no_aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_language,prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.no_aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_language: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_language:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_language:     (1 | speaker) + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                                  Df   AIC   BIC logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_language  7 95124 95190 -47555    95110       
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward             23 94607 94826 -47280    94561 548.92
#                                                                                  Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_language                      
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward                 16  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing adjustment
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="language"] = pchisq(548.92,16,lower.tail=FALSE)

# Test factor word class
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_pos = glmer(pause_in_pre_word_window_factor ~ word_length_characters_normalized + word_position_normalized + language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.no_aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_pos,prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.no_aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_pos: pause_in_pre_word_window_factor ~ word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_pos:     word_position_normalized + language_iso_code + (1 | speaker) + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_pos:     (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                             Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_pos 14 95803 95936 -47887    95775              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward        23 94607 94826 -47280    94561 1213.9      9
#                                                                             Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_pos               
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward         < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing adjustment
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="word class"] = pchisq(1213.9,9,lower.tail=FALSE)


## Alternative study including auxiliaries (AUX)

# Test fixed effects
drop1(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
#     word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + 
#     (1 | speaker) + (1 | text) + (1 | word_type)
#                                           Df   AIC    LRT   Pr(Chi)    
# <none>                                       99075                     
# word_length_characters_normalized          1 99194 121.42 < 2.2e-16 ***
# word_position_normalized                   1 99084  11.38 0.0007417 ***
# word_class_relevant_aux:language_iso_code  8 99511 451.80 < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# Warnmeldungen:
# 1: In checkConv(attr(opt, "derivs"), opt$par, ctrl = control$checkConv,  :
#   Model failed to converge with max|grad| = 0.00165653 (tol = 0.001, component 1)
# 2: In checkConv(attr(opt, "derivs"), opt$par, ctrl = control$checkConv,  :
#   Model failed to converge with max|grad| = 0.00224034 (tol = 0.001, component 1)

# Store p values for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="word length"] = pchisq(121.42,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="position"] = pchisq(11.38,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="word class:language"] = pchisq(451.80,8,lower.tail=FALSE)

# Test the factor language
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_language = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_language,prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_language: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_language:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_language:     word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                              Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_language  7 99636 99703 -49811    99622              
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward             23 99075 99296 -49514    99029 592.65     16
#                                                                              Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_language               
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward              < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="language"] = pchisq(592.65,16,lower.tail=FALSE)

# Test the factor word class
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_pos = glmer(pause_in_pre_word_window_factor ~ word_length_characters_normalized + word_position_normalized + language_iso_code + (1|speaker) + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_pos,prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_pos: pause_in_pre_word_window_factor ~ word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_pos:     word_position_normalized + language_iso_code + (1 | speaker) + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_pos:     (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                         Df    AIC    BIC logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_pos 14 100370 100504 -50171   100342              
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward        23  99075  99296 -49514    99029 1312.7      9
#                                                                         Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_pos               
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward         < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="word class"] = pchisq(1312.7,9,lower.tail=FALSE)


## Tests of random effects in final model ##

## Main study excluding auxiliaries (AUX)

# Test random factor speaker
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_speaker = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.no_aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_speaker,prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.no_aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_speaker: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_speaker:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_speaker:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_speaker:     (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                                 Df   AIC   BIC logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_speaker 22 94976 95186 -47466    94932       
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward            23 94607 94826 -47280    94561 371.75
#                                                                                 Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_speaker                      
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward                 1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing adjustment
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="speaker"] = pchisq(371.75,1,lower.tail=FALSE)

# Test random factor text
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + (1|speaker) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.no_aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))
# Warning message:
# In checkConv(attr(opt, "derivs"), opt$par, ctrl = control$checkConv,  :
#   Model failed to converge with max|grad| = 0.00260069 (tol = 0.001, component 1)

# Check with converge_ok function from library sjstats
# https://www.rdocumentation.org/packages/sjstats/versions/0.14.3/topics/converge_ok
converge_ok(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_text)
# 0.000860868246512217 
#                 TRUE

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_text,prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.no_aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_text:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_text:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_text:     (1 | speaker) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                              Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_text 22 94984 95194 -47470    94940              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward         23 94607 94826 -47280    94561 378.99      1
#                                                                              Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_text               
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward          < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing adjustment
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="text"] = pchisq(378.99,1,lower.tail=FALSE)

# Test random factor word type
prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + language_iso_code + word_class_relevant_no_aux:language_iso_code + (1|speaker) + (1|text), data=combined.wordtimes.prewindows.publish.pause_probability.no_aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))
# Warning message:
# In checkConv(attr(opt, "derivs"), opt$par, ctrl = control$checkConv,  :
#   Model failed to converge with max|grad| = 0.00250239 (tol = 0.001, component 1)

# Check with converge_ok function from library sjstats
# https://www.rdocumentation.org/packages/sjstats/versions/0.14.3/topics/converge_ok
converge_ok(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_word_type)
# 0.000829427547818955 
#                 TRUE 

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.no_aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_word_type:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_word_type:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_word_type:     (1 | speaker) + (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     language_iso_code + word_class_relevant_no_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                                   Df   AIC   BIC logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_word_type 22 95538 95748 -47747    95494       
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward              23 94607 94826 -47280    94561 933.71
#                                                                                   Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward.no_word_type                      
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.language.upward                   1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing adjustment
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="cross-linguistic" & p.values$variable=="word type"] = pchisq(933.71,1,lower.tail=FALSE)


## Alternative study including auxiliaries (AUX)

# Test the random factor speaker
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_speaker = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + (1|text) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_speaker,prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_speaker: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_speaker:     word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_speaker:     (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                             Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_speaker 22 99442 99654 -49699    99398              
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward            23 99075 99296 -49514    99029 369.63      1
#                                                                             Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_speaker               
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward             < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="speaker"] = pchisq(369.63,1,lower.tail=FALSE)

# Test the random factor text
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + (1|speaker) + (1|word_type), data=combined.wordtimes.prewindows.publish.pause_probability.aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))
# Warning message:
# In checkConv(attr(opt, "derivs"), opt$par, ctrl = control$checkConv,  :
#   Model failed to converge with max|grad| = 0.00123553 (tol = 0.001, component 1)

# Check with converge_ok function from library sjstats
# https://www.rdocumentation.org/packages/sjstats/versions/0.14.3/topics/converge_ok
converge_ok(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_text)
# 0.000598206214817138 
#                 TRUE 

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_text,prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_text:     word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_text:     (1 | speaker) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                          Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_text 22 99468 99679 -49712    99424              
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward         23 99075 99296 -49514    99029 395.13      1
#                                                                          Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_text               
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward          < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="text"] = pchisq(395.13,1,lower.tail=FALSE)

# Test the random factor word type
prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + (1|speaker) + (1|text), data=combined.wordtimes.prewindows.publish.pause_probability.aux,family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))
# Warning message:
# In checkConv(attr(opt, "derivs"), opt$par, ctrl = control$checkConv,  :
#   Model failed to converge with max|grad| = 0.0016395 (tol = 0.001, component 1)

# Check with converge_ok function from library sjstats
# https://www.rdocumentation.org/packages/sjstats/versions/0.14.3/topics/converge_ok
converge_ok(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_word_type)
# 0.000580286629638291 
#                 TRUE 

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward,test="Chisq")
# Data: combined.wordtimes.prewindows.publish.pause_probability.aux
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_word_type:     word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_word_type:     (1 | speaker) + (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     word_position_normalized + language_iso_code + word_class_relevant_aux:language_iso_code + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                               Df    AIC    BIC logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_word_type 22 100053 100264 -50004   100009       
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward              23  99075  99296 -49514    99029 979.87
#                                                                               Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward.no_word_type                      
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.language.upward                   1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="cross-linguistic" & p.values$variable=="word type"] = pchisq(979.87,1,lower.tail=FALSE)


## Additional models for individual languages ##

## Main study excluding auxiliaries (AUX)

# Baure
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="brg")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

summary(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized + word_position_normalized +      (1 | speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  
#     subset = language_iso_code == "brg"))
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#   5328.1   5375.5  -2657.1   5314.1     6357 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -1.0960 -0.4844 -0.3599 -0.2331  5.2971 
# 
# Random effects:
#  Groups    Name        Variance  Std.Dev. 
#  word_type (Intercept) 2.460e-01 4.960e-01
#  text      (Intercept) 3.712e-01 6.093e-01
#  speaker   (Intercept) 1.320e-13 3.633e-07
# Number of obs: 6364, groups:  word_type, 3084; text, 37; speaker, 10
# 
# Fixed effects:
#                                    Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                       -1.958678   0.159983 -12.243  < 2e-16 ***
# word_class_relevant_no_auxV       -0.097049   0.084823  -1.144    0.253    
# word_length_characters_normalized -0.002117   0.045816  -0.046    0.963    
# word_position_normalized           0.601755   0.125412   4.798  1.6e-06 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) w____V wrd___
# wrd_cls___V -0.341              
# wrd_lngth__ -0.052 -0.315       
# wrd_pstn_nr -0.616  0.164 -0.075

# Odds ratio V vs. N: 0.9075115

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure)
#       word_class_relevant_no_auxV word_length_characters_normalized          word_position_normalized 
#                      -0.128390198                      -0.005170288                       0.494053181 

# Test fixed effects
drop1(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type)
#                                   Df    AIC     LRT   Pr(Chi)    
# <none>                               5328.1                      
# word_class_relevant_no_aux         1 5327.4  1.2693    0.2599    
# word_length_characters_normalized  1 5326.1  0.0021    0.9634    
# word_position_normalized           1 5348.8 22.6390 1.955e-06 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p values for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word class"] = pchisq(1.2693,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word length"] = pchisq(0.0021,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="position"] = pchisq(22.6390,1,lower.tail=FALSE)

# Test random factor speaker
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_speaker = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="brg")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_speaker,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_speaker: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_speaker:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_speaker:     (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                             Df    AIC    BIC  logLik deviance Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_speaker  6 5326.1 5366.7 -2657.1   5314.1             
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure             7 5328.1 5375.5 -2657.1   5314.1     0      1
#                                                                             Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_speaker           
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure                0.9992

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="speaker"] = 0.9992

# Test random factor text
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="brg")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_text,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_text:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_text:     (1 | speaker) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                          Df    AIC    BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_text  6 5514.8 5555.4 -2751.4   5502.8              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure          7 5328.1 5375.5 -2657.1   5314.1 188.67      1
#                                                                          Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_text               
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure          < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="text"] = pchisq(188.67,1,lower.tail=FALSE)

# Test random factor word type
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="brg")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_word_type:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_word_type:     (1 | speaker) + (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                               Df    AIC    BIC  logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_word_type  6 5349.3 5389.8 -2668.6   5337.3       
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure               7 5328.1 5375.5 -2657.1   5314.1 23.109
#                                                                               Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure.no_word_type                      
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure                   1  1.531e-06 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word type"] = pchisq(23.109,1,lower.tail=FALSE)


# Bora
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="boa")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

summary(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized + word_position_normalized +      (1 | speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  
#     subset = language_iso_code == "boa"))
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#  15599.7  15652.2  -7792.9  15585.7    13309 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -1.5456 -0.6490 -0.4957  0.9715  4.3592 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept) 0.3737   0.6113  
#  speaker   (Intercept) 0.0492   0.2218  
#  text      (Intercept) 0.3974   0.6304  
# Number of obs: 13316, groups:  word_type, 6273; speaker, 43; text, 37
# 
# Fixed effects:
#                                   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                       -0.95491    0.17862  -5.346 8.99e-08 ***
# word_class_relevant_no_auxV       -0.57027    0.04886 -11.672  < 2e-16 ***
# word_length_characters_normalized  0.18795    0.02492   7.542 4.64e-14 ***
# word_position_normalized          -0.09471    0.07237  -1.309    0.191    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) w____V wrd___
# wrd_cls___V -0.091              
# wrd_lngth__ -0.031 -0.220       
# wrd_pstn_nr -0.266 -0.101 -0.049

# Odds ratio V vs. N: 0.5653728

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora)
#       word_class_relevant_no_auxV word_length_characters_normalized          word_position_normalized 
#                       -0.60866484                        0.38676976                       -0.06058945 

# Test fixed effects
drop1(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type)
#                                   Df   AIC     LRT   Pr(Chi)    
# <none>                               15600                      
# word_class_relevant_no_aux         1 15732 134.533 < 2.2e-16 ***
# word_length_characters_normalized  1 15652  54.809 1.328e-13 ***
# word_position_normalized           1 15599   1.684    0.1944    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p values for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word class"] = pchisq(134.533,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word length"] = pchisq(54.809,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="position"] = pchisq(1.684,1,lower.tail=FALSE)

# Test random factor speaker
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_speaker = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="boa")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_speaker,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_speaker: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_speaker:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_speaker:     (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                            Df   AIC   BIC  logLik deviance Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_speaker  6 15598 15643 -7793.2    15586             
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora             7 15600 15652 -7792.9    15586 0.651      1
#                                                                            Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_speaker           
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora                0.4197

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="speaker"] = pchisq(0.651,1,lower.tail=FALSE)

# Test random factor text
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="boa")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_text,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_text:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_text:     (1 | speaker) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                         Df   AIC   BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_text  6 15721 15766 -7854.6    15709              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora          7 15600 15652 -7792.9    15586 123.41      1
#                                                                         Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_text               
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora          < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="text"] = pchisq(123.41,1,lower.tail=FALSE)

# Test random factor word type
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="boa")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_word_type:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_word_type:     (1 | speaker) + (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                              Df   AIC   BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_word_type  6 15768 15813 -7878.2    15756              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora               7 15600 15652 -7792.9    15586 170.63      1
#                                                                              Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora.no_word_type               
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora               < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word type"] = pchisq(170.63,1,lower.tail=FALSE)


# Chintang
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="ctn")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

summary(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized + word_position_normalized +      (1 | speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  
#     subset = language_iso_code == "ctn"))
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#   9018.7   9070.7  -4502.4   9004.7    12276 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -1.2265 -0.4221 -0.2930 -0.1973  7.5313 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept) 0.2003   0.4476  
#  speaker   (Intercept) 0.6963   0.8344  
#  text      (Intercept) 0.1708   0.4132  
# Number of obs: 12283, groups:  word_type, 5120; speaker, 68; text, 40
# 
# Fixed effects:
#                                   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                       -1.77381    0.16118 -11.005   <2e-16 ***
# word_class_relevant_no_auxV       -0.61356    0.06430  -9.543   <2e-16 ***
# word_length_characters_normalized  0.06841    0.03138   2.180   0.0293 *  
# word_position_normalized           0.08143    0.10573   0.770   0.4412    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) w____V wrd___
# wrd_cls___V -0.056              
# wrd_lngth__ -0.046 -0.197       
# wrd_pstn_nr -0.373 -0.280 -0.091

# Odds ratio V vs. N: 0.54142

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang)
#       word_class_relevant_no_auxV word_length_characters_normalized          word_position_normalized 
#                        -0.8710656                         0.1946171                         0.0666393 

# Test fixed effects
drop1(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type)
#                                   Df    AIC    LRT Pr(Chi)    
# <none>                               9018.7                   
# word_class_relevant_no_aux         1 9105.3 88.550 < 2e-16 ***
# word_length_characters_normalized  1 9021.2  4.476 0.03437 *  
# word_position_normalized           1 9017.3  0.570 0.45009    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p values for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word class"] = pchisq(88.550,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word length"] = pchisq(4.476,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="position"] = pchisq(0.570,1,lower.tail=FALSE)

# Test random factor speaker
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_speaker = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="ctn")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_speaker,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang, test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_speaker: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_speaker:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_speaker:     (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                                Df    AIC    BIC  logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_speaker  6 9072.3 9116.8 -4530.1   9060.3       
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang             7 9018.7 9070.7 -4502.4   9004.7 55.534
#                                                                                Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_speaker                      
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang                 1  9.185e-14 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="speaker"] = pchisq(55.534,1,lower.tail=FALSE)

# Test random factor text
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="ctn")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_text,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang, test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_text:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_text:     (1 | speaker) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                             Df    AIC    BIC  logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_text  6 9027.8 9072.3 -4507.9   9015.8       
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang          7 9018.7 9070.7 -4502.4   9004.7 11.072
#                                                                             Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_text                      
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang              1  0.0008764 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="text"] = pchisq(11.072,1,lower.tail=FALSE)

# Test random factor word type
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="ctn")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang, test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_word_type:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_word_type:     (1 | speaker) + (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                                  Df    AIC    BIC  logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_word_type  6 9046.3 9090.8 -4517.1   9034.3       
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang               7 9018.7 9070.7 -4502.4   9004.7 29.519
#                                                                                  Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang.no_word_type                      
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang                   1  5.537e-08 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word type"] = pchisq(29.519,1,lower.tail=FALSE)


# Dutch
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="nld")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

summary(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized + word_position_normalized +      (1 | speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  
#     subset = language_iso_code == "nld"))
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#   7632.9   7683.5  -3809.5   7618.9    10140 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -0.8049 -0.4031 -0.3533 -0.2967  4.4546 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept) 0.06649  0.2579  
#  speaker   (Intercept) 0.16152  0.4019  
#  text      (Intercept) 0.04937  0.2222  
# Number of obs: 10147, groups:  word_type, 2589; speaker, 42; text, 17
# 
# Fixed effects:
#                                   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                       -2.09952    0.12633 -16.619   <2e-16 ***
# word_class_relevant_no_auxV       -0.12288    0.07102  -1.730   0.0836 .  
# word_length_characters_normalized  0.08013    0.02821   2.841   0.0045 ** 
# word_position_normalized           0.09780    0.10358   0.944   0.3450    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) w____V wrd___
# wrd_cls___V -0.378              
# wrd_lngth__ -0.245  0.272       
# wrd_pstn_nr -0.516  0.062 -0.130

# Odds ratio V vs. N: 0.8843698

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch)
#       word_class_relevant_no_auxV word_length_characters_normalized          word_position_normalized 
#                       -0.17837242                        0.28244905                        0.08988945 

# Test fixed effects
drop1(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type)
#                                   Df    AIC    LRT  Pr(Chi)   
# <none>                               7632.9                   
# word_class_relevant_no_aux         1 7633.9 2.9616 0.085261 . 
# word_length_characters_normalized  1 7638.7 7.8131 0.005187 **
# word_position_normalized           1 7631.8 0.8774 0.348917   
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p values for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word class"] = pchisq(2.9616,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word length"] = pchisq(7.8131,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="position"] = pchisq(0.8774,1,lower.tail=FALSE)

# Test random factor speaker
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_speaker = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="nld")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_speaker,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_speaker: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_speaker:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_speaker:     (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                             Df    AIC    BIC  logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_speaker  6 7689.1 7732.5 -3838.6   7677.1       
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch             7 7632.9 7683.5 -3809.5   7618.9 58.195
#                                                                             Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_speaker                      
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch                 1  2.374e-14 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="speaker"] = pchisq(58.195,1,lower.tail=FALSE)

# Test random factor text
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="nld")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_text,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_text:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_text:     (1 | speaker) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                          Df    AIC    BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_text  6 7632.1 7675.4 -3810.0   7620.1              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch          7 7632.9 7683.5 -3809.5   7618.9 1.1475      1
#                                                                          Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_text           
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch             0.2841

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="text"] = pchisq(1.1475,1,lower.tail=FALSE)

# Test random factor word type
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="nld")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_word_type:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_word_type:     (1 | speaker) + (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                               Df    AIC    BIC  logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_word_type  6 7634.2 7677.5 -3811.1   7622.2       
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch               7 7632.9 7683.5 -3809.5   7618.9 3.2485
#                                                                               Chi Df Pr(>Chisq)  
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch.no_word_type                    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch                   1    0.07149 .
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word type"] = pchisq(3.2485,1,lower.tail=FALSE)


# English
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="eng")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

summary(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized + word_position_normalized +      (1 | speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  
#     subset = language_iso_code == "eng"))
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#  16313.5  16368.2  -8149.8  16299.5    18275 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -1.1967 -0.4767 -0.3994 -0.3135  4.4290 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept) 0.14481  0.3805  
#  speaker   (Intercept) 0.13295  0.3646  
#  text      (Intercept) 0.02249  0.1500  
# Number of obs: 18282, groups:  word_type, 2941; speaker, 80; text, 47
# 
# Fixed effects:
#                                   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                       -1.73359    0.08212 -21.109  < 2e-16 ***
# word_class_relevant_no_auxV        0.22471    0.05642   3.983 6.81e-05 ***
# word_length_characters_normalized  0.08658    0.02538   3.412 0.000645 ***
# word_position_normalized          -0.18090    0.07257  -2.493 0.012672 *  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) w____V wrd___
# wrd_cls___V -0.447              
# wrd_lngth__ -0.313  0.149       
# wrd_pstn_nr -0.569  0.152 -0.067

# Odds ratio V vs. N: 1.25196

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english)
#       word_class_relevant_no_auxV word_length_characters_normalized          word_position_normalized 
#                         0.2922238                         0.2444516                        -0.1400608 

# Test fixed effects
drop1(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type)
#                                   Df   AIC     LRT   Pr(Chi)    
# <none>                               16314                      
# word_class_relevant_no_aux         1 16327 15.4155 8.628e-05 ***
# word_length_characters_normalized  1 16323 11.0928 0.0008666 ***
# word_position_normalized           1 16318  6.1098 0.0134437 *  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p values for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="word class"] = pchisq(15.4155,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="word length"] = pchisq(11.0928,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="position"] = pchisq(6.1098,1,lower.tail=FALSE)

# Test random factor speaker
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_speaker = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="eng")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_speaker,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_speaker: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_speaker:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_speaker:     (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                               Df   AIC   BIC  logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_speaker  6 16405 16451 -8196.3    16393       
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english             7 16314 16368 -8149.8    16300 93.005
#                                                                               Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_speaker                      
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english                 1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="speaker"] = pchisq(93.005,1,lower.tail=FALSE)

# Test random factor text
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="eng")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_text,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_text:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_text:     (1 | speaker) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                            Df   AIC   BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_text  6 16315 16362 -8151.5    16303              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english          7 16314 16368 -8149.8    16300 3.5376      1
#                                                                            Pr(>Chisq)  
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_text             
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english            0.05999 .
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="text"] = pchisq(3.5376,1,lower.tail=FALSE)

# Test random factor word type
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="eng")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_word_type:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_word_type:     (1 | speaker) + (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                                 Df   AIC   BIC  logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_word_type  6 16543 16590 -8265.5    16531       
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english               7 16314 16368 -8149.8    16300 231.44
#                                                                                 Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english.no_word_type                      
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english                   1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="word type"] = pchisq(231.44,1,lower.tail=FALSE)


# Even
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="eve")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

summary(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized + word_position_normalized +      (1 | speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  
#     subset = language_iso_code == "eve"))
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#  19611.0  19665.1  -9798.5  19597.0    17010 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -1.4649 -0.6386 -0.4698  0.9453  4.2388 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept) 0.36552  0.6046  
#  text      (Intercept) 0.05213  0.2283  
#  speaker   (Intercept) 0.12077  0.3475  
# Number of obs: 17017, groups:  word_type, 7357; text, 67; speaker, 32
# 
# Fixed effects:
#                                   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                       -0.51662    0.09102  -5.676 1.38e-08 ***
# word_class_relevant_no_auxV       -0.91129    0.04395 -20.736  < 2e-16 ***
# word_length_characters_normalized  0.10609    0.02334   4.546 5.47e-06 ***
# word_position_normalized           0.23948    0.06537   3.663 0.000249 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) w____V wrd___
# wrd_cls___V -0.139              
# wrd_lngth__ -0.143 -0.139       
# wrd_pstn_nr -0.404 -0.155 -0.031

# Odds ratio V vs. N:  0.4020053

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even)
#       word_class_relevant_no_auxV word_length_characters_normalized          word_position_normalized 
#                        -0.9898201                         0.2107227                         0.1529148 

# Test fixed effects
drop1(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type)
#                                   Df   AIC    LRT   Pr(Chi)    
# <none>                               19611                     
# word_class_relevant_no_aux         1 20033 424.28 < 2.2e-16 ***
# word_length_characters_normalized  1 19629  20.08 7.425e-06 ***
# word_position_normalized           1 19622  13.29 0.0002662 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p values for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="word class"] = pchisq(424.28,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="word length"] = pchisq(20.08,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="position"] = pchisq(13.29,1,lower.tail=FALSE)

# Test random factor speaker
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_speaker = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="eve")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_speaker,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_speaker: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_speaker:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_speaker:     (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                            Df   AIC   BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_speaker  6 19639 19686 -9813.5    19627              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even             7 19611 19665 -9798.5    19597 30.051      1
#                                                                            Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_speaker               
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even             4.208e-08 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="speaker"] = pchisq(30.051,1,lower.tail=FALSE)

# Test random factor text
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) +  (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="eve")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_text,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_text:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_text:     (1 | speaker) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                         Df   AIC   BIC  logLik deviance Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_text  6 19649 19695 -9818.3    19637             
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even          7 19611 19665 -9798.5    19597 39.66      1
#                                                                         Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_text               
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even          3.022e-10 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="text"] = pchisq(39.66,1,lower.tail=FALSE)

# Test random factor word type
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="eve")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_word_type:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_word_type:     (1 | speaker) + (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                              Df   AIC   BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_word_type  6 19906 19952 -9946.8    19894              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even               7 19611 19665 -9798.5    19597 296.69      1
#                                                                              Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even.no_word_type               
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even               < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="word type"] = pchisq(296.69,1,lower.tail=FALSE)


# Hoocąk
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="win")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

summary(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized + word_position_normalized +      (1 | speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  
#     subset = language_iso_code == "win"))
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#  10447.1  10496.7  -5216.5  10433.1     8818 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.2188 -0.6499 -0.4604  0.8548  5.8107 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept) 0.3952   0.6286  
#  text      (Intercept) 0.1098   0.3314  
#  speaker   (Intercept) 0.1460   0.3821  
# Number of obs: 8825, groups:  word_type, 4231; text, 62; speaker, 28
# 
# Fixed effects:
#                                   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                        0.07224    0.11950   0.605    0.545    
# word_class_relevant_no_auxV       -1.21800    0.06776 -17.974  < 2e-16 ***
# word_length_characters_normalized  0.14933    0.02893   5.161 2.46e-07 ***
# word_position_normalized          -0.02598    0.09216  -0.282    0.778    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) w____V wrd___
# wrd_cls___V -0.244              
# wrd_lngth__ -0.073 -0.176       
# wrd_pstn_nr -0.363 -0.240 -0.046

# Odds ratio V vs. N: 0.2958212

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak)
#       word_class_relevant_no_auxV word_length_characters_normalized          word_position_normalized 
#                       -1.20589254                        0.31766975                       -0.01600474 

# Test fixed effects
drop1(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type)
#                                   Df   AIC    LRT   Pr(Chi)    
# <none>                               10447                     
# word_class_relevant_no_aux         1 10786 341.25 < 2.2e-16 ***
# word_length_characters_normalized  1 10471  26.21 3.066e-07 ***
# word_position_normalized           1 10445   0.08      0.78    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p values for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="word class"] = pchisq(341.25,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="word length"] = pchisq(26.21,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="position"] = pchisq(0.08,1,lower.tail=FALSE)

# Test random factor speaker
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_speaker = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="win")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_speaker,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_speaker: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_speaker:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_speaker:     (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                              Df   AIC   BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_speaker  6 10461 10504 -5224.6    10449              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak             7 10447 10497 -5216.5    10433 16.088      1
#                                                                              Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_speaker               
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak             6.046e-05 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="speaker"] = pchisq(16.088,1,lower.tail=FALSE)

# Test random factor text
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="win")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_text,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_text:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_text:     (1 | speaker) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                           Df   AIC   BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_text  6 10485 10528 -5236.7    10473              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak          7 10447 10497 -5216.5    10433 40.288      1
#                                                                           Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_text               
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak          2.192e-10 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="text"] = pchisq(40.288,1,lower.tail=FALSE)

# Test random factor word type
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="win")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_word_type:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_word_type:     (1 | speaker) + (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                                Df   AIC   BIC  logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_word_type  6 10553 10596 -5270.6    10541       
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak               7 10447 10497 -5216.5    10433 108.22
#                                                                                Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak.no_word_type                      
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak                   1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="word type"] = pchisq(108.22,1,lower.tail=FALSE)


# Nǁng
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="ngh")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

summary(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized + word_position_normalized +      (1 | speaker) + (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  
#     subset = language_iso_code == "ngh"))
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#   5179.0   5229.2  -2582.5   5165.0     9612 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -0.9268 -0.3391 -0.2194 -0.1487 10.0339 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept) 0.2849   0.5338  
#  text      (Intercept) 0.1247   0.3531  
#  speaker   (Intercept) 0.4907   0.7005  
# Number of obs: 9619, groups:  word_type, 1162; text, 33; speaker, 7
# 
# Fixed effects:
#                                   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                       -2.06215    0.31369  -6.574 4.90e-11 ***
# word_class_relevant_no_auxV       -0.76219    0.09365  -8.138 4.01e-16 ***
# word_length_characters_normalized  0.09439    0.04977   1.897   0.0579 .  
# word_position_normalized           0.28926    0.14632   1.977   0.0481 *  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) w____V wrd___
# wrd_cls___V -0.219              
# wrd_lngth__ -0.159  0.225       
# wrd_pstn_nr -0.372  0.109 -0.088

# Odds ratio V vs. N: 0.4666434

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu)
#       word_class_relevant_no_auxV word_length_characters_normalized          word_position_normalized 
#                        -1.2625968                         0.2900664                         0.2801441 

# Test fixed effects
drop1(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | speaker) + (1 | text) + (1 | word_type)
#                                   Df    AIC    LRT   Pr(Chi)    
# <none>                               5179.0                     
# word_class_relevant_no_aux         1 5238.4 61.373 4.723e-15 ***
# word_length_characters_normalized  1 5180.3  3.325   0.06824 .  
# word_position_normalized           1 5180.8  3.770   0.05218 .  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p values for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & grepl("^N",p.values$model) & p.values$variable=="word class"] = pchisq(61.373,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & grepl("^N",p.values$model) & p.values$variable=="word length"] = pchisq(3.325,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & grepl("^N",p.values$model) & p.values$variable=="position"] = pchisq(3.770,1,lower.tail=FALSE)

# Test random factor speaker
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_speaker = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="ngh")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_speaker,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_speaker: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_speaker:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_speaker:     (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                           Df    AIC    BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_speaker  6 5294.4 5337.4 -2641.2   5282.4              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu             7 5179.0 5229.2 -2582.5   5165.0 117.33      1
#                                                                           Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_speaker               
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu             < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & grepl("^N",p.values$model) & p.values$variable=="speaker"] = pchisq(117.33,1,lower.tail=FALSE)

# Test random factor text
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="ngh")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_text,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_text:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_text:     (1 | speaker) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                        Df    AIC    BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_text  6 5193.9 5236.9 -2590.9   5181.9              
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu          7 5179.0 5229.2 -2582.5   5165.0 16.841      1
#                                                                        Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_text               
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu          4.064e-05 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & grepl("^N",p.values$model) & p.values$variable=="text"] = pchisq(16.841,1,lower.tail=FALSE)

# Test random factor word type
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="ngh")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_word_type:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_word_type:     (1 | speaker) + (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu:     (1 | speaker) + (1 | text) + (1 | word_type)
#                                                                             Df    AIC    BIC  logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_word_type  6 5211.4 5254.4 -2599.7   5199.4       
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu               7 5179.0 5229.2 -2582.5   5165.0 34.396
#                                                                             Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu.no_word_type                      
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu                   1  4.496e-09 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & grepl("^N",p.values$model) & p.values$variable=="word type"] = pchisq(34.396,1,lower.tail=FALSE)


# Texistepec Popoluca
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|text) + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="poq")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

summary(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux +  
#     word_length_characters_normalized + word_position_normalized +      (1 | text) + (1 | word_type)
#    Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  
#     subset = language_iso_code == "poq"))
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#   5344.2   5385.8  -2666.1   5332.2     7580 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -0.7577 -0.3548 -0.2967 -0.2505  4.9566 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept) 0.4676   0.6838  
#  text      (Intercept) 0.0000   0.0000  
# Number of obs: 7586, groups:  word_type, 2215; text, 6
# 
# Fixed effects:
#                                   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                       -2.21713    0.13884 -15.969  < 2e-16 ***
# word_class_relevant_no_auxV       -0.71318    0.09405  -7.583 3.37e-14 ***
# word_length_characters_normalized  0.11530    0.04155   2.775  0.00552 ** 
# word_position_normalized           0.61407    0.14442   4.252 2.12e-05 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) w____V wrd___
# wrd_cls___V -0.450              
# wrd_lngth__ -0.109 -0.151       
# wrd_pstn_nr -0.811  0.112 -0.067

# Odds ratio V vs. N: 0.4900833

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca)
#       word_class_relevant_no_auxV word_length_characters_normalized          word_position_normalized 
#                        -1.0255874                         0.3786292                         0.5218570 

# Test fixed effects
drop1(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
#     word_length_characters_normalized + word_position_normalized + 
#     (1 | text) + (1 | word_type)
#                                   Df    AIC    LRT   Pr(Chi)    
# <none>                               5344.2                     
# word_class_relevant_no_aux         1 5396.8 54.608 1.472e-13 ***
# word_length_characters_normalized  1 5349.6  7.371  0.006629 ** 
# word_position_normalized           1 5360.7 18.465 1.731e-05 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p values for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="word class"] = pchisq(54.608,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="word length"] = pchisq(7.371,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="position"] = pchisq(18.465,1,lower.tail=FALSE)

# No random factor speaker in Texistepec Popoluca because there is only one speaker in this subcorpus

# Test random factor text
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|word_type), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="poq")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca.no_text,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca.no_text:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca.no_text:     (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca:     (1 | text) + (1 | word_type)
#                                                                             Df    AIC    BIC  logLik deviance Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca.no_text  5 5342.2 5376.9 -2666.1   5332.2             
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca          6 5344.2 5385.8 -2666.1   5332.2     0      1
#                                                                             Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca.no_text           
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca             0.9998

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="text"] = 0.9998

# Test random factor word type
prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + word_length_characters_normalized + word_position_normalized + (1|text), data=droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=language_iso_code=="poq")),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca,test="Chisq")
# Data: droplevels(subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca.no_word_type:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca.no_word_type:     (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca: pause_in_pre_word_window_factor ~ word_class_relevant_no_aux + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca:     word_length_characters_normalized + word_position_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca:     (1 | text) + (1 | word_type)
#                                                                                  Df    AIC    BIC  logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca.no_word_type  5 5386.3 5421.0 -2688.2   5376.3       
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca               6 5344.2 5385.8 -2666.1   5332.2 44.121
#                                                                                  Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca.no_word_type                      
# prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca                   1  3.087e-11 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="word type"] = pchisq(44.121,1,lower.tail=FALSE)


## Alternative study including auxiliaries (AUX)

# Baure (same as main study, no auxiliaries)
# Bora (same as main study, no auxiliaries)
# Chintang (same as main study, no auxiliaries)
# Dutch (same as main study, no auxiliaries)

# English
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="eng"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

summary(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized +  
#     word_position_normalized + (1 | speaker) + (1 | text) + (1 |      word_type)
#    Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,      subset = language_iso_code == "eng")
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#  17827.4  17882.8  -8906.7  17813.4    20142 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -1.2297 -0.4726 -0.3987 -0.3144  4.3861 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept) 0.13244  0.3639  
#  speaker   (Intercept) 0.12946  0.3598  
#  text      (Intercept) 0.02208  0.1486  
# Number of obs: 20149, groups:  word_type, 2952; speaker, 80; text, 47
# 
# Fixed effects:
#                                   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                       -1.77604    0.08021 -22.142  < 2e-16 ***
# word_class_relevant_auxV           0.22595    0.05516   4.096 4.21e-05 ***
# word_length_characters_normalized  0.08956    0.02457   3.646 0.000266 ***
# word_position_normalized          -0.12150    0.06989  -1.738 0.082145 .  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___
# wrd_clss__V -0.471              
# wrd_lngth__ -0.304  0.183       
# wrd_pstn_nr -0.561  0.157 -0.075

# Odds ratio V vs. N:  1.253513

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english)
#          word_class_relevant_auxV word_length_characters_normalized          word_position_normalized 
#                         0.2906399                         0.2652137                        -0.0945079 

# Test fixed effects
drop1(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
#     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
#     word_type)
#                                   Df   AIC     LRT   Pr(Chi)    
# <none>                               17827                      
# word_class_relevant_aux            1 17842 16.3401 5.293e-05 ***
# word_length_characters_normalized  1 17838 12.6225 0.0003811 ***
# word_position_normalized           1 17828  2.9762 0.0844963 .  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p values for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="word class"] = pchisq(16.3401,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="word length"] = pchisq(12.6225,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="position"] = pchisq(2.9762,1,lower.tail=FALSE)

# Test random factor speaker
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_speaker = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|text) + (1|word_type), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="eng"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_speaker,prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english, test="Chisq")
# Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_speaker: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_speaker:     word_position_normalized + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english:     word_type)
#                                                                           Df   AIC   BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_speaker  6 17915 17963 -8951.7    17903              
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english             7 17827 17883 -8906.7    17813 89.904      1
#                                                                           Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_speaker               
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english             < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="speaker"] = pchisq(89.904,1,lower.tail=FALSE)

# Test random factor text
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|word_type), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="eng"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_text,prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english, test="Chisq")
# Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_text:     word_position_normalized + (1 | speaker) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english:     word_type)
#                                                                        Df   AIC   BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_text  6 17829 17876 -8908.3    17817              
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english          7 17827 17883 -8906.7    17813 3.2532      1
#                                                                        Pr(>Chisq)  
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_text             
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english            0.07128 .
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="text"] = pchisq(3.2532,1,lower.tail=FALSE)

# Test random factor word type
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="eng"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english, test="Chisq")
# Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_word_type:     word_position_normalized + (1 | speaker) + (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english:     word_type)
#                                                                             Df   AIC   BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_word_type  6 18066 18114 -9027.2    18054              
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english               7 17827 17883 -8906.7    17813 240.86      1
#                                                                             Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english.no_word_type               
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english               < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="word type"] = pchisq(240.86,1,lower.tail=FALSE)


# Even
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="eve"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

summary(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized +  
#     word_position_normalized + (1 | speaker) + (1 | text) + (1 |      word_type)
#    Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,      subset = language_iso_code == "eve")
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#  20170.4  20224.8 -10078.2  20156.4    17581 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -1.4743 -0.6341 -0.4675  0.9402  4.2947 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept) 0.35782  0.5982  
#  text      (Intercept) 0.05447  0.2334  
#  speaker   (Intercept) 0.12375  0.3518  
# Number of obs: 17588, groups:  word_type, 7428; text, 67; speaker, 32
# 
# Fixed effects:
#                                   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                       -0.50598    0.09151  -5.529 3.22e-08 ***
# word_class_relevant_auxV          -0.90857    0.04326 -21.001  < 2e-16 ***
# word_length_characters_normalized  0.10686    0.02284   4.678 2.90e-06 ***
# word_position_normalized           0.22957    0.06456   3.556 0.000377 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___
# wrd_clss__V -0.147              
# wrd_lngth__ -0.137 -0.117       
# wrd_pstn_nr -0.396 -0.152 -0.036

# Odds ratio V vs. N: 0.4031002

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even)
#          word_class_relevant_auxV word_length_characters_normalized          word_position_normalized 
#                        -0.9872519                         0.2144189                         0.1464858 

# Test fixed effects
drop1(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
#     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
#     word_type)
#                                   Df   AIC    LRT   Pr(Chi)    
# <none>                               20170                     
# word_class_relevant_aux            1 20602 434.16 < 2.2e-16 ***
# word_length_characters_normalized  1 20190  21.24 4.061e-06 ***
# word_position_normalized           1 20181  12.52 0.0004022 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p values for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="word class"] = pchisq(434.16,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="word length"] = pchisq(21.24,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="position"] = pchisq(12.52,1,lower.tail=FALSE)

# Test random factor speaker
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_speaker = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|text) + (1|word_type), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="eve"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_speaker,prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even,test="Chisq")
# Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_speaker: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_speaker:     word_position_normalized + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even:     word_type)
#                                                                        Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_speaker  6 20199 20245 -10093    20187              
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even             7 20170 20225 -10078    20156 30.277      1
#                                                                        Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_speaker               
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even             3.744e-08 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="speaker"] = pchisq(30.277,1,lower.tail=FALSE)

# Test random factor text
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|word_type), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="eve"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_text,prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even,test="Chisq")
# Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_text:     word_position_normalized + (1 | speaker) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even:     word_type)
#                                                                     Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_text  6 20212 20258 -10100    20200              
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even          7 20170 20225 -10078    20156 43.518      1
#                                                                     Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_text               
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even            4.2e-11 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="text"] = pchisq(43.518,1,lower.tail=FALSE)

# Test random factor word type
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="eve"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even,test="Chisq")
# Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_word_type:     word_position_normalized + (1 | speaker) + (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even:     word_type)
#                                                                          Df   AIC   BIC logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_word_type  6 20466 20513 -10227    20454              
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even               7 20170 20225 -10078    20156 297.96      1
#                                                                          Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even.no_word_type               
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even               < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="word type"] = pchisq(297.96,1,lower.tail=FALSE)


# Hoocąk
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text) + (1|word_type), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="win"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

summary(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized +  
#     word_position_normalized + (1 | speaker) + (1 | text) + (1 |      word_type)
#    Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,      subset = language_iso_code == "win")
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#  11801.5  11852.1  -5893.7  11787.5    10256 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -2.1679 -0.6164 -0.4424  0.8361  5.7892 
# 
# Random effects:
#  Groups    Name        Variance Std.Dev.
#  word_type (Intercept) 0.4260   0.6527  
#  text      (Intercept) 0.1169   0.3419  
#  speaker   (Intercept) 0.1395   0.3735  
# Number of obs: 10263, groups:  word_type, 4968; text, 62; speaker, 28
# 
# Fixed effects:
#                                   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                        0.08042    0.11804   0.681    0.496    
# word_class_relevant_auxV          -1.33425    0.06673 -19.996  < 2e-16 ***
# word_length_characters_normalized  0.15516    0.02745   5.652 1.58e-08 ***
# word_position_normalized          -0.03985    0.08677  -0.459    0.646    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___
# wrd_clss__V -0.257              
# wrd_lngth__ -0.068 -0.182       
# wrd_pstn_nr -0.344 -0.251 -0.049

# Odds ratio V vs. N: 0.2633556

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak)
#          word_class_relevant_auxV word_length_characters_normalized          word_position_normalized 
#                       -1.28941565                        0.33727145                       -0.02521699 

# Test fixed effects
drop1(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
#     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
#     word_type)
#                                   Df   AIC    LRT   Pr(Chi)    
# <none>                               11802                     
# word_class_relevant_aux            1 12223 423.52 < 2.2e-16 ***
# word_length_characters_normalized  1 11831  31.42 2.076e-08 ***
# word_position_normalized           1 11800   0.21    0.6497    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p values for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="word class"] = pchisq(423.52,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="word length"] = pchisq(31.42,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="position"] = pchisq(0.21,1,lower.tail=FALSE)

# Test random factor speaker
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_speaker = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|text) + (1|word_type), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="win"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_speaker,prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak,test="Chisq")
# Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_speaker: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_speaker:     word_position_normalized + (1 | text) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak:     word_type)
#                                                                          Df   AIC   BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_speaker  6 11819 11862 -5903.4    11807              
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak             7 11802 11852 -5893.7    11788 19.264      1
#                                                                          Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_speaker               
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak             1.138e-05 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="speaker"] = pchisq(19.264,1,lower.tail=FALSE)

# Test random factor text
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) +  (1|word_type), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="win"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_text,prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak,test="Chisq")
# Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_text:     word_position_normalized + (1 | speaker) + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak:     word_type)
#                                                                       Df   AIC   BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_text  6 11852 11896 -5920.1    11840              
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak          7 11802 11852 -5893.7    11788 52.767      1
#                                                                       Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_text               
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak          3.755e-13 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="text"] = pchisq(52.767,1,lower.tail=FALSE)

# Test random factor word type
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|speaker) + (1|text), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="win"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak,test="Chisq")
# Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_word_type:     word_position_normalized + (1 | speaker) + (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak:     word_position_normalized + (1 | speaker) + (1 | text) + (1 | 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak:     word_type)
#                                                                            Df   AIC   BIC  logLik deviance  Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_word_type  6 11926 11969 -5956.7    11914              
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak               7 11802 11852 -5893.7    11788 125.98      1
#                                                                            Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak.no_word_type               
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak               < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="word type"] = pchisq(125.98,1,lower.tail=FALSE)


# Nǁng (same as main study, no auxiliaries)

# Texistepec Popoluca
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|text) + (1|word_type), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="poq"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

summary(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca)
# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
#  Family: binomial  ( logit )
# Formula: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized +  
#     word_position_normalized + (1 | text) + (1 | word_type)
#    Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,      subset = language_iso_code == "poq")
# Control: glmerControl(optimizer = "bobyqa")
# 
#      AIC      BIC   logLik deviance df.resid 
#   6374.6   6417.2  -3181.3   6362.6     8933 
# 
# Scaled residuals: 
#     Min      1Q  Median      3Q     Max 
# -0.8007 -0.3617 -0.3047 -0.2529  5.4009 
# 
# Random effects:
#  Groups    Name        Variance  Std.Dev. 
#  word_type (Intercept) 5.750e-01 7.583e-01
#  text      (Intercept) 8.419e-15 9.175e-08
# Number of obs: 8939, groups:  word_type, 2245; text, 6
# 
# Fixed effects:
#                                   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                       -2.26013    0.13636 -16.575  < 2e-16 ***
# word_class_relevant_auxV          -0.64770    0.09561  -6.774 1.25e-11 ***
# word_length_characters_normalized  0.08250    0.04138   1.993   0.0462 *  
# word_position_normalized           0.66171    0.13737   4.817 1.46e-06 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) wr___V wrd___
# wrd_clss__V -0.481              
# wrd_lngth__ -0.105 -0.119       
# wrd_pstn_nr -0.790  0.116 -0.087

# Odds ratio V vs. N: 0.5232479

# Standardized coefficients
lm.beta.lmer(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca)
#          word_class_relevant_auxV word_length_characters_normalized          word_position_normalized 
#                        -0.8818008                         0.2767031                         0.5598706 

# Test fixed effects
drop1(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca,test="Chisq")
# Single term deletions
# 
# Model:
# pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
#     word_position_normalized + (1 | text) + (1 | word_type)
#                                   Df    AIC    LRT   Pr(Chi)    
# <none>                               6374.6                     
# word_class_relevant_aux            1 6417.3 44.674 2.327e-11 ***
# word_length_characters_normalized  1 6376.5  3.866   0.04926 *  
# word_position_normalized           1 6396.4 23.742 1.102e-06 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p values for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="word class"] = pchisq(44.674,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="word length"] = pchisq(3.866,1,lower.tail=FALSE)
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="position"] = pchisq(23.742,1,lower.tail=FALSE)

# No random factor speaker in Texistepec Popoluca because there is only one speaker in this subcorpus

# Test random factor text
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca.no_text = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|word_type), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="poq"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca.no_text,prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca,test="Chisq")
# Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca.no_text: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca.no_text:     word_position_normalized + (1 | word_type)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca:     word_position_normalized + (1 | text) + (1 | word_type)
#                                                                         Df    AIC    BIC  logLik deviance Chisq Chi Df
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca.no_text  5 6372.6 6408.1 -3181.3   6362.6             
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca          6 6374.6 6417.2 -3181.3   6362.6     0      1
#                                                                         Pr(>Chisq)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca.no_text           
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca             0.9997

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="text"] = 0.9997

# Test random factor word type
prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca.no_word_type = glmer(pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + word_position_normalized + (1|text), data=subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=language_iso_code=="poq"),family=binomial(link=logit),control=glmerControl(optimizer="bobyqa"))

anova(prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca.no_word_type,prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca,test="Chisq")
# Data: subset(combined.wordtimes.prewindows.publish.pause_probability.aux,  ...
# Models:
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca.no_word_type: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca.no_word_type:     word_position_normalized + (1 | text)
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca: pause_in_pre_word_window_factor ~ word_class_relevant_aux + word_length_characters_normalized + 
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca:     word_position_normalized + (1 | text) + (1 | word_type)
#                                                                              Df    AIC    BIC  logLik deviance  Chisq
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca.no_word_type  5 6454.5 6490.0 -3222.2   6444.5       
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca               6 6374.6 6417.2 -3181.3   6362.6 81.821
#                                                                              Chi Df Pr(>Chisq)    
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca.no_word_type                      
# prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca                   1  < 2.2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Store p value for multiple testing correction
p.values$p.value[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="word type"] = pchisq(81.821,1,lower.tail=FALSE)


### Adjust p values for multiple testing ###

p.values = p.values[c("study","auxiliaries","model","factor","variable","p.value")]

# Adjust p values using the Benjamini-Hochberg method
p.values$p.value.adjusted.BH = p.adjust(p.values$p.value,method="BH")

p.values$stars = stars.pval(p.values$p.value)
p.values$stars.adjusted.BH = stars.pval(p.values$p.value.adjusted.BH)

p.values$stars[p.values$stars == " "] = "n.s."
p.values$stars.adjusted.BH[p.values$stars.adjusted.BH == " "] = "n.s."

p.values$stars[p.values$stars == "."] = "n.s."
p.values$stars.adjusted.BH[p.values$stars.adjusted.BH == "."] = "n.s."


### Effects plots ###

## Articulation rate ##

## Main study excluding auxiliaries (AUX)

# Based on fixed model structure

pos.effect.articulation_speed.aux_other.baure = as.data.frame(effect("word_class_relevant_no_aux", prewindow.articulation_speed.n_vs_v.aux_other.pos.final.baure.reml))
# NOTE: word_class_relevant_no_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_other.baure
#   word_class_relevant_no_aux      fit        se    lower    upper
# 1                        N 13.41435 0.2057463 13.01101 13.81770
# 2                        V 14.02631 0.1856438 13.66238 14.39024

pos.effect.articulation_speed.aux_other.bora = as.data.frame(effect("word_class_relevant_no_aux", prewindow.articulation_speed.n_vs_v.aux_other.pos.final.bora.reml))
# NOTE: word_class_relevant_no_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_other.bora
#   word_class_relevant_no_aux      fit        se    lower    upper
# 1                        N 17.31525 0.7089080 15.92565 18.70485
# 2                        V 17.44697 0.7055903 16.06388 18.83007

pos.effect.articulation_speed.aux_other.chintang = as.data.frame(effect("word_class_relevant_no_aux", prewindow.articulation_speed.n_vs_v.aux_other.pos.final.chintang.reml))
# NOTE: word_class_relevant_no_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_other.chintang
#   word_class_relevant_no_aux      fit        se    lower    upper
# 1                        N 16.28563 0.3145141 15.66912 16.90213
# 2                        V 17.45794 0.3060277 16.85807 18.05781

pos.effect.articulation_speed.aux_other.dutch = as.data.frame(effect("word_class_relevant_no_aux", prewindow.articulation_speed.n_vs_v.aux_other.pos.final.dutch.reml))
# NOTE: word_class_relevant_no_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_other.dutch
#   word_class_relevant_no_aux      fit        se    lower    upper
# 1                        N 20.95468 0.4483315 20.07585 21.83351
# 2                        V 21.38709 0.4450006 20.51479 22.25939

pos.effect.articulation_speed.aux_other.english = as.data.frame(effect("word_class_relevant_no_aux", prewindow.articulation_speed.n_vs_v.aux_other.pos.final.english.reml))
# NOTE: word_class_relevant_no_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_other.english
#   word_class_relevant_no_aux      fit        se    lower    upper
# 1                        N 18.63114 0.2609484 18.11966 19.14263
# 2                        V 18.88769 0.2655072 18.36727 19.40811

pos.effect.articulation_speed.aux_other.even = as.data.frame(effect("word_class_relevant_no_aux", prewindow.articulation_speed.n_vs_v.aux_other.pos.final.even.reml))
# NOTE: word_class_relevant_no_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_other.even
#   word_class_relevant_no_aux      fit        se    lower    upper
# 1                        N 14.55159 0.2501989 14.06117 15.04202
# 2                        V 15.09216 0.2484819 14.60510 15.57922

pos.effect.articulation_speed.aux_other.hoocak = as.data.frame(effect("word_class_relevant_no_aux", prewindow.articulation_speed.n_vs_v.aux_other.pos.final.hoocak.reml))
# NOTE: word_class_relevant_no_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_other.hoocak
#   word_class_relevant_no_aux      fit        se    lower    upper
# 1                        N 12.57591 0.4347092 11.72373 13.42809
# 2                        V 13.16923 0.4213454 12.34325 13.99521

pos.effect.articulation_speed.aux_other.nuu = as.data.frame(effect("word_class_relevant_no_aux", prewindow.articulation_speed.n_vs_v.aux_other.pos.final.nuu.reml))
# NOTE: word_class_relevant_no_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_other.nuu
#   word_class_relevant_no_aux      fit        se    lower    upper
# 1                        N 16.28909 0.7441784 14.83033 17.74785
# 2                        V 16.14416 0.7386913 14.69615 17.59216

pos.effect.articulation_speed.aux_other.popoluca = as.data.frame(effect("word_class_relevant_no_aux", prewindow.articulation_speed.n_vs_v.aux_other.pos.final.popoluca.reml))
# NOTE: word_class_relevant_no_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_other.popoluca
#   word_class_relevant_no_aux      fit        se    lower    upper
# 1                        N 18.14352 0.2405122 17.67205 18.61500
# 2                        V 19.55294 0.1985097 19.16381 19.94208

pos.effect.articulation_speed.aux_other.by_language = rbind(pos.effect.articulation_speed.aux_other.baure,pos.effect.articulation_speed.aux_other.bora,pos.effect.articulation_speed.aux_other.chintang,pos.effect.articulation_speed.aux_other.dutch,pos.effect.articulation_speed.aux_other.english,pos.effect.articulation_speed.aux_other.even,pos.effect.articulation_speed.aux_other.hoocak,pos.effect.articulation_speed.aux_other.nuu,pos.effect.articulation_speed.aux_other.popoluca)

pos.effect.articulation_speed.aux_other.by_language$language = c("Baure","Baure","Bora","Bora","Chintang","Chintang","Dutch","Dutch","English","English","Even","Even","Hoocąk","Hoocąk","Nǁng","Nǁng","Texistepec","Texistepec")

pos.effect.articulation_speed.aux_other.by_language$language = factor(pos.effect.articulation_speed.aux_other.by_language$language)

pos.effect.articulation_speed.aux_other.by_language$group = as.factor(1)

pos.effect.articulation_speed.aux_other.by_language
#    word_class_relevant_no_aux      fit        se    lower    upper   language group
# 1                           N 13.41435 0.2057464 13.01101 13.81770      Baure     1
# 2                           V 14.02631 0.1856439 13.66238 14.39024      Baure     1
# 11                          N 17.31525 0.7089080 15.92565 18.70485       Bora     1
# 21                          V 17.44697 0.7055903 16.06388 18.83007       Bora     1
# 12                          N 16.28563 0.3145142 15.66912 16.90213   Chintang     1
# 22                          V 17.45794 0.3060277 16.85807 18.05781   Chintang     1
# 13                          N 20.95468 0.4483315 20.07585 21.83351      Dutch     1
# 23                          V 21.38709 0.4450006 20.51479 22.25939      Dutch     1
# 14                          N 18.63114 0.2609484 18.11966 19.14263    English     1
# 24                          V 18.88769 0.2655072 18.36727 19.40811    English     1
# 15                          N 14.55159 0.2501989 14.06117 15.04202       Even     1
# 25                          V 15.09216 0.2484820 14.60510 15.57922       Even     1
# 16                          N 12.57591 0.4347092 11.72373 13.42809     Hoocąk     1
# 26                          V 13.16923 0.4213453 12.34325 13.99521     Hoocąk     1
# 17                          N 16.28909 0.7441805 14.83033 17.74785       Nǁng     1
# 27                          V 16.14416 0.7386934 14.69615 17.59216       Nǁng     1
# 18                          N 18.14352 0.2405122 17.67205 18.61500 Texistepec     1
# 28                          V 19.55294 0.1985097 19.16381 19.94208 Texistepec     1

articulation_speed.aux_other.by_language.common.stars =  c(p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Nǁng" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="word class"])
articulation_speed.aux_other.by_language.common.stars.adjusted =  c(p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Nǁng" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="word class"])

# Add statistical significance based on log-likelihood ratio tests of the linear models
pos.effect.articulation_speed.aux_other.by_language$significance = rep(articulation_speed.aux_other.by_language.common.stars,each=2)
pos.effect.articulation_speed.aux_other.by_language$significance.adjusted = rep(articulation_speed.aux_other.by_language.common.stars.adjusted,each=2)

pos.effect.articulation_speed.aux_other.by_language$middle = rep(as.vector(by(pos.effect.articulation_speed.aux_other.by_language$fit,INDICES=list(pos.effect.articulation_speed.aux_other.by_language$language),FUN=mean)),each=2)

# Rename word classes for paper
pos.effect.articulation_speed.aux_other.by_language$word_class_relevant_no_aux = as.character(pos.effect.articulation_speed.aux_other.by_language$word_class_relevant_no_aux)
pos.effect.articulation_speed.aux_other.by_language$word_class_relevant_no_aux[pos.effect.articulation_speed.aux_other.by_language$word_class_relevant_no_aux=="N"] = "nouns"
pos.effect.articulation_speed.aux_other.by_language$word_class_relevant_no_aux[pos.effect.articulation_speed.aux_other.by_language$word_class_relevant_no_aux=="V"] = "verbs"
pos.effect.articulation_speed.aux_other.by_language$word_class_relevant_no_aux = factor(pos.effect.articulation_speed.aux_other.by_language$word_class_relevant_no_aux,levels=c("nouns","verbs"))

pos.effect.articulation_speed.aux_other.by_language
#    word_class_relevant_no_aux      fit        se    lower    upper   language group significance significance.adjusted   middle
# 1                       nouns 13.41435 0.2057464 13.01101 13.81770      Baure     1           **                    ** 13.72033
# 2                       verbs 14.02631 0.1856439 13.66238 14.39024      Baure     1           **                    ** 13.72033
# 11                      nouns 17.31525 0.7089080 15.92565 18.70485       Bora     1         n.s.                  n.s. 17.38111
# 21                      verbs 17.44697 0.7055903 16.06388 18.83007       Bora     1         n.s.                  n.s. 17.38111
# 12                      nouns 16.28563 0.3145142 15.66912 16.90213   Chintang     1          ***                   *** 16.87178
# 22                      verbs 17.45794 0.3060277 16.85807 18.05781   Chintang     1          ***                   *** 16.87178
# 13                      nouns 20.95468 0.4483315 20.07585 21.83351      Dutch     1           **                     * 21.17088
# 23                      verbs 21.38709 0.4450006 20.51479 22.25939      Dutch     1           **                     * 21.17088
# 14                      nouns 18.63114 0.2609484 18.11966 19.14263    English     1           **                     * 18.75942
# 24                      verbs 18.88769 0.2655072 18.36727 19.40811    English     1           **                     * 18.75942
# 15                      nouns 14.55159 0.2501989 14.06117 15.04202       Even     1          ***                   *** 14.82188
# 25                      verbs 15.09216 0.2484820 14.60510 15.57922       Even     1          ***                   *** 14.82188
# 16                      nouns 12.57591 0.4347092 11.72373 13.42809     Hoocąk     1          ***                   *** 12.87257
# 26                      verbs 13.16923 0.4213453 12.34325 13.99521     Hoocąk     1          ***                   *** 12.87257
# 17                      nouns 16.28909 0.7441805 14.83033 17.74785       Nǁng     1         n.s.                  n.s. 16.21662
# 27                      verbs 16.14416 0.7386934 14.69615 17.59216       Nǁng     1         n.s.                  n.s. 16.21662
# 18                      nouns 18.14352 0.2405122 17.67205 18.61500 Texistepec     1          ***                   *** 18.84823
# 28                      verbs 19.55294 0.1985097 19.16381 19.94208 Texistepec     1          ***                   *** 18.84823

# Plot effects diagram
cairo_pdf("articulation_speed.effect.by_language.fixed.no_aux.pdf",width=7,height=7,family="Helvetica")
ggplot(pos.effect.articulation_speed.aux_other.by_language,aes(word_class_relevant_no_aux,fit,color=word_class_relevant_no_aux)) + geom_line(aes(group=group),color="black") + geom_errorbar(aes(ymin = lower, ymax = upper), width = 0.2) + facet_wrap(~language,ncol=3,scales="fixed") + ggtitle("Articulation rate by word class") + ylab("Articulation rate (segments / second)") + xlab("Word class") + theme(legend.title=element_text(size=15),legend.text=element_text(size=15),axis.text.y=element_text(size=12,color="black"),axis.text.x=element_text(size=13,color="black"),axis.title=element_text(size=15),plot.title=element_text(size=17,hjust=0.5),strip.text.x=element_text(size=13,hjust=0.5)) + guides(color=FALSE) + pos_color_scale2 + pos_fill_scale2 + geom_text(aes(x=1.5,y=middle*1.05,label=significance.adjusted),color="black")
dev.off()

png("articulation_speed.effect.by_language.fixed.no_aux.png",width=7,height=7,units="in",res=600,family="Helvetica")
ggplot(pos.effect.articulation_speed.aux_other.by_language,aes(word_class_relevant_no_aux,fit,color=word_class_relevant_no_aux)) + geom_line(aes(group=group),color="black") + geom_errorbar(aes(ymin = lower, ymax = upper), width = 0.2) + facet_wrap(~language,ncol=3,scales="fixed") + ggtitle("Articulation rate by word class") + ylab("Articulation rate (segments / second)") + xlab("Word class") + theme(legend.title=element_text(size=15),legend.text=element_text(size=15),axis.text.y=element_text(size=12,color="black"),axis.text.x=element_text(size=13,color="black"),axis.title=element_text(size=15),plot.title=element_text(size=17,hjust=0.5),strip.text.x=element_text(size=13,hjust=0.5)) + guides(color=FALSE) + pos_color_scale2 + pos_fill_scale2 + geom_text(aes(x=1.5,y=middle*1.05,label=significance.adjusted),color="black")
dev.off()


## Alternative study including auxiliaries (AUX)

# Based on fixed model structure
pos.effect.articulation_speed.aux_v.baure = as.data.frame(effect("word_class_relevant_aux", prewindow.articulation_speed.n_vs_v.aux_v.pos.final.baure.reml))
# NOTE: word_class_relevant_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_v.baure
# word_class_relevant_aux      fit        se    lower    upper
# 1                        N 13.41435 0.2057463 13.01101 13.81770
# 2                        V 14.02631 0.1856438 13.66238 14.39024

pos.effect.articulation_speed.aux_v.bora = as.data.frame(effect("word_class_relevant_aux", prewindow.articulation_speed.n_vs_v.aux_v.pos.final.bora.reml))
# NOTE: word_class_relevant_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_v.bora
# word_class_relevant_aux      fit        se    lower    upper
# 1                        N 17.31525 0.7089077 15.92566 18.70485
# 2                        V 17.44697 0.7055901 16.06388 18.83007

pos.effect.articulation_speed.aux_v.chintang = as.data.frame(effect("word_class_relevant_aux", prewindow.articulation_speed.n_vs_v.aux_v.pos.final.chintang.reml))
# NOTE: word_class_relevant_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_v.chintang
# word_class_relevant_aux      fit        se    lower    upper
# 1                        N 16.28563 0.3145141 15.66912 16.90213
# 2                        V 17.45794 0.3060276 16.85807 18.05781

pos.effect.articulation_speed.aux_v.dutch = as.data.frame(effect("word_class_relevant_aux", prewindow.articulation_speed.n_vs_v.aux_v.pos.final.dutch.reml))
# NOTE: word_class_relevant_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_v.dutch
# word_class_relevant_aux      fit        se    lower    upper
# 1                        N 20.95468 0.4483315 20.07585 21.83351
# 2                        V 21.38709 0.4450006 20.51479 22.25939

pos.effect.articulation_speed.aux_v.english = as.data.frame(effect("word_class_relevant_aux", prewindow.articulation_speed.n_vs_v.aux_v.pos.final.english.reml))
# NOTE: word_class_relevant_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_v.english
# word_class_relevant_aux      fit        se    lower    upper
# 1                        N 18.65997 0.2665405 18.13753 19.18241
# 2                        V 18.93539 0.2675458 18.41098 19.45980

pos.effect.articulation_speed.aux_v.even = as.data.frame(effect("word_class_relevant_aux", prewindow.articulation_speed.n_vs_v.aux_v.pos.final.even.reml))
# NOTE: word_class_relevant_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_v.even
# word_class_relevant_aux      fit        se    lower    upper
# 1                        N 14.56482 0.2553199 14.06436 15.06529
# 2                        V 15.15092 0.2533867 14.65424 15.64759

pos.effect.articulation_speed.aux_v.hoocak = as.data.frame(effect("word_class_relevant_aux", prewindow.articulation_speed.n_vs_v.aux_v.pos.final.hoocak.reml))
# NOTE: word_class_relevant_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_v.hoocak
# word_class_relevant_aux      fit        se    lower    upper
# 1                        N 12.51552 0.4122303 11.70743 13.32360
# 2                        V 13.16115 0.3969136 12.38309 13.93922

pos.effect.articulation_speed.aux_v.nuu = as.data.frame(effect("word_class_relevant_aux", prewindow.articulation_speed.n_vs_v.aux_v.pos.final.nuu.reml))
# NOTE: word_class_relevant_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_v.nuu
# word_class_relevant_aux      fit        se    lower    upper
# 1                        N 16.28909 0.7441784 14.83033 17.74785
# 2                        V 16.14416 0.7386913 14.69615 17.59216

pos.effect.articulation_speed.aux_v.popoluca = as.data.frame(effect("word_class_relevant_aux", prewindow.articulation_speed.n_vs_v.aux_v.pos.final.popoluca.reml))
# NOTE: word_class_relevant_aux is not a high-order term in the model

pos.effect.articulation_speed.aux_v.popoluca
# word_class_relevant_aux      fit        se   lower    upper
# 1                        N 18.06137 0.2404144 17.5901 18.53264
# 2                        V 19.50450 0.1963042 19.1197 19.88931

pos.effect.articulation_speed.aux_v.by_language = rbind(pos.effect.articulation_speed.aux_v.baure,pos.effect.articulation_speed.aux_v.bora,pos.effect.articulation_speed.aux_v.chintang,pos.effect.articulation_speed.aux_v.dutch,pos.effect.articulation_speed.aux_v.english,pos.effect.articulation_speed.aux_v.even,pos.effect.articulation_speed.aux_v.hoocak,pos.effect.articulation_speed.aux_v.nuu,pos.effect.articulation_speed.aux_v.popoluca)

pos.effect.articulation_speed.aux_v.by_language$language = c("Baure","Baure","Bora","Bora","Chintang","Chintang","Dutch","Dutch","English","English","Even","Even","Hoocąk","Hoocąk","Nǁng","Nǁng","Texistepec","Texistepec")

pos.effect.articulation_speed.aux_v.by_language$language = factor(pos.effect.articulation_speed.aux_v.by_language$language)

pos.effect.articulation_speed.aux_v.by_language$group = as.factor(1)

pos.effect.articulation_speed.aux_v.by_language
#    word_class_relevant_aux      fit        se    lower    upper   language group
# 1                        N 13.41435 0.2057464 13.01101 13.81770      Baure     1
# 2                        V 14.02631 0.1856439 13.66238 14.39024      Baure     1
# 11                       N 17.31525 0.7089080 15.92565 18.70485       Bora     1
# 21                       V 17.44697 0.7055903 16.06388 18.83007       Bora     1
# 12                       N 16.28563 0.3145143 15.66912 16.90213   Chintang     1
# 22                       V 17.45794 0.3060278 16.85807 18.05781   Chintang     1
# 13                       N 20.95468 0.4483315 20.07585 21.83351      Dutch     1
# 23                       V 21.38709 0.4450006 20.51479 22.25939      Dutch     1
# 14                       N 18.65997 0.2665406 18.13753 19.18241    English     1
# 24                       V 18.93539 0.2675458 18.41098 19.45980    English     1
# 15                       N 14.56482 0.2553199 14.06436 15.06529       Even     1
# 25                       V 15.15092 0.2533867 14.65424 15.64759       Even     1
# 16                       N 12.51552 0.4122302 11.70743 13.32360     Hoocąk     1
# 26                       V 13.16115 0.3969136 12.38309 13.93922     Hoocąk     1
# 17                       N 16.28909 0.7441805 14.83033 17.74785       Nǁng     1
# 27                       V 16.14416 0.7386934 14.69615 17.59216       Nǁng     1
# 18                       N 18.06137 0.2404144 17.59010 18.53264 Texistepec     1
# 28                       V 19.50450 0.1963042 19.11970 19.88931 Texistepec     1

# Add significance stars
articulation_speed.aux_v.by_language.common.stars =  c(p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Nǁng" & p.values$variable=="word class"],p.values$stars[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="word class"])
articulation_speed.aux_v.by_language.common.stars.adjusted =  c(p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="excluded" & p.values$model=="Nǁng" & p.values$variable=="word class"],p.values$stars.adjusted.BH[p.values$study=="articulation rate" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="word class"])

# Add statistical significance based on log-likelihood ratio tests of the linear models
pos.effect.articulation_speed.aux_v.by_language$significance = rep(articulation_speed.aux_v.by_language.common.stars,each=2)
pos.effect.articulation_speed.aux_v.by_language$significance.adjusted = rep(articulation_speed.aux_v.by_language.common.stars.adjusted,each=2)

pos.effect.articulation_speed.aux_v.by_language$middle = rep(as.vector(by(pos.effect.articulation_speed.aux_v.by_language$fit,INDICES=list(pos.effect.articulation_speed.aux_v.by_language$language),FUN=mean)),each=2)

# Rename word classes for paper
pos.effect.articulation_speed.aux_v.by_language$word_class_relevant_aux = as.character(pos.effect.articulation_speed.aux_v.by_language$word_class_relevant_aux)
pos.effect.articulation_speed.aux_v.by_language$word_class_relevant_aux[pos.effect.articulation_speed.aux_v.by_language$word_class_relevant_aux=="N"] = "nouns"
pos.effect.articulation_speed.aux_v.by_language$word_class_relevant_aux[pos.effect.articulation_speed.aux_v.by_language$word_class_relevant_aux=="V"] = "verbs"
pos.effect.articulation_speed.aux_v.by_language$word_class_relevant_aux = factor(pos.effect.articulation_speed.aux_v.by_language$word_class_relevant_aux,levels=c("nouns","verbs"))

pos.effect.articulation_speed.aux_v.by_language
#    word_class_relevant_aux      fit        se    lower    upper   language group significance significance.adjusted   middle
# 1                    nouns 13.41435 0.2057464 13.01101 13.81770      Baure     1           **                    ** 13.72033
# 2                    verbs 14.02631 0.1856439 13.66238 14.39024      Baure     1           **                    ** 13.72033
# 11                   nouns 17.31525 0.7089080 15.92565 18.70485       Bora     1         n.s.                  n.s. 17.38111
# 21                   verbs 17.44697 0.7055903 16.06388 18.83007       Bora     1         n.s.                  n.s. 17.38111
# 12                   nouns 16.28563 0.3145143 15.66912 16.90213   Chintang     1          ***                   *** 16.87178
# 22                   verbs 17.45794 0.3060278 16.85807 18.05781   Chintang     1          ***                   *** 16.87178
# 13                   nouns 20.95468 0.4483315 20.07585 21.83351      Dutch     1           **                     * 21.17088
# 23                   verbs 21.38709 0.4450006 20.51479 22.25939      Dutch     1           **                     * 21.17088
# 14                   nouns 18.65997 0.2665406 18.13753 19.18241    English     1           **                    ** 18.79768
# 24                   verbs 18.93539 0.2675458 18.41098 19.45980    English     1           **                    ** 18.79768
# 15                   nouns 14.56482 0.2553199 14.06436 15.06529       Even     1          ***                   *** 14.85787
# 25                   verbs 15.15092 0.2533867 14.65424 15.64759       Even     1          ***                   *** 14.85787
# 16                   nouns 12.51552 0.4122302 11.70743 13.32360     Hoocąk     1          ***                   *** 12.83833
# 26                   verbs 13.16115 0.3969136 12.38309 13.93922     Hoocąk     1          ***                   *** 12.83833
# 17                   nouns 16.28909 0.7441805 14.83033 17.74785       Nǁng     1         n.s.                  n.s. 16.21662
# 27                   verbs 16.14416 0.7386934 14.69615 17.59216       Nǁng     1         n.s.                  n.s. 16.21662
# 18                   nouns 18.06137 0.2404144 17.59010 18.53264 Texistepec     1          ***                   *** 18.78294
# 28                   verbs 19.50450 0.1963042 19.11970 19.88931 Texistepec     1          ***                   *** 18.78294

# Plot effects diagram
cairo_pdf("articulation_speed.effect.by_language.fixed.aux.pdf",width=7,height=7,family="Helvetica")
ggplot(pos.effect.articulation_speed.aux_v.by_language,aes(word_class_relevant_aux,fit,color=word_class_relevant_aux)) + geom_line(aes(group=group),color="black") + geom_errorbar(aes(ymin = lower, ymax = upper), width = 0.2) + facet_wrap(~language,ncol=3,scales="fixed") + ggtitle("Articulation rate by word class") + ylab("Articulation rate (segments / second)") + xlab("Word class") + theme(legend.title=element_text(size=15),legend.text=element_text(size=15),axis.text.y=element_text(size=12,color="black"),axis.text.x=element_text(size=13,color="black"),axis.title=element_text(size=15),plot.title=element_text(size=17,hjust=0.5),strip.text.x=element_text(size=13,hjust=0.5)) + guides(color=FALSE) + pos_color_scale2 + pos_fill_scale2 + geom_text(aes(x=1.5,y=middle*1.05,label=significance.adjusted),color="black")
dev.off()

png("articulation_speed.effect.by_language.fixed.aux.png",width=7,height=7,units="in",res=600,family="Helvetica")
ggplot(pos.effect.articulation_speed.aux_v.by_language,aes(word_class_relevant_aux,fit,color=word_class_relevant_aux)) + geom_line(aes(group=group),color="black") + geom_errorbar(aes(ymin = lower, ymax = upper), width = 0.2) + facet_wrap(~language,ncol=3,scales="fixed") + ggtitle("Articulation rate by word class") + ylab("Articulation rate (segments / second)") + xlab("Word class") + theme(legend.title=element_text(size=15),legend.text=element_text(size=15),axis.text.y=element_text(size=12,color="black"),axis.text.x=element_text(size=13,color="black"),axis.title=element_text(size=15),plot.title=element_text(size=17,hjust=0.5),strip.text.x=element_text(size=13,hjust=0.5)) + guides(color=FALSE) + pos_color_scale2 + pos_fill_scale2 + geom_text(aes(x=1.5,y=middle*1.05,label=significance.adjusted),color="black")
dev.off()


## Pause probability ##

## Main study excluding auxiliaries (AUX)

# Based on fixed model structure

pos.effect.pause_probability_150.aux_other.baure = as.data.frame(effect("word_class_relevant_no_aux", prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure))

pos.effect.pause_probability_150.aux_other.baure
#   word_class_relevant_no_aux      fit        se     lower     upper
# 1                          N 0.176016 0.1266227 0.1428581 0.2149402
# 2                          V 0.162380 0.1214923 0.1325330 0.1974190

pos.effect.pause_probability_150.aux_other.bora = as.data.frame(effect("word_class_relevant_no_aux", prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora))

pos.effect.pause_probability_150.aux_other.bora
#   word_class_relevant_no_aux       fit        se     lower     upper
# 1                          N 0.2840839 0.1720519 0.2207143 0.3573056
# 2                          V 0.1832379 0.1723575 0.1379554 0.2392587

pos.effect.pause_probability_150.aux_other.chintang = as.data.frame(effect("word_class_relevant_no_aux", prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang))

pos.effect.pause_probability_150.aux_other.chintang
#   word_class_relevant_no_aux        fit        se      lower     upper
# 1                          N 0.15732504 0.1493659 0.12227946 0.2001246
# 2                          V 0.09180198 0.1492509 0.07015212 0.1192762

pos.effect.pause_probability_150.aux_other.dutch = as.data.frame(effect("word_class_relevant_no_aux", prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch))

pos.effect.pause_probability_150.aux_other.dutch
#   word_class_relevant_no_aux       fit        se      lower     upper
# 1                          N 0.1206936 0.1028651 0.10087948 0.1437771
# 2                          V 0.1082485 0.1007376 0.09061082 0.1288331

pos.effect.pause_probability_150.aux_other.english = as.data.frame(effect("word_class_relevant_no_aux", prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.english))

pos.effect.pause_probability_150.aux_other.english
#   word_class_relevant_no_aux       fit         se     lower     upper
# 1                          N 0.1427875 0.06324840 0.1282755 0.1586424
# 2                          V 0.1725556 0.06307849 0.1556110 0.1909281

pos.effect.pause_probability_150.aux_other.even = as.data.frame(effect("word_class_relevant_no_aux", prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.even))

pos.effect.pause_probability_150.aux_other.even
#   word_class_relevant_no_aux       fit         se     lower     upper
# 1                          N 0.4232091 0.08211776 0.3844834 0.4629019
# 2                          V 0.2277773 0.08278398 0.2005022 0.2575673

pos.effect.pause_probability_150.aux_other.hoocak = as.data.frame(effect("word_class_relevant_no_aux", prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.hoocak))

pos.effect.pause_probability_150.aux_other.hoocak
#   word_class_relevant_no_aux       fit        se     lower     upper
# 1                          N 0.5325385 0.1113751 0.4780259 0.5862852
# 2                          V 0.2520591 0.1046295 0.2153910 0.2926414

pos.effect.pause_probability_150.aux_other.nuu = as.data.frame(effect("word_class_relevant_no_aux", prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu))

pos.effect.pause_probability_150.aux_other.nuu
#   word_class_relevant_no_aux       fit        se      lower     upper
# 1                          N 0.1445351 0.2862102 0.08793733 0.2284365
# 2                          V 0.0730801 0.2855488 0.04310823 0.1212500

pos.effect.pause_probability_150.aux_other.popoluca = as.data.frame(effect("word_class_relevant_no_aux", prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.popoluca))

pos.effect.pause_probability_150.aux_other.popoluca
#   word_class_relevant_no_aux        fit         se      lower      upper
# 1                          N 0.15075369 0.07914606 0.13195010 0.17170684
# 2                          V 0.08003411 0.06961149 0.07054683 0.09067279

pos.effect.pause_probability_150.aux_other.by_language = rbind(pos.effect.pause_probability_150.aux_other.baure,pos.effect.pause_probability_150.aux_other.bora,pos.effect.pause_probability_150.aux_other.chintang,pos.effect.pause_probability_150.aux_other.dutch,pos.effect.pause_probability_150.aux_other.english,pos.effect.pause_probability_150.aux_other.even,pos.effect.pause_probability_150.aux_other.hoocak,pos.effect.pause_probability_150.aux_other.nuu,pos.effect.pause_probability_150.aux_other.popoluca)

pos.effect.pause_probability_150.aux_other.by_language$language = c("Baure","Baure","Bora","Bora","Chintang","Chintang","Dutch","Dutch","English","English","Even","Even","Hoocąk","Hoocąk","Nǁng","Nǁng","Texistepec","Texistepec")

pos.effect.pause_probability_150.aux_other.by_language$language = factor(pos.effect.pause_probability_150.aux_other.by_language$language)

pos.effect.pause_probability_150.aux_other.by_language$group = as.factor(1)

pos.effect.pause_probability_150.aux_other.by_language
#    word_class_relevant_no_aux        fit         se      lower      upper   language group
# 1                           N 0.17601603 0.12662274 0.14285806 0.21494021      Baure     1
# 2                           V 0.16238002 0.12149232 0.13253301 0.19741897      Baure     1
# 11                          N 0.28408393 0.17205186 0.22071430 0.35730564       Bora     1
# 21                          V 0.18323792 0.17235750 0.13795536 0.23925870       Bora     1
# 12                          N 0.15732504 0.14936592 0.12227946 0.20012465   Chintang     1
# 22                          V 0.09180198 0.14925088 0.07015212 0.11927620   Chintang     1
# 13                          N 0.12069356 0.10286509 0.10087948 0.14377707      Dutch     1
# 23                          V 0.10824855 0.10073758 0.09061082 0.12883314      Dutch     1
# 14                          N 0.14278745 0.06324840 0.12827548 0.15864241    English     1
# 24                          V 0.17255556 0.06307849 0.15561096 0.19092806    English     1
# 15                          N 0.42320910 0.08211776 0.38448340 0.46290190       Even     1
# 25                          V 0.22777725 0.08278398 0.20050221 0.25756729       Even     1
# 16                          N 0.53253849 0.11137509 0.47802592 0.58628516     Hoocąk     1
# 26                          V 0.25205915 0.10462955 0.21539104 0.29264136     Hoocąk     1
# 17                          N 0.14453511 0.28621022 0.08793733 0.22843646       Nǁng     1
# 27                          V 0.07308010 0.28554877 0.04310823 0.12125001       Nǁng     1
# 18                          N 0.15075369 0.07914606 0.13195010 0.17170684 Texistepec     1
# 28                          V 0.08003411 0.06961149 0.07054683 0.09067279 Texistepec     1

pause_probability_150.aux_other.by_language.common.stars =  c(p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Nǁng" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="word class"])

pause_probability_150.aux_other.by_language.common.stars.adjusted =  c(p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="English" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Even" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Hoocąk" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Nǁng" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Texistepec" & p.values$variable=="word class"])

# Add statistical significance based on log-likelihood ratio tests of the linear models
pos.effect.pause_probability_150.aux_other.by_language$significance = rep(pause_probability_150.aux_other.by_language.common.stars,each=2)
pos.effect.pause_probability_150.aux_other.by_language$significance.adjusted = rep(pause_probability_150.aux_other.by_language.common.stars.adjusted,each=2)

pos.effect.pause_probability_150.aux_other.by_language$middle = rep(as.vector(by(pos.effect.pause_probability_150.aux_other.by_language$fit,INDICES=list(pos.effect.pause_probability_150.aux_other.by_language$language),FUN=mean)),each=2)

# Adjust middle for Baure and Dutch to make plot look more pretty
pos.effect.pause_probability_150.aux_other.by_language$middle[pos.effect.pause_probability_150.aux_other.by_language$language=="Baure"] = pos.effect.pause_probability_150.aux_other.by_language$middle[pos.effect.pause_probability_150.aux_other.by_language$language=="Baure"] + 0.02

pos.effect.pause_probability_150.aux_other.by_language$middle[pos.effect.pause_probability_150.aux_other.by_language$language=="Dutch"] = pos.effect.pause_probability_150.aux_other.by_language$middle[pos.effect.pause_probability_150.aux_other.by_language$language=="Dutch"] + 0.02

# Rename word classes for paper
pos.effect.pause_probability_150.aux_other.by_language$word_class_relevant_no_aux = as.character(pos.effect.pause_probability_150.aux_other.by_language$word_class_relevant_no_aux)
pos.effect.pause_probability_150.aux_other.by_language$word_class_relevant_no_aux[pos.effect.pause_probability_150.aux_other.by_language$word_class_relevant_no_aux=="N"] = "nouns"
pos.effect.pause_probability_150.aux_other.by_language$word_class_relevant_no_aux[pos.effect.pause_probability_150.aux_other.by_language$word_class_relevant_no_aux=="V"] = "verbs"
pos.effect.pause_probability_150.aux_other.by_language$word_class_relevant_no_aux = factor(pos.effect.pause_probability_150.aux_other.by_language$word_class_relevant_no_aux,levels=c("nouns","verbs"))

pos.effect.pause_probability_150.aux_other.by_language
#    word_class_relevant_no_aux        fit         se      lower      upper   language group significance significance.adjusted    middle
# 1                       nouns 0.17601603 0.12662274 0.14285806 0.21494021      Baure     1         n.s.                  n.s. 0.1891980
# 2                       verbs 0.16238002 0.12149232 0.13253301 0.19741897      Baure     1         n.s.                  n.s. 0.1891980
# 11                      nouns 0.28408393 0.17205186 0.22071430 0.35730564       Bora     1          ***                   *** 0.2336609
# 21                      verbs 0.18323792 0.17235750 0.13795536 0.23925870       Bora     1          ***                   *** 0.2336609
# 12                      nouns 0.15732504 0.14936592 0.12227946 0.20012465   Chintang     1          ***                   *** 0.1245635
# 22                      verbs 0.09180198 0.14925088 0.07015212 0.11927620   Chintang     1          ***                   *** 0.1245635
# 13                      nouns 0.12069356 0.10286509 0.10087948 0.14377707      Dutch     1         n.s.                  n.s. 0.1344711
# 23                      verbs 0.10824855 0.10073758 0.09061082 0.12883314      Dutch     1         n.s.                  n.s. 0.1344711
# 14                      nouns 0.14278745 0.06324840 0.12827548 0.15864241    English     1          ***                   *** 0.1576715
# 24                      verbs 0.17255556 0.06307849 0.15561096 0.19092806    English     1          ***                   *** 0.1576715
# 15                      nouns 0.42320910 0.08211776 0.38448340 0.46290190       Even     1          ***                   *** 0.3254932
# 25                      verbs 0.22777725 0.08278398 0.20050221 0.25756729       Even     1          ***                   *** 0.3254932
# 16                      nouns 0.53253849 0.11137509 0.47802592 0.58628516     Hoocąk     1          ***                   *** 0.3922988
# 26                      verbs 0.25205915 0.10462955 0.21539104 0.29264136     Hoocąk     1          ***                   *** 0.3922988
# 17                      nouns 0.14453511 0.28621022 0.08793733 0.22843646       Nǁng     1          ***                   *** 0.1088076
# 27                      verbs 0.07308010 0.28554877 0.04310823 0.12125001       Nǁng     1          ***                   *** 0.1088076
# 18                      nouns 0.15075369 0.07914606 0.13195010 0.17170684 Texistepec     1          ***                   *** 0.1153939
# 28                      verbs 0.08003411 0.06961149 0.07054683 0.09067279 Texistepec     1          ***                   *** 0.1153939

# Plot effects diagram
cairo_pdf("pause_probability_150.effect.by_language.fixed.no_aux.pdf",width=7,height=7,family="Helvetica")
ggplot(pos.effect.pause_probability_150.aux_other.by_language,aes(word_class_relevant_no_aux,fit,color=word_class_relevant_no_aux)) + geom_line(aes(group=group),color="black") + geom_errorbar(aes(ymin = lower, ymax = upper), width = 0.2) + facet_wrap(~language,ncol=3,scales="fixed") + ggtitle("Probability of pause by word class") + ylab("Probability of pause") + xlab("Word class") + theme(legend.title=element_text(size=15),legend.text=element_text(size=15),axis.text.y=element_text(size=12,color="black"),axis.text.x=element_text(size=13,color="black"),axis.title=element_text(size=15),plot.title=element_text(size=17,hjust=0.5),strip.text.x=element_text(size=13,hjust=0.5)) + guides(color=FALSE) + pos_color_scale2 + pos_fill_scale2 + geom_text(aes(x=1.5,y=middle*1.15,label=significance.adjusted),color="black")
dev.off()

png("pause_probability_150.effect.by_language.fixed.no_aux.png",width=7,height=7,units="in",res=600,family="Helvetica")
ggplot(pos.effect.pause_probability_150.aux_other.by_language,aes(word_class_relevant_no_aux,fit,color=word_class_relevant_no_aux)) + geom_line(aes(group=group),color="black") + geom_errorbar(aes(ymin = lower, ymax = upper), width = 0.2) + facet_wrap(~language,ncol=3,scales="fixed") + ggtitle("Probability of pause by word class") + ylab("Probability of pause") + xlab("Word class") + theme(legend.title=element_text(size=15),legend.text=element_text(size=15),axis.text.y=element_text(size=12,color="black"),axis.text.x=element_text(size=13,color="black"),axis.title=element_text(size=15),plot.title=element_text(size=17,hjust=0.5),strip.text.x=element_text(size=13,hjust=0.5)) + guides(color=FALSE) + pos_color_scale2 + pos_fill_scale2 + geom_text(aes(x=1.5,y=middle*1.15,label=significance.adjusted),color="black")
dev.off()


## Alternative study including auxiliaries (AUX)

# Based on fixed model structure

# Same as main study, no auxiliaries in Baure
pos.effect.pause_probability_150.aux_v.baure = as.data.frame(effect("word_class_relevant_no_aux", prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.baure))
colnames(pos.effect.pause_probability_150.aux_v.baure)[1] = "word_class_relevant_aux"

pos.effect.pause_probability_150.aux_v.baure
#   word_class_relevant_aux      fit        se     lower     upper
# 1                       N 0.176016 0.1266227 0.1428581 0.2149402
# 2                       V 0.162380 0.1214923 0.1325330 0.1974190

# Same as main study, no auxiliaries in Bora
pos.effect.pause_probability_150.aux_v.bora = as.data.frame(effect("word_class_relevant_no_aux", prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.bora))
colnames(pos.effect.pause_probability_150.aux_v.bora)[1] = "word_class_relevant_aux"

pos.effect.pause_probability_150.aux_v.bora
#   word_class_relevant_aux       fit        se     lower     upper
# 1                       N 0.2840839 0.1720519 0.2207143 0.3573056
# 2                       V 0.1832379 0.1723575 0.1379554 0.2392587

# Same as main study, no auxiliaries in Chintang
pos.effect.pause_probability_150.aux_v.chintang = as.data.frame(effect("word_class_relevant_no_aux", prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.chintang))
colnames(pos.effect.pause_probability_150.aux_v.chintang)[1] = "word_class_relevant_aux"

pos.effect.pause_probability_150.aux_v.chintang
#   word_class_relevant_aux        fit        se      lower     upper
# 1                       N 0.15732504 0.1493659 0.12227946 0.2001246
# 2                       V 0.09180198 0.1492509 0.07015212 0.1192762

# Same as main study, no auxiliaries in Dutch
pos.effect.pause_probability_150.aux_v.dutch = as.data.frame(effect("word_class_relevant_no_aux", prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.dutch))
colnames(pos.effect.pause_probability_150.aux_v.dutch)[1] = "word_class_relevant_aux"

pos.effect.pause_probability_150.aux_v.dutch
#   word_class_relevant_aux       fit        se      lower     upper
# 1                       N 0.1206936 0.1028651 0.10087948 0.1437771
# 2                       V 0.1082485 0.1007376 0.09061082 0.1288331

pos.effect.pause_probability_150.aux_v.english = as.data.frame(effect("word_class_relevant_aux", prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.english))

pos.effect.pause_probability_150.aux_v.english
#   word_class_relevant_aux       fit         se     lower     upper
# 1                       N 0.1408590 0.06323741 0.1265165 0.1565361
# 2                       V 0.1704807 0.06131939 0.1541511 0.1881555

pos.effect.pause_probability_150.aux_v.even = as.data.frame(effect("word_class_relevant_aux", prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.even))

pos.effect.pause_probability_150.aux_v.even
#   word_class_relevant_aux       fit         se     lower     upper
# 1                       N 0.4236167 0.08296469 0.3844857 0.4637298
# 2                       V 0.2285504 0.08335245 0.2010279 0.2586213

pos.effect.pause_probability_150.aux_v.hoocak = as.data.frame(effect("word_class_relevant_aux", prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.hoocak))

pos.effect.pause_probability_150.aux_v.hoocak
#   word_class_relevant_aux       fit        se     lower     upper
# 1                       N 0.5345872 0.1110885 0.4802205 0.5881444
# 2                       V 0.2322446 0.1030308 0.1981945 0.2701733

# Same as main study, no auxiliaries in Nǁng
pos.effect.pause_probability_150.aux_v.nuu = as.data.frame(effect("word_class_relevant_no_aux", prewindow.pause_probability_150.n_vs_v.aux_other.pos.final.nuu))
colnames(pos.effect.pause_probability_150.aux_v.nuu)[1] = "word_class_relevant_aux"

pos.effect.pause_probability_150.aux_v.nuu
#   word_class_relevant_aux       fit        se      lower     upper
# 1                       N 0.1445351 0.2862102 0.08793733 0.2284365
# 2                       V 0.0730801 0.2855488 0.04310823 0.1212500

pos.effect.pause_probability_150.aux_v.popoluca = as.data.frame(effect("word_class_relevant_aux", prewindow.pause_probability_150.n_vs_v.aux_v.pos.final.popoluca))

pos.effect.pause_probability_150.aux_v.popoluca
#   word_class_relevant_aux        fit         se      lower      upper
# 1                       N 0.14269775 0.08265895 0.12400154 0.16368613
# 2                       V 0.08011675 0.07171174 0.07035072 0.09110562

pos.effect.pause_probability_150.aux_v.by_language = rbind(pos.effect.pause_probability_150.aux_v.baure,pos.effect.pause_probability_150.aux_v.bora,pos.effect.pause_probability_150.aux_v.chintang,pos.effect.pause_probability_150.aux_v.dutch,pos.effect.pause_probability_150.aux_v.english,pos.effect.pause_probability_150.aux_v.even,pos.effect.pause_probability_150.aux_v.hoocak,pos.effect.pause_probability_150.aux_v.nuu,pos.effect.pause_probability_150.aux_v.popoluca)

pos.effect.pause_probability_150.aux_v.by_language$language = c("Baure","Baure","Bora","Bora","Chintang","Chintang","Dutch","Dutch","English","English","Even","Even","Hoocąk","Hoocąk","Nǁng","Nǁng","Texistepec","Texistepec")

pos.effect.pause_probability_150.aux_v.by_language$language = factor(pos.effect.pause_probability_150.aux_v.by_language$language)

pos.effect.pause_probability_150.aux_v.by_language$group = as.factor(1)

pos.effect.pause_probability_150.aux_v.by_language
#    word_class_relevant_aux        fit         se      lower      upper   language group
# 1                        N 0.17601603 0.12662274 0.14285806 0.21494021      Baure     1
# 2                        V 0.16238002 0.12149232 0.13253301 0.19741897      Baure     1
# 11                       N 0.28408393 0.17205186 0.22071430 0.35730564       Bora     1
# 21                       V 0.18323792 0.17235750 0.13795536 0.23925870       Bora     1
# 12                       N 0.15732504 0.14936592 0.12227946 0.20012465   Chintang     1
# 22                       V 0.09180198 0.14925088 0.07015212 0.11927620   Chintang     1
# 13                       N 0.12069356 0.10286509 0.10087948 0.14377707      Dutch     1
# 23                       V 0.10824855 0.10073758 0.09061082 0.12883314      Dutch     1
# 14                       N 0.14085900 0.06323741 0.12651648 0.15653608    English     1
# 24                       V 0.17048074 0.06131939 0.15415105 0.18815548    English     1
# 15                       N 0.42361672 0.08296469 0.38448570 0.46372983       Even     1
# 25                       V 0.22855037 0.08335245 0.20102787 0.25862126       Even     1
# 16                       N 0.53458718 0.11108855 0.48022045 0.58814437     Hoocąk     1
# 26                       V 0.23224457 0.10303080 0.19819455 0.27017329     Hoocąk     1
# 17                       N 0.14453511 0.28621022 0.08793733 0.22843646       Nǁng     1
# 27                       V 0.07308010 0.28554877 0.04310823 0.12125001       Nǁng     1
# 18                       N 0.14269775 0.08265895 0.12400154 0.16368613 Texistepec     1
# 28                       V 0.08011675 0.07171174 0.07035072 0.09110562 Texistepec     1

pause_probability_150.aux_v.by_language.common.stars =  c(p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Nǁng" & p.values$variable=="word class"],p.values$stars[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="word class"])

pause_probability_150.aux_v.by_language.common.stars.adjusted =  c(p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Baure" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Bora" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Chintang" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Dutch" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="English" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Even" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Hoocąk" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="excluded" & p.values$model=="Nǁng" & p.values$variable=="word class"],p.values$stars.adjusted[p.values$study=="pause probability" & p.values$auxiliaries=="included" & p.values$model=="Texistepec" & p.values$variable=="word class"])

# Add statistical significance based on log-likelihood ratio tests of the linear models
pos.effect.pause_probability_150.aux_v.by_language$significance = rep(pause_probability_150.aux_v.by_language.common.stars,each=2)
pos.effect.pause_probability_150.aux_v.by_language$significance.adjusted = rep(pause_probability_150.aux_v.by_language.common.stars.adjusted,each=2)

pos.effect.pause_probability_150.aux_v.by_language$middle = rep(as.vector(by(pos.effect.pause_probability_150.aux_v.by_language$fit,INDICES=list(pos.effect.pause_probability_150.aux_v.by_language$language),FUN=mean)),each=2)

# Adjust middle for Baure and Dutch to make plot look more pretty
pos.effect.pause_probability_150.aux_v.by_language$middle[pos.effect.pause_probability_150.aux_v.by_language$language=="Baure"] = pos.effect.pause_probability_150.aux_v.by_language$middle[pos.effect.pause_probability_150.aux_v.by_language$language=="Baure"] + 0.02
pos.effect.pause_probability_150.aux_v.by_language$middle[pos.effect.pause_probability_150.aux_v.by_language$language=="Dutch"] = pos.effect.pause_probability_150.aux_v.by_language$middle[pos.effect.pause_probability_150.aux_v.by_language$language=="Dutch"] + 0.02

# Rename word class for paper
pos.effect.pause_probability_150.aux_v.by_language$word_class_relevant_aux = as.character(pos.effect.pause_probability_150.aux_v.by_language$word_class_relevant_aux)
pos.effect.pause_probability_150.aux_v.by_language$word_class_relevant_aux[pos.effect.pause_probability_150.aux_v.by_language$word_class_relevant_aux=="N"] = "nouns"
pos.effect.pause_probability_150.aux_v.by_language$word_class_relevant_aux[pos.effect.pause_probability_150.aux_v.by_language$word_class_relevant_aux=="V"] = "verbs"
pos.effect.pause_probability_150.aux_v.by_language$word_class_relevant_aux = factor(pos.effect.pause_probability_150.aux_v.by_language$word_class_relevant_aux,levels=c("nouns","verbs"))

pos.effect.pause_probability_150.aux_v.by_language
#    word_class_relevant_aux        fit         se      lower      upper   language group significance significance.adjusted    middle
# 1                    nouns 0.17601603 0.12662274 0.14285806 0.21494021      Baure     1         n.s.                  n.s. 0.1891980
# 2                    verbs 0.16238002 0.12149232 0.13253301 0.19741897      Baure     1         n.s.                  n.s. 0.1891980
# 11                   nouns 0.28408393 0.17205186 0.22071430 0.35730564       Bora     1          ***                   *** 0.2336609
# 21                   verbs 0.18323792 0.17235750 0.13795536 0.23925870       Bora     1          ***                   *** 0.2336609
# 12                   nouns 0.15732504 0.14936592 0.12227946 0.20012465   Chintang     1          ***                   *** 0.1245635
# 22                   verbs 0.09180198 0.14925088 0.07015212 0.11927620   Chintang     1          ***                   *** 0.1245635
# 13                   nouns 0.12069356 0.10286509 0.10087948 0.14377707      Dutch     1         n.s.                  n.s. 0.1344711
# 23                   verbs 0.10824855 0.10073758 0.09061082 0.12883314      Dutch     1         n.s.                  n.s. 0.1344711
# 14                   nouns 0.14085900 0.06323741 0.12651648 0.15653608    English     1          ***                   *** 0.1556699
# 24                   verbs 0.17048074 0.06131939 0.15415105 0.18815548    English     1          ***                   *** 0.1556699
# 15                   nouns 0.42361672 0.08296469 0.38448570 0.46372983       Even     1          ***                   *** 0.3260835
# 25                   verbs 0.22855037 0.08335245 0.20102787 0.25862126       Even     1          ***                   *** 0.3260835
# 16                   nouns 0.53458718 0.11108855 0.48022045 0.58814437     Hoocąk     1          ***                   *** 0.3834159
# 26                   verbs 0.23224457 0.10303080 0.19819455 0.27017329     Hoocąk     1          ***                   *** 0.3834159
# 17                   nouns 0.14453511 0.28621022 0.08793733 0.22843646       Nǁng     1          ***                   *** 0.1088076
# 27                   verbs 0.07308010 0.28554877 0.04310823 0.12125001       Nǁng     1          ***                   *** 0.1088076
# 18                   nouns 0.14269775 0.08265895 0.12400154 0.16368613 Texistepec     1          ***                   *** 0.1114072
# 28                   verbs 0.08011675 0.07171174 0.07035072 0.09110562 Texistepec     1          ***                   *** 0.1114072

# Plot effects diagram
cairo_pdf("pause_probability_150.effect.by_language.fixed.aux.pdf",width=7,height=7,family="Helvetica")
ggplot(pos.effect.pause_probability_150.aux_v.by_language,aes(word_class_relevant_aux,fit,color=word_class_relevant_aux)) + geom_line(aes(group=group),color="black") + geom_errorbar(aes(ymin = lower, ymax = upper), width = 0.2) + facet_wrap(~language,ncol=3,scales="fixed") + ggtitle("Probability of pause by word class") + ylab("Probability of pause") + xlab("Word class") + theme(legend.title=element_text(size=15),legend.text=element_text(size=15),axis.text.y=element_text(size=12,color="black"),axis.text.x=element_text(size=13,color="black"),axis.title=element_text(size=15),plot.title=element_text(size=17,hjust=0.5),strip.text.x=element_text(size=13,hjust=0.5)) + guides(color=FALSE) + pos_color_scale2 + pos_fill_scale2 + geom_text(aes(x=1.5,y=middle*1.15,label=significance.adjusted),color="black")
dev.off()

png("pause_probability_150.effect.by_language.fixed.aux.png",width=7,height=7,units="in",res=600,family="Helvetica")
ggplot(pos.effect.pause_probability_150.aux_v.by_language,aes(word_class_relevant_aux,fit,color=word_class_relevant_aux)) + geom_line(aes(group=group),color="black") + geom_errorbar(aes(ymin = lower, ymax = upper), width = 0.2) + facet_wrap(~language,ncol=3,scales="fixed") + ggtitle("Probability of pause by word class") + ylab("Probability of pause") + xlab("Word class") + theme(legend.title=element_text(size=15),legend.text=element_text(size=15),axis.text.y=element_text(size=12,color="black"),axis.text.x=element_text(size=13,color="black"),axis.title=element_text(size=15),plot.title=element_text(size=17,hjust=0.5),strip.text.x=element_text(size=13,hjust=0.5)) + guides(color=FALSE) + pos_color_scale2 + pos_fill_scale2 + geom_text(aes(x=1.5,y=middle*1.15,label=significance.adjusted),color="black")
dev.off()


### Statistics on pre-word context window lengths ###

# Make a data frame of pre-word context window sizes for articulation rate study
articulation_rate.window_sizes = cbind(aggregate(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_length_seconds_no_pauses,by=list(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language),FUN=mean),aggregate(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$pre_word_window_length_seconds_no_pauses,by=list(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux,combined.wordtimes.prewindows.publish.articulation_rate.no_aux$language),FUN=sd)$x)

colnames(articulation_rate.window_sizes) = c("word_class","language","mean_window_length", "sd_window_length")

# Put language column first
articulation_rate.window_sizes = articulation_rate.window_sizes[,c(2,1,3,4)]
articulation_rate.window_sizes$word_class = as.character(articulation_rate.window_sizes$word_class)
articulation_rate.window_sizes$word_class[articulation_rate.window_sizes$word_class=="N"] = "nouns"
articulation_rate.window_sizes$word_class[articulation_rate.window_sizes$word_class=="V"] = "verbs"
articulation_rate.window_sizes$word_class = factor(articulation_rate.window_sizes$word_class)

articulation_rate.window_sizes = cbind(articulation_rate.window_sizes[articulation_rate.window_sizes$word_class=="nouns",c(1,3,4)],articulation_rate.window_sizes[articulation_rate.window_sizes$word_class=="verbs",c(3,4)])
colnames(articulation_rate.window_sizes) = c("language","mean_window_length_nouns", "sd_window_length_nouns","mean_window_length_verbs", "sd_window_length_verbs")

articulation_rate.window_sizes$difference = articulation_rate.window_sizes$mean_window_length_nouns-articulation_rate.window_sizes$mean_window_length_verbs

articulation_rate.window_sizes
#      language mean_window_length_nouns sd_window_length_nouns mean_window_length_verbs sd_window_length_verbs   difference
# 1       Baure                0.4470457              0.1933746                0.4554404              0.2010051 -0.008394678
# 3        Bora                0.4533915              0.1663956                0.4632619              0.1856099 -0.009870367
# 5    Chintang                0.4268186              0.1670807                0.4421854              0.1539236 -0.015366759
# 7       Dutch                0.4397025              0.1390099                0.3810787              0.1733788  0.058623831
# 9     English                0.4526002              0.1374775                0.3865548              0.1742401  0.066045469
# 11       Even                0.4498545              0.1679092                0.4765981              0.1547718 -0.026743598
# 13     Hoocąk                0.5011166              0.1907041                0.5103271              0.1771737 -0.009210458
# 15       Nǁng                0.3924878              0.1511214                0.2943454              0.1510973  0.098142377
# 17 Texistepec                0.4308764              0.1555927                0.3601408              0.1726639  0.070735568

# Make a data frame of pre-word context window sizes for pause probability study
pause_probability.window_sizes = cbind(aggregate(combined.wordtimes.prewindows.publish.pause_probability.no_aux$pre_word_window_length_seconds,by=list(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language),FUN=mean),aggregate(combined.wordtimes.prewindows.publish.pause_probability.no_aux$pre_word_window_length_seconds,by=list(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux,combined.wordtimes.prewindows.publish.pause_probability.no_aux$language),FUN=sd)$x)

colnames(pause_probability.window_sizes) = c("word_class","language","mean_window_length", "sd_window_length")

# Put language column first
pause_probability.window_sizes = pause_probability.window_sizes[,c(2,1,3,4)]
pause_probability.window_sizes$word_class = as.character(pause_probability.window_sizes$word_class)
pause_probability.window_sizes$word_class[pause_probability.window_sizes$word_class=="N"] = "nouns"
pause_probability.window_sizes$word_class[pause_probability.window_sizes$word_class=="V"] = "verbs"
pause_probability.window_sizes$word_class = factor(pause_probability.window_sizes$word_class)

pause_probability.window_sizes = cbind(pause_probability.window_sizes[pause_probability.window_sizes$word_class=="nouns",c(1,3,4)],pause_probability.window_sizes[pause_probability.window_sizes$word_class=="verbs",c(3,4)])
colnames(pause_probability.window_sizes) = c("language","mean_window_length_nouns", "sd_window_length_nouns","mean_window_length_verbs", "sd_window_length_verbs")

pause_probability.window_sizes$difference = pause_probability.window_sizes$mean_window_length_nouns-pause_probability.window_sizes$mean_window_length_verbs

pause_probability.window_sizes
#      language mean_window_length_nouns sd_window_length_nouns mean_window_length_verbs sd_window_length_verbs   difference
# 1       Baure                0.4667598              0.1815234                0.4727635              0.1891085 -0.006003740
# 3        Bora                0.4924885              0.1457348                0.4995194              0.1629297 -0.007030931
# 5    Chintang                0.4499765              0.1601255                0.4594933              0.1476835 -0.009516729
# 7       Dutch                0.4674879              0.1247365                0.4128688              0.1664643  0.054619168
# 9     English                0.4838622              0.1136053                0.4381090              0.1545559  0.045753207
# 11       Even                0.4831121              0.1441263                0.4975049              0.1391110 -0.014392738
# 13     Hoocąk                0.5004754              0.1552542                0.5163212              0.1582292 -0.015845750
# 15       Nǁng                0.4295647              0.1401156                0.3213040              0.1595548  0.108260744
# 17 Texistepec                0.4597830              0.1410798                0.3851747              0.1714870  0.074608282
